resources_types = {
    "aws": [
        "aws",
        "aws_root",
        "aws_root_access_key",
        "aws_acm_certificate",
        "aws_acm_certificate_validation",
        "aws_acmpca_certificate_authority",
        "aws_api_gateway_account",
        "aws_api_gateway_api_key",
        "aws_api_gateway_authorizer",
        "aws_api_gateway_base_path_mapping",
        "aws_api_gateway_client_certificate",
        "aws_api_gateway_deployment",
        "aws_api_gateway_documentation_part",
        "aws_api_gateway_documentation_version",
        "aws_api_gateway_domain_name",
        "aws_api_gateway_gateway_response",
        "aws_api_gateway_integration",
        "aws_api_gateway_integration_response",
        "aws_api_gateway_method",
        "aws_api_gateway_method_response",
        "aws_api_gateway_method_settings",
        "aws_api_gateway_model",
        "aws_api_gateway_request_validator",
        "aws_api_gateway_resource",
        "aws_api_gateway_rest_api",
        "aws_api_gateway_stage",
        "aws_api_gateway_usage_plan",
        "aws_api_gateway_usage_plan_key",
        "aws_api_gateway_vpc_link",
        "aws_apigatewayv2_api",
        "aws_apigatewayv2_api_mapping",
        "aws_apigatewayv2_authorizer",
        "aws_apigatewayv2_deployment",
        "aws_apigatewayv2_domain_name",
        "aws_apigatewayv2_integration",
        "aws_apigatewayv2_integration_response",
        "aws_apigatewayv2_model",
        "aws_apigatewayv2_route",
        "aws_apigatewayv2_route_response",
        "aws_apigatewayv2_stage",
        "aws_apigatewayv2_vpc_link",
        "aws_accessanalyzer_analyzer",
        "aws_appmesh_mesh",
        "aws_appmesh_route",
        "aws_appmesh_virtual_node",
        "aws_appmesh_virtual_router",
        "aws_appmesh_virtual_service",
        "aws_appsync_api_key",
        "aws_appsync_datasource",
        "aws_appsync_function",
        "aws_appsync_graphql_api",
        "aws_appsync_resolver",
        "aws_appautoscaling_policy",
        "aws_appautoscaling_scheduled_action",
        "aws_appautoscaling_target",
        "aws_athena_database",
        "aws_athena_named_query",
        "aws_athena_workgroup",
        "aws_autoscaling_attachment",
        "aws_autoscaling_group",
        "aws_autoscaling_lifecycle_hook",
        "aws_autoscaling_notification",
        "aws_autoscaling_policy",
        "aws_autoscaling_schedule",
        "aws_backup_plan",
        "aws_backup_selection",
        "aws_backup_vault",
        "aws_batch_compute_environment",
        "aws_batch_job_definition",
        "aws_batch_job_queue",
        "aws_budgets_budget",
        "aws_cloud9_environment_ec2",
        "aws_cloudformation_stack",
        "aws_cloudformation_stack_set",
        "aws_cloudformation_stack_set_instance",
        "aws_cloudfront_distribution",
        "aws_cloudfront_origin_access_identity",
        "aws_cloudfront_public_key",
        "aws_cloudhsm_v2_cluster",
        "aws_cloudhsm_v2_hsm",
        "aws_cloudtrail",
        "aws_cloudwatch_dashboard",
        "aws_cloudwatch_event_permission",
        "aws_cloudwatch_event_rule",
        "aws_cloudwatch_event_target",
        "aws_cloudwatch_log_destination",
        "aws_cloudwatch_log_destination_policy",
        "aws_cloudwatch_log_group",
        "aws_cloudwatch_log_metric_filter",
        "aws_cloudwatch_log_resource_policy",
        "aws_cloudwatch_log_stream",
        "aws_cloudwatch_log_subscription_filter",
        "aws_cloudwatch_metric_alarm",
        "aws_codebuild_project",
        "aws_codebuild_source_credential",
        "aws_codebuild_webhook",
        "aws_codecommit_repository",
        "aws_codecommit_trigger",
        "aws_codedeploy_app",
        "aws_codedeploy_deployment_config",
        "aws_codedeploy_deployment_group",
        "aws_codepipeline",
        "aws_codepipeline_webhook",
        "aws_codestarnotifications_notification_rule",
        "aws_cognito_identity_pool",
        "aws_cognito_identity_pool_roles_attachment",
        "aws_cognito_identity_provider",
        "aws_cognito_resource_server",
        "aws_cognito_user_group",
        "aws_cognito_user_pool",
        "aws_cognito_user_pool_client",
        "aws_cognito_user_pool_domain",
        "aws_config_aggregate_authorization",
        "aws_config_config_rule",
        "aws_config_configuration_aggregator",
        "aws_config_configuration_recorder",
        "aws_config_configuration_recorder_status",
        "aws_config_delivery_channel",
        "aws_config_organization_custom_rule",
        "aws_config_organization_managed_rule",
        "aws_cur_report_definition",
        "aws_dlm_lifecycle_policy",
        "aws_datapipeline_pipeline",
        "aws_datasync_agent",
        "aws_datasync_location_efs",
        "aws_datasync_location_nfs",
        "aws_datasync_location_s3",
        "aws_datasync_location_smb",
        "aws_datasync_task",
        "aws_dms_certificate",
        "aws_dms_endpoint",
        "aws_dms_event_subscription",
        "aws_dms_replication_instance",
        "aws_dms_replication_subnet_group",
        "aws_dms_replication_task",
        "aws_devicefarm_project",
        "aws_dx_bgp_peer",
        "aws_dx_connection",
        "aws_dx_connection_association",
        "aws_dx_gateway",
        "aws_dx_gateway_association",
        "aws_dx_gateway_association_proposal",
        "aws_dx_hosted_private_virtual_interface",
        "aws_dx_hosted_private_virtual_interface_accepter",
        "aws_dx_hosted_public_virtual_interface",
        "aws_dx_hosted_public_virtual_interface_accepter",
        "aws_dx_hosted_transit_virtual_interface",
        "aws_dx_hosted_transit_virtual_interface_accepter",
        "aws_dx_lag",
        "aws_dx_private_virtual_interface",
        "aws_dx_public_virtual_interface",
        "aws_dx_transit_virtual_interface",
        "aws_directory_service_conditional_forwarder",
        "aws_directory_service_directory",
        "aws_directory_service_log_subscription",
        "aws_docdb_cluster",
        "aws_docdb_cluster_instance",
        "aws_docdb_cluster_parameter_group",
        "aws_docdb_cluster_snapshot",
        "aws_docdb_subnet_group",
        "aws_dynamodb_global_table",
        "aws_dynamodb_table",
        "aws_dynamodb_table_item",
        "aws_dax_cluster",
        "aws_dax_parameter_group",
        "aws_dax_subnet_group",
        "aws_ami",
        "aws_ami_copy",
        "aws_ami_from_instance",
        "aws_ami_launch_permission",
        "aws_ebs_default_kms_key",
        "aws_ebs_encryption_by_default",
        "aws_ebs_snapshot",
        "aws_ebs_snapshot_copy",
        "aws_ebs_volume",
        "aws_ec2_availability_zone_group",
        "aws_ec2_capacity_reservation",
        "aws_ec2_client_vpn_authorization_rule",
        "aws_ec2_client_vpn_endpoint",
        "aws_ec2_client_vpn_network_association",
        "aws_ec2_client_vpn_route",
        "aws_ec2_fleet",
        "aws_ec2_local_gateway_route",
        "aws_ec2_local_gateway_route_table_vpc_association",
        "aws_ec2_tag",
        "aws_ec2_traffic_mirror_filter",
        "aws_ec2_traffic_mirror_filter_rule",
        "aws_ec2_traffic_mirror_session",
        "aws_ec2_traffic_mirror_target",
        "aws_ec2_transit_gateway",
        "aws_ec2_transit_gateway_peering_attachment",
        "aws_ec2_transit_gateway_peering_attachment_accepter",
        "aws_ec2_transit_gateway_route",
        "aws_ec2_transit_gateway_route_table",
        "aws_ec2_transit_gateway_route_table_association",
        "aws_ec2_transit_gateway_route_table_propagation",
        "aws_ec2_transit_gateway_vpc_attachment",
        "aws_ec2_transit_gateway_vpc_attachment_accepter",
        "aws_eip",
        "aws_eip_association",
        "aws_instance",
        "aws_key_pair",
        "aws_launch_configuration",
        "aws_launch_template",
        "aws_placement_group",
        "aws_snapshot_create_volume_permission",
        "aws_spot_datafeed_subscription",
        "aws_spot_fleet_request",
        "aws_spot_instance_request",
        "aws_volume_attachment",
        "aws_ecr_lifecycle_policy",
        "aws_ecr_repository",
        "aws_ecr_repository_policy",
        "aws_ecs_capacity_provider",
        "aws_ecs_cluster",
        "aws_ecs_service",
        "aws_ecs_task_definition",
        "aws_efs_access_point",
        "aws_efs_file_system",
        "aws_efs_file_system_policy",
        "aws_efs_mount_target",
        "aws_eks_cluster",
        "aws_eks_fargate_profile",
        "aws_eks_node_group",
        "aws_elasticache_cluster",
        "aws_elasticache_parameter_group",
        "aws_elasticache_replication_group",
        "aws_elasticache_security_group",
        "aws_elasticache_subnet_group",
        "aws_elastic_beanstalk_application",
        "aws_elastic_beanstalk_application_version",
        "aws_elastic_beanstalk_configuration_template",
        "aws_elastic_beanstalk_environment",
        "aws_app_cookie_stickiness_policy",
        "aws_elb",
        "aws_elb_attachment",
        "aws_lb_cookie_stickiness_policy",
        "aws_lb_ssl_negotiation_policy",
        "aws_load_balancer_backend_server_policy",
        "aws_load_balancer_listener_policy",
        "aws_load_balancer_policy",
        "aws_proxy_protocol_policy",
        "aws_lb",
        "aws_lb_listener",
        "aws_lb_listener_certificate",
        "aws_lb_listener_rule",
        "aws_lb_target_group",
        "aws_lb_target_group_attachment",
        "aws_emr_cluster",
        "aws_emr_instance_group",
        "aws_emr_security_configuration",
        "aws_elastictranscoder_pipeline",
        "aws_elastictranscoder_preset",
        "aws_elasticsearch_domain",
        "aws_elasticsearch_domain_policy",
        "aws_fsx_lustre_file_system",
        "aws_fsx_windows_file_system",
        "aws_fms_admin_account",
        "aws_gamelift_alias",
        "aws_gamelift_build",
        "aws_gamelift_fleet",
        "aws_gamelift_game_session_queue",
        "aws_glacier_vault",
        "aws_glacier_vault_lock",
        "aws_globalaccelerator_accelerator",
        "aws_globalaccelerator_endpoint_group",
        "aws_globalaccelerator_listener",
        "aws_glue_catalog_database",
        "aws_glue_catalog_table",
        "aws_glue_classifier",
        "aws_glue_connection",
        "aws_glue_crawler",
        "aws_glue_job",
        "aws_glue_security_configuration",
        "aws_glue_trigger",
        "aws_glue_workflow",
        "aws_guardduty_detector",
        "aws_guardduty_invite_accepter",
        "aws_guardduty_ipset",
        "aws_guardduty_member",
        "aws_guardduty_organization_admin_account",
        "aws_guardduty_organization_configuration",
        "aws_guardduty_threatintelset",
        "aws_iam_access_key",
        "aws_iam_account_alias",
        "aws_iam_account_password_policy",
        "aws_iam_group",
        "aws_iam_group_membership",
        "aws_iam_group_policy",
        "aws_iam_group_policy_attachment",
        "aws_iam_instance_profile",
        "aws_iam_openid_connect_provider",
        "aws_iam_policy",
        "aws_iam_policy_attachment",
        "aws_iam_policy_document",
        "aws_iam_role",
        "aws_iam_role_policy",
        "aws_iam_role_policy_attachment",
        "aws_iam_saml_provider",
        "aws_iam_server_certificate",
        "aws_iam_service_linked_role",
        "aws_iam_user",
        "aws_iam_user_group_membership",
        "aws_iam_user_login_profile",
        "aws_iam_user_policy",
        "aws_iam_user_policy_attachment",
        "aws_iam_user_ssh_key",
        "aws_inspector_assessment_target",
        "aws_inspector_assessment_template",
        "aws_inspector_resource_group",
        "aws_iot_certificate",
        "aws_iot_policy",
        "aws_iot_policy_attachment",
        "aws_iot_role_alias",
        "aws_iot_thing",
        "aws_iot_thing_principal_attachment",
        "aws_iot_thing_type",
        "aws_iot_topic_rule",
        "aws_kms_alias",
        "aws_kms_ciphertext",
        "aws_kms_external_key",
        "aws_kms_grant",
        "aws_kms_key",
        "aws_kinesis_analytics_application",
        "aws_kinesis_stream",
        "aws_kinesis_firehose_delivery_stream",
        "aws_kinesis_video_stream",
        "aws_lambda_alias",
        "aws_lambda_event_source_mapping",
        "aws_lambda_function",
        "aws_lambda_function_event_invoke_config",
        "aws_lambda_layer_version",
        "aws_lambda_permission",
        "aws_lambda_provisioned_concurrency_config",
        "aws_licensemanager_association",
        "aws_licensemanager_license_configuration",
        "aws_lightsail_domain",
        "aws_lightsail_instance",
        "aws_lightsail_key_pair",
        "aws_lightsail_static_ip",
        "aws_lightsail_static_ip_attachment",
        "aws_mq_broker",
        "aws_mq_configuration",
        "aws_macie_member_account_association",
        "aws_macie_s3_bucket_association",
        "aws_msk_cluster",
        "aws_msk_configuration",
        "aws_media_convert_queue",
        "aws_media_package_channel",
        "aws_media_store_container",
        "aws_media_store_container_policy",
        "aws_neptune_cluster",
        "aws_neptune_cluster_instance",
        "aws_neptune_cluster_parameter_group",
        "aws_neptune_cluster_snapshot",
        "aws_neptune_event_subscription",
        "aws_neptune_parameter_group",
        "aws_neptune_subnet_group",
        "aws_opsworks_application",
        "aws_opsworks_custom_layer",
        "aws_opsworks_ganglia_layer",
        "aws_opsworks_haproxy_layer",
        "aws_opsworks_instance",
        "aws_opsworks_java_app_layer",
        "aws_opsworks_memcached_layer",
        "aws_opsworks_mysql_layer",
        "aws_opsworks_nodejs_app_layer",
        "aws_opsworks_permission",
        "aws_opsworks_php_app_layer",
        "aws_opsworks_rails_app_layer",
        "aws_opsworks_rds_db_instance",
        "aws_opsworks_stack",
        "aws_opsworks_static_web_layer",
        "aws_opsworks_user_profile",
        "aws_organizations_account",
        "aws_organizations_organization",
        "aws_organizations_organizational_unit",
        "aws_organizations_policy",
        "aws_organizations_policy_attachment",
        "aws_pinpoint_adm_channel",
        "aws_pinpoint_apns_channel",
        "aws_pinpoint_apns_sandbox_channel",
        "aws_pinpoint_apns_voip_channel",
        "aws_pinpoint_apns_voip_sandbox_channel",
        "aws_pinpoint_app",
        "aws_pinpoint_baidu_channel",
        "aws_pinpoint_email_channel",
        "aws_pinpoint_event_stream",
        "aws_pinpoint_gcm_channel",
        "aws_pinpoint_sms_channel",
        "aws_qldb_ledger",
        "aws_quicksight_group",
        "aws_quicksight_user",
        "aws_ram_principal_association",
        "aws_ram_resource_association",
        "aws_ram_resource_share",
        "aws_ram_resource_share_accepter",
        "aws_db_cluster_snapshot",
        "aws_db_event_subscription",
        "aws_db_instance",
        "aws_db_instance_role_association",
        "aws_db_option_group",
        "aws_db_parameter_group",
        "aws_db_security_group",
        "aws_db_snapshot",
        "aws_db_subnet_group",
        "aws_rds_cluster",
        "aws_rds_cluster_endpoint",
        "aws_rds_cluster_instance",
        "aws_rds_cluster_parameter_group",
        "aws_rds_global_cluster",
        "aws_redshift_cluster",
        "aws_redshift_event_subscription",
        "aws_redshift_parameter_group",
        "aws_redshift_security_group",
        "aws_redshift_snapshot_copy_grant",
        "aws_redshift_snapshot_schedule",
        "aws_redshift_snapshot_schedule_association",
        "aws_redshift_subnet_group",
        "aws_resourcegroups_group",
        "aws_route53_delegation_set",
        "aws_route53_health_check",
        "aws_route53_query_log",
        "aws_route53_record",
        "aws_route53_zone",
        "aws_route53_zone_association",
        "aws_route53_resolver_endpoint",
        "aws_route53_resolver_rule",
        "aws_route53_resolver_rule_association",
        "aws_s3_access_point",
        "aws_s3_account_public_access_block",
        "aws_s3_bucket",
        "aws_s3_bucket_analytics_configuration",
        "aws_s3_bucket_inventory",
        "aws_s3_bucket_metric",
        "aws_s3_bucket_notification",
        "aws_s3_bucket_object",
        "aws_s3_bucket_policy",
        "aws_s3_bucket_public_access_block",
        "aws_ses_active_receipt_rule_set",
        "aws_ses_configuration_set",
        "aws_ses_domain_dkim",
        "aws_ses_domain_identity",
        "aws_ses_domain_identity_verification",
        "aws_ses_domain_mail_from",
        "aws_ses_email_identity",
        "aws_ses_event_destination",
        "aws_ses_identity_notification_topic",
        "aws_ses_identity_policy",
        "aws_ses_receipt_filter",
        "aws_ses_receipt_rule",
        "aws_ses_receipt_rule_set",
        "aws_ses_template",
        "aws_sns_platform_application",
        "aws_sns_sms_preferences",
        "aws_sns_topic",
        "aws_sns_topic_policy",
        "aws_sns_topic_subscription",
        "aws_sqs_queue",
        "aws_sqs_queue_policy",
        "aws_ssm_activation",
        "aws_ssm_association",
        "aws_ssm_document",
        "aws_ssm_maintenance_window",
        "aws_ssm_maintenance_window_target",
        "aws_ssm_maintenance_window_task",
        "aws_ssm_parameter",
        "aws_ssm_patch_baseline",
        "aws_ssm_patch_group",
        "aws_ssm_resource_data_sync",
        "aws_swf_domain",
        "aws_sagemaker_endpoint",
        "aws_sagemaker_endpoint_configuration",
        "aws_sagemaker_model",
        "aws_sagemaker_notebook_instance",
        "aws_sagemaker_notebook_instance_lifecycle_configuration",
        "aws_secretsmanager_secret",
        "aws_secretsmanager_secret_rotation",
        "aws_secretsmanager_secret_version",
        "aws_securityhub_account",
        "aws_securityhub_member",
        "aws_securityhub_product_subscription",
        "aws_securityhub_standards_subscription",
        "aws_servicecatalog_portfolio",
        "aws_service_discovery_http_namespace",
        "aws_service_discovery_private_dns_namespace",
        "aws_service_discovery_public_dns_namespace",
        "aws_service_discovery_service",
        "aws_servicequotas_service_quota",
        "aws_shield_protection",
        "aws_simpledb_domain",
        "aws_sfn_activity",
        "aws_sfn_state_machine",
        "aws_storagegateway_cache",
        "aws_storagegateway_cached_iscsi_volume",
        "aws_storagegateway_gateway",
        "aws_storagegateway_nfs_file_share",
        "aws_storagegateway_smb_file_share",
        "aws_storagegateway_upload_buffer",
        "aws_storagegateway_working_storage",
        "aws_transfer_server",
        "aws_transfer_ssh_key",
        "aws_transfer_user",
        "aws_customer_gateway",
        "aws_default_network_acl",
        "aws_default_route_table",
        "aws_default_security_group",
        "aws_default_subnet",
        "aws_default_vpc",
        "aws_default_vpc_dhcp_options",
        "aws_egress_only_internet_gateway",
        "aws_flow_log",
        "aws_internet_gateway",
        "aws_main_route_table_association",
        "aws_nat_gateway",
        "aws_network_acl",
        "aws_network_acl_rule",
        "aws_network_interface",
        "aws_network_interface_attachment",
        "aws_network_interface_sg_attachment",
        "aws_route",
        "aws_route_table",
        "aws_route_table_association",
        "aws_security_group",
        "aws_security_group_rule",
        "aws_subnet",
        "aws_vpc",
        "aws_vpc_dhcp_options",
        "aws_vpc_dhcp_options_association",
        "aws_vpc_endpoint",
        "aws_vpc_endpoint_connection_notification",
        "aws_vpc_endpoint_route_table_association",
        "aws_vpc_endpoint_service",
        "aws_vpc_endpoint_service_allowed_principal",
        "aws_vpc_endpoint_subnet_association",
        "aws_vpc_ipv4_cidr_block_association",
        "aws_vpc_peering_connection",
        "aws_vpc_peering_connection_accepter",
        "aws_vpc_peering_connection_options",
        "aws_vpn_connection",
        "aws_vpn_connection_route",
        "aws_vpn_gateway",
        "aws_vpn_gateway_attachment",
        "aws_vpn_gateway_route_propagation",
        "aws_waf_byte_match_set",
        "aws_waf_geo_match_set",
        "aws_waf_ipset",
        "aws_waf_rate_based_rule",
        "aws_waf_regex_match_set",
        "aws_waf_regex_pattern_set",
        "aws_waf_rule",
        "aws_waf_rule_group",
        "aws_waf_size_constraint_set",
        "aws_waf_sql_injection_match_set",
        "aws_waf_web_acl",
        "aws_waf_xss_match_set",
        "aws_wafregional_byte_match_set",
        "aws_wafregional_geo_match_set",
        "aws_wafregional_ipset",
        "aws_wafregional_rate_based_rule",
        "aws_wafregional_regex_match_set",
        "aws_wafregional_regex_pattern_set",
        "aws_wafregional_rule",
        "aws_wafregional_rule_group",
        "aws_wafregional_size_constraint_set",
        "aws_wafregional_sql_injection_match_set",
        "aws_wafregional_web_acl",
        "aws_wafregional_web_acl_association",
        "aws_wafregional_xss_match_set",
        "aws_wafv2_ip_set",
        "aws_wafv2_regex_pattern_set",
        "aws_wafv2_rule_group",
        "aws_wafv2_web_acl",
        "aws_wafv2_web_acl_association",
        "aws_wafv2_web_acl_logging_configuration",
        "aws_worklink_fleet",
        "aws_worklink_website_certificate_authority_association",
        "aws_workspaces_directory",
        "aws_workspaces_ip_group",
        "aws_workspaces_workspace",
        "aws_xray_sampling_rule",
        "aws_route53_vpc_association_authorization",
        "aws_alb",
        "aws_alb_listener",
        "aws_alb_listener_certificate",
        "aws_alb_listener_rule",
        "aws_alb_target_group",
        "aws_alb_target_group_attachment",
        "aws_api_gateway_rest_api_policy",
        "aws_appmesh_gateway_route",
        "aws_appmesh_virtual_gateway",
        "aws_autoscalingplans_scaling_plan",
        "aws_backup_global_settings",
        "aws_backup_region_settings",
        "aws_backup_vault_notifications",
        "aws_backup_vault_policy",
        "aws_cloudfront_cache_policy",
        "aws_cloudfront_origin_request_policy",
        "aws_cloudfront_realtime_log_config",
        "aws_cloudwatch_composite_alarm",
        "aws_cloudwatch_event_archive",
        "aws_cloudwatch_event_bus",
        "aws_codeartifact_domain",
        "aws_codeartifact_domain_permissions_policy",
        "aws_codeartifact_repository",
        "aws_codeartifact_repository_permissions_policy",
        "aws_codebuild_report_group",
        "aws_codestarconnections_connection",
        "aws_config_conformance_pack",
        "aws_config_remediation_configuration",
        "aws_datasync_location_fsx_windows_file_system",
        "aws_db_proxy",
        "aws_db_proxy_default_target_group",
        "aws_db_proxy_target",
        "aws_ec2_carrier_gateway",
        "aws_ec2_managed_prefix_list",
        "aws_ec2_transit_gateway_prefix_list_reference",
        "aws_elasticache_global_replication_group",
        "aws_emr_instance_fleet",
        "aws_emr_managed_scaling_policy",
        "aws_fms_policy",
        "aws_glue_data_catalog_encryption_settings",
        "aws_glue_dev_endpoint",
        "aws_glue_ml_transform",
        "aws_glue_partition",
        "aws_glue_registry",
        "aws_glue_resource_policy",
        "aws_glue_schema",
        "aws_glue_user_defined_function",
        "aws_guardduty_filter",
        "aws_guardduty_publishing_destination",
        "aws_imagebuilder_component",
        "aws_imagebuilder_distribution_configuration",
        "aws_imagebuilder_image",
        "aws_imagebuilder_image_pipeline",
        "aws_imagebuilder_image_recipe",
        "aws_imagebuilder_infrastructure_configuration",
        "aws_kinesisanalyticsv2_application",
        "aws_lakeformation_data_lake_settings",
        "aws_lakeformation_permissions",
        "aws_lakeformation_resource",
        "aws_lambda_code_signing_config",
        "aws_lex_bot",
        "aws_lex_bot_alias",
        "aws_lex_intent",
        "aws_lex_slot_type",
        "aws_msk_scram_secret_association",
        "aws_networkfirewall_firewall",
        "aws_networkfirewall_firewall_policy",
        "aws_networkfirewall_logging_configuration",
        "aws_networkfirewall_resource_policy",
        "aws_networkfirewall_rule_group",
        "aws_prometheus_workspace",
        "aws_route53_key_signing_key",
        "aws_route53_resolver_dnssec_config",
        "aws_route53_resolver_query_log_config",
        "aws_route53_resolver_query_log_config_association",
        "aws_s3_bucket_ownership_controls",
        "aws_s3_object_copy",
        "aws_s3control_bucket",
        "aws_s3control_bucket_lifecycle_configuration",
        "aws_s3control_bucket_policy",
        "aws_s3outposts_endpoint",
        "aws_sagemaker_app_image_config",
        "aws_sagemaker_code_repository",
        "aws_sagemaker_domain",
        "aws_sagemaker_feature_group",
        "aws_sagemaker_image",
        "aws_sagemaker_image_version",
        "aws_sagemaker_model_package_group",
        "aws_sagemaker_user_profile",
        "aws_secretsmanager_secret_policy",
        "aws_securityhub_action_target",
        "aws_securityhub_invite_accepter",
        "aws_securityhub_organization_admin_account",
        "aws_serverlessapplicationrepository_cloudformation_stack",
        "aws_signer_signing_job",
        "aws_signer_signing_profile",
        "aws_signer_signing_profile_permission",
        "aws_ssoadmin_account_assignment",
        "aws_ssoadmin_managed_policy_attachment",
        "aws_ssoadmin_permission_set",
        "aws_ssoadmin_permission_set_inline_policy",
        "aws_storagegateway_stored_iscsi_volume",
        "aws_storagegateway_tape_pool",
        "aws_synthetics_canary",
        "aws_xray_encryption_config",
        "aws_xray_group",
        "aws_acmpca_certificate",
        "aws_acmpca_certificate_authority_certificate",
        "aws_cloudfront_key_group",
        "aws_cloudwatch_query_definition",
        "aws_cognito_user_pool_ui_customization",
        "aws_ecr_registry_policy",
        "aws_ecr_replication_configuration",
        "aws_ecrpublic_repository",
        "aws_eks_addon",
        "aws_kinesis_stream_consumer",
        "aws_kinesisanalyticsv2_application_snapshot",
        "aws_lightsail_instance_public_ports",
        "aws_mwaa_environment",
        "aws_route53_hosted_zone_dnssec",
        "aws_route53_resolver_firewall_domain_list",
        "aws_route53_resolver_firewall_rule_group",
        "aws_sagemaker_app",
        "aws_securityhub_insight",
        "aws_timestreamwrite_database",
        "aws_account_alternate_contact",
        "aws_amplify_app",
        "aws_amplify_backend_environment",
        "aws_amplify_branch",
        "aws_amplify_domain_association",
        "aws_amplify_webhook",
        "aws_appconfig_application",
        "aws_appconfig_configuration_profile",
        "aws_appconfig_deployment",
        "aws_appconfig_deployment_strategy",
        "aws_appconfig_environment",
        "aws_appconfig_hosted_configuration_version",
        "aws_apprunner_auto_scaling_configuration_version",
        "aws_apprunner_connection",
        "aws_apprunner_custom_domain_association",
        "aws_apprunner_service",
        "aws_appstream_directory_config",
        "aws_appstream_fleet",
        "aws_appstream_fleet_stack_association",
        "aws_appstream_image_builder",
        "aws_appstream_stack",
        "aws_appstream_user",
        "aws_appstream_user_stack_association",
        "aws_autoscaling_group_tag",
        "aws_backup_vault_lock_configuration",
        "aws_batch_scheduling_policy",
        "aws_budgets_budget_action",
        "aws_chime_voice_connector",
        "aws_chime_voice_connector_group",
        "aws_chime_voice_connector_logging",
        "aws_chime_voice_connector_origination",
        "aws_chime_voice_connector_streaming",
        "aws_chime_voice_connector_termination",
        "aws_chime_voice_connector_termination_credentials",
        "aws_cloud9_environment_membership",
        "aws_cloudcontrolapi_resource",
        "aws_cloudformation_type",
        "aws_cloudfront_field_level_encryption_config",
        "aws_cloudfront_field_level_encryption_profile",
        "aws_cloudfront_function",
        "aws_cloudfront_monitoring_subscription",
        "aws_cloudfront_response_headers_policy",
        "aws_cloudwatch_event_api_destination",
        "aws_cloudwatch_event_bus_policy",
        "aws_cloudwatch_event_connection",
        "aws_cloudwatch_metric_stream",
        "aws_codebuild_resource_policy",
        "aws_codecommit_approval_rule_template",
        "aws_codecommit_approval_rule_template_association",
        "aws_codestarconnections_host",
        "aws_config_organization_conformance_pack",
        "aws_connect_bot_association",
        "aws_connect_contact_flow",
        "aws_connect_hours_of_operation",
        "aws_connect_instance",
        "aws_connect_lambda_function_association",
        "aws_datasync_location_fsx_lustre_file_system",
        "aws_datasync_location_hdfs",
        "aws_db_proxy_endpoint",
        "aws_detective_graph",
        "aws_devicefarm_device_pool",
        "aws_devicefarm_network_profile",
        "aws_devicefarm_upload",
        "aws_docdb_global_cluster",
        "aws_dx_connection_confirmation",
        "aws_dx_hosted_connection",
        "aws_dynamodb_kinesis_streaming_destination",
        "aws_dynamodb_tag",
        "aws_ebs_snapshot_import",
        "aws_ec2_host",
        "aws_ec2_managed_prefix_list_entry",
        "aws_ec2_subnet_cidr_reservation",
        "aws_ecr_pull_through_cache_rule",
        "aws_ecr_registry_scanning_configuration",
        "aws_ecrpublic_repository_policy",
        "aws_ecs_account_setting_default",
        "aws_ecs_tag",
        "aws_ecs_task_set",
        "aws_efs_backup_policy",
        "aws_eks_identity_provider_config",
        "aws_elasticache_user",
        "aws_elasticache_user_group",
        "aws_elasticsearch_domain_saml_options",
        "aws_emr_studio",
        "aws_emr_studio_session_mapping",
        "aws_fsx_backup",
        "aws_fsx_ontap_file_system",
        "aws_fsx_ontap_storage_virtual_machine",
        "aws_fsx_ontap_volume",
        "aws_fsx_openzfs_file_system",
        "aws_fsx_openzfs_snapshot",
        "aws_fsx_openzfs_volume",
        "aws_glue_partition_index",
        "aws_iot_authorizer",
        "aws_iot_thing_group",
        "aws_iot_thing_group_membership",
        "aws_kms_replica_external_key",
        "aws_kms_replica_key",
        "aws_lambda_layer_version_permission",
        "aws_macie2_account",
        "aws_macie2_classification_job",
        "aws_macie2_custom_data_identifier",
        "aws_macie2_findings_filter",
        "aws_macie2_invitation_accepter",
        "aws_macie2_member",
        "aws_macie2_organization_admin_account",
        "aws_memorydb_acl",
        "aws_memorydb_cluster",
        "aws_memorydb_parameter_group",
        "aws_memorydb_subnet_group",
        "aws_memorydb_user",
        "aws_mskconnect_custom_plugin",
        "aws_mskconnect_worker_configuration",
        "aws_neptune_cluster_endpoint",
        "aws_organizations_delegated_administrator",
        "aws_prometheus_alert_manager_definition",
        "aws_prometheus_rule_group_namespace",
        "aws_quicksight_data_source",
        "aws_quicksight_group_membership",
        "aws_rds_cluster_role_association",
        "aws_redshift_scheduled_action",
        "aws_route53_resolver_firewall_config",
        "aws_route53_resolver_firewall_rule",
        "aws_route53_resolver_firewall_rule_group_association",
        "aws_route53recoverycontrolconfig_cluster",
        "aws_route53recoverycontrolconfig_control_panel",
        "aws_route53recoverycontrolconfig_routing_control",
        "aws_route53recoverycontrolconfig_safety_rule",
        "aws_route53recoveryreadiness_cell",
        "aws_route53recoveryreadiness_readiness_check",
        "aws_route53recoveryreadiness_recovery_group",
        "aws_route53recoveryreadiness_resource_set",
        "aws_s3_bucket_intelligent_tiering_configuration",
        "aws_s3_bucket_replication_configuration",
        "aws_s3control_access_point_policy",
        "aws_s3control_multi_region_access_point",
        "aws_s3control_multi_region_access_point_policy",
        "aws_s3control_object_lambda_access_point",
        "aws_s3control_object_lambda_access_point_policy",
        "aws_sagemaker_device",
        "aws_sagemaker_device_fleet",
        "aws_sagemaker_flow_definition",
        "aws_sagemaker_human_task_ui",
        "aws_sagemaker_model_package_group_policy",
        "aws_sagemaker_studio_lifecycle_config",
        "aws_sagemaker_workforce",
        "aws_sagemaker_workteam",
        "aws_schemas_discoverer",
        "aws_schemas_registry",
        "aws_schemas_schema",
        "aws_securityhub_finding_aggregator",
        "aws_securityhub_organization_configuration",
        "aws_securityhub_standards_control",
        "aws_service_discovery_instance",
        "aws_servicecatalog_budget_resource_association",
        "aws_servicecatalog_constraint",
        "aws_servicecatalog_organizations_access",
        "aws_servicecatalog_portfolio_share",
        "aws_servicecatalog_principal_portfolio_association",
        "aws_servicecatalog_product",
        "aws_servicecatalog_product_portfolio_association",
        "aws_servicecatalog_provisioned_product",
        "aws_servicecatalog_provisioning_artifact",
        "aws_servicecatalog_service_action",
        "aws_servicecatalog_tag_option",
        "aws_servicecatalog_tag_option_resource_association",
        "aws_shield_protection_group",
        "aws_storagegateway_file_system_association",
        "aws_timestreamwrite_table",
        "aws_transfer_access",
        "aws_vpc_endpoint_connection_accepter",
        "aws_vpc_ipam",
        "aws_vpc_ipam_organization_admin_account",
        "aws_vpc_ipam_pool",
        "aws_vpc_ipam_pool_cidr",
        "aws_vpc_ipam_pool_cidr_allocation",
        "aws_vpc_ipam_preview_next_cidr",
        "aws_vpc_ipam_scope",
        "aws_vpc_ipv6_cidr_block_association",
        "aws_accessanalyzer_archive_rule",
        "aws_acmpca_policy",
        "aws_appflow_connector_profile",
        "aws_appflow_flow",
        "aws_appintegrations_event_integration",
        "aws_applicationinsights_application",
        "aws_apprunner_observability_configuration",
        "aws_apprunner_vpc_connector",
        "aws_appsync_api_cache",
        "aws_appsync_domain_name",
        "aws_appsync_domain_name_api_association",
        "aws_athena_data_catalog",
        "aws_backup_framework",
        "aws_backup_report_plan",
        "aws_ce_anomaly_monitor",
        "aws_ce_anomaly_subscription",
        "aws_ce_cost_allocation_tag",
        "aws_ce_cost_category",
        "aws_cloudsearch_domain",
        "aws_cloudsearch_domain_service_access_policy",
        "aws_cloudtrail_event_data_store",
        "aws_cognito_identity_pool_provider_principal_tag",
        "aws_cognito_risk_configuration",
        "aws_cognito_user",
        "aws_cognito_user_in_group",
        "aws_connect_contact_flow_module",
        "aws_connect_queue",
        "aws_connect_quick_connect",
        "aws_connect_routing_profile",
        "aws_connect_security_profile",
        "aws_connect_user",
        "aws_connect_user_hierarchy_group",
        "aws_connect_user_hierarchy_structure",
        "aws_connect_vocabulary",
        "aws_dataexchange_data_set",
        "aws_dataexchange_revision",
        "aws_datapipeline_pipeline_definition",
        "aws_datasync_location_fsx_openzfs_file_system",
        "aws_db_instance_automated_backups_replication",
        "aws_db_snapshot_copy",
        "aws_detective_invitation_accepter",
        "aws_detective_member",
        "aws_devicefarm_instance_profile",
        "aws_devicefarm_test_grid_project",
        "aws_directory_service_shared_directory",
        "aws_directory_service_shared_directory_accepter",
        "aws_docdb_event_subscription",
        "aws_dynamodb_contributor_insights",
        "aws_ec2_network_insights_path",
        "aws_ec2_serial_console_access",
        "aws_ec2_transit_gateway_connect",
        "aws_ec2_transit_gateway_connect_peer",
        "aws_ec2_transit_gateway_multicast_domain",
        "aws_ec2_transit_gateway_multicast_domain_association",
        "aws_ec2_transit_gateway_multicast_group_member",
        "aws_ec2_transit_gateway_multicast_group_source",
        "aws_ecs_cluster_capacity_providers",
        "aws_efs_replication_configuration",
        "aws_elasticache_user_group_association",
        "aws_emrcontainers_virtual_cluster",
        "aws_emrserverless_application",
        "aws_fis_experiment_template",
        "aws_fsx_data_repository_association",
        "aws_gamelift_game_server_group",
        "aws_gamelift_script",
        "aws_grafana_license_association",
        "aws_grafana_role_association",
        "aws_grafana_workspace",
        "aws_grafana_workspace_saml_configuration",
        "aws_iam_service_specific_credential",
        "aws_iam_signing_certificate",
        "aws_iam_virtual_mfa_device",
        "aws_imagebuilder_container_recipe",
        "aws_internet_gateway_attachment",
        "aws_iot_indexing_configuration",
        "aws_iot_logging_options",
        "aws_iot_provisioning_template",
        "aws_iot_topic_rule_destination",
        "aws_kendra_experience",
        "aws_kendra_faq",
        "aws_kendra_index",
        "aws_kendra_query_suggestions_block_list",
        "aws_kendra_thesaurus",
        "aws_keyspaces_keyspace",
        "aws_keyspaces_table",
        "aws_lakeformation_lf_tag",
        "aws_lakeformation_resource_lf_tags",
        "aws_lambda_function_url",
        "aws_lambda_invocation",
        "aws_lightsail_container_service",
        "aws_lightsail_container_service_deployment_version",
        "aws_lightsail_database",
        "aws_location_geofence_collection",
        "aws_location_map",
        "aws_location_place_index",
        "aws_location_route_calculator",
        "aws_location_tracker",
        "aws_memorydb_snapshot",
        "aws_mskconnect_connector",
        "aws_network_acl_association",
        "aws_networkmanager_connection",
        "aws_networkmanager_customer_gateway_association",
        "aws_networkmanager_device",
        "aws_networkmanager_global_network",
        "aws_networkmanager_link",
        "aws_networkmanager_link_association",
        "aws_networkmanager_site",
        "aws_networkmanager_transit_gateway_connect_peer_association",
        "aws_networkmanager_transit_gateway_registration",
        "aws_opensearch_domain",
        "aws_opensearch_domain_policy",
        "aws_opensearch_domain_saml_options",
        "aws_opsworks_ecs_cluster_layer",
        "aws_qldb_stream",
        "aws_rds_cluster_activity_stream",
        "aws_redshift_authentication_profile",
        "aws_redshift_cluster_iam_roles",
        "aws_redshift_endpoint_access",
        "aws_redshift_hsm_client_certificate",
        "aws_redshift_hsm_configuration",
        "aws_redshift_usage_limit",
        "aws_redshiftdata_statement",
        "aws_redshiftserverless_namespace",
        "aws_rolesanywhere_profile",
        "aws_rolesanywhere_trust_anchor",
        "aws_route53_traffic_policy",
        "aws_route53_traffic_policy_instance",
        "aws_route53domains_registered_domain",
        "aws_rum_app_monitor",
        "aws_s3_bucket_accelerate_configuration",
        "aws_s3_bucket_acl",
        "aws_s3_bucket_cors_configuration",
        "aws_s3_bucket_lifecycle_configuration",
        "aws_s3_bucket_logging",
        "aws_s3_bucket_object_lock_configuration",
        "aws_s3_bucket_request_payment_configuration",
        "aws_s3_bucket_server_side_encryption_configuration",
        "aws_s3_bucket_versioning",
        "aws_s3_bucket_website_configuration",
        "aws_s3_object",
        "aws_sagemaker_project",
        "aws_shield_protection_health_check_association",
        "aws_transcribe_medical_vocabulary",
        "aws_transcribe_vocabulary",
        "aws_transcribe_vocabulary_filter",
        "aws_transfer_workflow",
        "aws_vpc_endpoint_policy",
        "aws_vpc_endpoint_security_group_association",
        "aws_acmpca_permission",
        "aws_appconfig_extension",
        "aws_appconfig_extension_association",
        "aws_apprunner_vpc_ingress_connection",
        "aws_auditmanager_account_registration",
        "aws_auditmanager_control",
        "aws_auditmanager_framework",
        "aws_cloudfront_origin_access_control",
        "aws_cloudwatch_log_data_protection_policy",
        "aws_codepipeline_custom_action_type",
        "aws_comprehend_document_classifier",
        "aws_comprehend_entity_recognizer",
        "aws_connect_instance_storage_config",
        "aws_connect_phone_number",
        "aws_controltower_control",
        "aws_directory_service_radius_settings",
        "aws_directory_service_region",
        "aws_dms_s3_endpoint",
        "aws_dx_macsec_key_association",
        "aws_dynamodb_table_replica",
        "aws_ec2_network_insights_analysis",
        "aws_ec2_transit_gateway_policy_table",
        "aws_ec2_transit_gateway_policy_table_association",
        "aws_evidently_feature",
        "aws_evidently_project",
        "aws_evidently_segment",
        "aws_fsx_file_cache",
        "aws_grafana_workspace_api_key",
        "aws_identitystore_group",
        "aws_identitystore_group_membership",
        "aws_identitystore_user",
        "aws_inspector2_delegated_admin_account",
        "aws_inspector2_enabler",
        "aws_inspector2_organization_configuration",
        "aws_ivs_channel",
        "aws_ivs_playback_key_pair",
        "aws_ivs_recording_configuration",
        "aws_ivschat_logging_configuration",
        "aws_ivschat_room",
        "aws_kendra_data_source",
        "aws_kms_custom_key_store",
        "aws_lightsail_certificate",
        "aws_lightsail_disk",
        "aws_lightsail_disk_attachment",
        "aws_lightsail_domain_entry",
        "aws_lightsail_lb",
        "aws_lightsail_lb_attachment",
        "aws_lightsail_lb_certificate",
        "aws_lightsail_lb_certificate_attachment",
        "aws_lightsail_lb_https_redirection_policy",
        "aws_lightsail_lb_stickiness_policy",
        "aws_location_tracker_association",
        "aws_macie2_classification_export_configuration",
        "aws_medialive_channel",
        "aws_medialive_input",
        "aws_medialive_input_security_group",
        "aws_medialive_multiplex",
        "aws_medialive_multiplex_program",
        "aws_msk_serverless_cluster",
        "aws_neptune_global_cluster",
        "aws_networkmanager_attachment_accepter",
        "aws_networkmanager_connect_attachment",
        "aws_networkmanager_core_network",
        "aws_networkmanager_site_to_site_vpn_attachment",
        "aws_networkmanager_transit_gateway_peering",
        "aws_networkmanager_transit_gateway_route_table_attachment",
        "aws_networkmanager_vpc_attachment",
        "aws_opensearch_inbound_connection_accepter",
        "aws_opensearch_outbound_connection",
        "aws_rds_reserved_instance",
        "aws_redshift_endpoint_authorization",
        "aws_redshift_partner",
        "aws_redshiftserverless_endpoint_access",
        "aws_redshiftserverless_resource_policy",
        "aws_redshiftserverless_snapshot",
        "aws_redshiftserverless_usage_limit",
        "aws_redshiftserverless_workgroup",
        "aws_resourceexplorer2_index",
        "aws_route53_resolver_config",
        "aws_rum_metrics_destination",
        "aws_s3control_storage_lens_configuration",
        "aws_sagemaker_servicecatalog_portfolio_status",
        "aws_sagemaker_space",
        "aws_scheduler_schedule",
        "aws_scheduler_schedule_group",
        "aws_schemas_registry_policy",
        "aws_sesv2_configuration_set",
        "aws_sesv2_dedicated_ip_assignment",
        "aws_sesv2_dedicated_ip_pool",
        "aws_sesv2_email_identity",
        "aws_sesv2_email_identity_feedback_attributes",
        "aws_sesv2_email_identity_mail_from_attributes",
        "aws_sqs_queue_redrive_allow_policy",
        "aws_sqs_queue_redrive_policy",
        "aws_ssm_default_patch_baseline",
        "aws_ssm_service_setting",
        "aws_ssoadmin_customer_managed_policy_attachment",
        "aws_ssoadmin_permissions_boundary_attachment",
        "aws_transcribe_language_model",
        "aws_transfer_tag",
        "aws_vpc_network_performance_metric_subscription",
        "aws_account_primary_contact",
        "aws_apprunner_default_auto_scaling_configuration_version",
        "aws_appsync_type",
        "aws_athena_prepared_statement",
        "aws_auditmanager_assessment",
        "aws_auditmanager_assessment_delegation",
        "aws_auditmanager_assessment_report",
        "aws_auditmanager_framework_share",
        "aws_auditmanager_organization_admin_account_registration",
        "aws_autoscaling_traffic_source_attachment",
        "aws_bedrock_model_invocation_logging_configuration",
        "aws_chimesdkmediapipelines_media_insights_pipeline_configuration",
        "aws_chimesdkvoice_global_settings",
        "aws_chimesdkvoice_sip_media_application",
        "aws_chimesdkvoice_sip_rule",
        "aws_chimesdkvoice_voice_profile_domain",
        "aws_cleanrooms_collaboration",
        "aws_cleanrooms_configured_table",
        "aws_cloudfront_continuous_deployment_policy",
        "aws_cloudwatch_event_endpoint",
        "aws_codecatalyst_dev_environment",
        "aws_codecatalyst_project",
        "aws_codecatalyst_source_repository",
        "aws_codeguruprofiler_profiling_group",
        "aws_codegurureviewer_repository_association",
        "aws_cognito_managed_user_pool_client",
        "aws_config_organization_custom_policy_rule",
        "aws_customerprofiles_domain",
        "aws_customerprofiles_profile",
        "aws_datasync_location_azure_blob",
        "aws_datasync_location_fsx_ontap_file_system",
        "aws_datasync_location_object_storage",
        "aws_detective_organization_admin_account",
        "aws_detective_organization_configuration",
        "aws_directory_service_trust",
        "aws_dms_replication_config",
        "aws_docdbelastic_cluster",
        "aws_ebs_fast_snapshot_restore",
        "aws_ec2_image_block_public_access",
        "aws_ec2_instance_connect_endpoint",
        "aws_ec2_instance_state",
        "aws_eks_access_entry",
        "aws_eks_access_policy_association",
        "aws_eks_pod_identity_association",
        "aws_elasticache_serverless_cache",
        "aws_elasticsearch_vpc_endpoint",
        "aws_emr_block_public_access_configuration",
        "aws_emrcontainers_job_template",
        "aws_evidently_launch",
        "aws_finspace_kx_cluster",
        "aws_finspace_kx_database",
        "aws_finspace_kx_dataview",
        "aws_finspace_kx_environment",
        "aws_finspace_kx_scaling_group",
        "aws_finspace_kx_user",
        "aws_finspace_kx_volume",
        "aws_globalaccelerator_custom_routing_accelerator",
        "aws_globalaccelerator_custom_routing_endpoint_group",
        "aws_globalaccelerator_custom_routing_listener",
        "aws_glue_data_quality_ruleset",
        "aws_guardduty_detector_feature",
        "aws_guardduty_organization_configuration_feature",
        "aws_iam_security_token_service_preferences",
        "aws_imagebuilder_workflow",
        "aws_inspector2_member_association",
        "aws_internetmonitor_monitor",
        "aws_iot_billing_group",
        "aws_iot_ca_certificate",
        "aws_iot_domain_configuration",
        "aws_iot_event_configurations",
        "aws_kinesis_resource_policy",
        "aws_kms_key_policy",
        "aws_lb_trust_store",
        "aws_lb_trust_store_revocation",
        "aws_lexv2models_bot",
        "aws_lexv2models_bot_locale",
        "aws_lexv2models_bot_version",
        "aws_lexv2models_intent",
        "aws_licensemanager_grant",
        "aws_licensemanager_grant_accepter",
        "aws_lightsail_bucket",
        "aws_lightsail_bucket_access_key",
        "aws_lightsail_bucket_resource_access",
        "aws_lightsail_distribution",
        "aws_msk_cluster_policy",
        "aws_msk_replicator",
        "aws_msk_vpc_connection",
        "aws_networkmanager_connect_peer",
        "aws_networkmanager_core_network_policy_attachment",
        "aws_oam_link",
        "aws_oam_sink",
        "aws_oam_sink_policy",
        "aws_opensearch_package",
        "aws_opensearch_package_association",
        "aws_opensearch_vpc_endpoint",
        "aws_opensearchserverless_access_policy",
        "aws_opensearchserverless_collection",
        "aws_opensearchserverless_lifecycle_policy",
        "aws_opensearchserverless_security_config",
        "aws_opensearchserverless_security_policy",
        "aws_opensearchserverless_vpc_endpoint",
        "aws_organizations_resource_policy",
        "aws_pipes_pipe",
        "aws_prometheus_scraper",
        "aws_quicksight_folder",
        "aws_quicksight_folder_membership",
        "aws_quicksight_vpc_connection",
        "aws_ram_sharing_with_organization",
        "aws_rbin_rule",
        "aws_rds_custom_db_engine_version",
        "aws_rds_export_task",
        "aws_redshift_cluster_snapshot",
        "aws_redshift_resource_policy",
        "aws_resourceexplorer2_view",
        "aws_resourcegroups_resource",
        "aws_route53_cidr_collection",
        "aws_route53_cidr_location",
        "aws_s3_directory_bucket",
        "aws_s3control_access_grant",
        "aws_s3control_access_grants_instance",
        "aws_s3control_access_grants_instance_resource_policy",
        "aws_s3control_access_grants_location",
        "aws_sagemaker_data_quality_job_definition",
        "aws_sagemaker_monitoring_schedule",
        "aws_sagemaker_pipeline",
        "aws_securitylake_aws_log_source",
        "aws_securitylake_data_lake",
        "aws_servicequotas_template",
        "aws_servicequotas_template_association",
        "aws_sesv2_account_vdm_attributes",
        "aws_sesv2_configuration_set_event_destination",
        "aws_sesv2_contact_list",
        "aws_sfn_alias",
        "aws_shield_application_layer_automatic_response",
        "aws_shield_drt_access_log_bucket_association",
        "aws_shield_drt_access_role_arn_association",
        "aws_sns_topic_data_protection_policy",
        "aws_ssmcontacts_contact",
        "aws_ssmcontacts_contact_channel",
        "aws_ssmcontacts_plan",
        "aws_ssmincidents_replication_set",
        "aws_ssmincidents_response_plan",
        "aws_ssoadmin_application",
        "aws_ssoadmin_application_access_scope",
        "aws_ssoadmin_application_assignment",
        "aws_ssoadmin_application_assignment_configuration",
        "aws_ssoadmin_instance_access_control_attributes",
        "aws_ssoadmin_trusted_token_issuer",
        "aws_synthetics_group",
        "aws_synthetics_group_association",
        "aws_transfer_agreement",
        "aws_transfer_certificate",
        "aws_transfer_connector",
        "aws_transfer_profile",
        "aws_verifiedaccess_endpoint",
        "aws_verifiedaccess_group",
        "aws_verifiedaccess_instance",
        "aws_verifiedaccess_instance_logging_configuration",
        "aws_verifiedaccess_instance_trust_provider_attachment",
        "aws_verifiedaccess_trust_provider",
        "aws_verifiedpermissions_policy_store",
        "aws_verifiedpermissions_policy_template",
        "aws_verifiedpermissions_schema",
        "aws_vpc_ipam_resource_discovery",
        "aws_vpc_ipam_resource_discovery_association",
        "aws_vpc_security_group_egress_rule",
        "aws_vpc_security_group_ingress_rule",
        "aws_vpclattice_access_log_subscription",
        "aws_vpclattice_auth_policy",
        "aws_vpclattice_listener",
        "aws_vpclattice_listener_rule",
        "aws_vpclattice_resource_policy",
        "aws_vpclattice_service",
        "aws_vpclattice_service_network",
        "aws_vpclattice_service_network_service_association",
        "aws_vpclattice_service_network_vpc_association",
        "aws_vpclattice_target_group",
        "aws_vpclattice_target_group_attachment",
        "aws_workspaces_connection_alias",
        "aws_az_info",
        "aws_caller_info",
        "aws_region_info",
        "aws_bedrockagent_agent",
        "aws_account_region",
        "aws_api_gateway_domain_name_access_association",
        "aws_appfabric_app_authorization",
        "aws_appfabric_app_authorization_connection",
        "aws_appfabric_app_bundle",
        "aws_appfabric_ingestion",
        "aws_appfabric_ingestion_destination",
        "aws_appintegrations_data_integration",
        "aws_apprunner_deployment",
        "aws_appsync_source_api_association",
        "aws_backup_logically_air_gapped_vault",
        "aws_backup_restore_testing_plan",
        "aws_backup_restore_testing_selection",
        "aws_bcmdataexports_export",
        "aws_bedrock_custom_model",
        "aws_bedrock_guardrail",
        "aws_bedrock_guardrail_version",
        "aws_bedrock_inference_profile",
        "aws_bedrock_provisioned_model_throughput",
        "aws_bedrockagent_agent_action_group",
        "aws_bedrockagent_agent_alias",
        "aws_bedrockagent_agent_collaborator",
        "aws_bedrockagent_agent_knowledge_base_association",
        "aws_bedrockagent_data_source",
        "aws_bedrockagent_knowledge_base",
        "aws_chatbot_slack_channel_configuration",
        "aws_chatbot_teams_channel_configuration",
        "aws_cleanrooms_membership",
        "aws_cloudformation_stack_instances",
        "aws_cloudfront_key_value_store",
        "aws_cloudfront_vpc_origin",
        "aws_cloudfrontkeyvaluestore_key",
        "aws_cloudtrail_organization_delegated_admin_account",
        "aws_cloudwatch_log_account_policy",
        "aws_cloudwatch_log_anomaly_detector",
        "aws_cloudwatch_log_delivery",
        "aws_cloudwatch_log_delivery_destination",
        "aws_cloudwatch_log_delivery_destination_policy",
        "aws_cloudwatch_log_delivery_source",
        "aws_cloudwatch_log_index_policy",
        "aws_codebuild_fleet",
        "aws_codeconnections_connection",
        "aws_codeconnections_host",
        "aws_computeoptimizer_enrollment_status",
        "aws_computeoptimizer_recommendation_preferences",
        "aws_config_retention_configuration",
        "aws_controltower_landing_zone",
        "aws_costoptimizationhub_enrollment_status",
        "aws_costoptimizationhub_preferences",
        "aws_datazone_asset_type",
        "aws_datazone_domain",
        "aws_datazone_environment",
        "aws_datazone_environment_blueprint_configuration",
        "aws_datazone_environment_profile",
        "aws_datazone_form_type",
        "aws_datazone_glossary",
        "aws_datazone_glossary_term",
        "aws_datazone_project",
        "aws_datazone_user_profile",
        "aws_devopsguru_event_sources_config",
        "aws_devopsguru_notification_channel",
        "aws_devopsguru_resource_collection",
        "aws_devopsguru_service_integration",
        "aws_drs_replication_configuration_template",
        "aws_dynamodb_resource_policy",
        "aws_dynamodb_table_export",
        "aws_ebs_snapshot_block_public_access",
        "aws_ec2_capacity_block_reservation",
        "aws_ec2_instance_metadata_defaults",
        "aws_ec2_transit_gateway_default_route_table_association",
        "aws_ec2_transit_gateway_default_route_table_propagation",
        "aws_ecr_account_setting",
        "aws_ecr_repository_creation_template",
        "aws_eip_domain_name",
        "aws_elasticache_reserved_cache_node",
        "aws_fms_resource_set",
        "aws_globalaccelerator_cross_account_attachment",
        "aws_glue_catalog_table_optimizer",
        "aws_grafana_workspace_service_account",
        "aws_grafana_workspace_service_account_token",
        "aws_guardduty_malware_protection_plan",
        "aws_guardduty_member_detector_feature",
        "aws_iam_group_policies_exclusive",
        "aws_iam_group_policy_attachments_exclusive",
        "aws_iam_organizations_features",
        "aws_iam_role_policies_exclusive",
        "aws_iam_role_policy_attachments_exclusive",
        "aws_iam_user_policies_exclusive",
        "aws_iam_user_policy_attachments_exclusive",
        "aws_imagebuilder_lifecycle_policy",
        "aws_lakeformation_data_cells_filter",
        "aws_lakeformation_resource_lf_tag",
        "aws_lambda_function_recursion_config",
        "aws_lambda_runtime_management_config",
        "aws_lexv2models_slot",
        "aws_lexv2models_slot_type",
        "aws_m2_application",
        "aws_m2_deployment",
        "aws_m2_environment",
        "aws_media_packagev2_channel_group",
        "aws_memorydb_multi_region_cluster",
        "aws_msk_single_scram_secret_association",
        "aws_networkfirewall_tls_inspection_configuration",
        "aws_networkmanager_dx_gateway_attachment",
        "aws_networkmonitor_monitor",
        "aws_networkmonitor_probe",
        "aws_opensearch_authorize_vpc_endpoint_access",
        "aws_osis_pipeline",
        "aws_paymentcryptography_key",
        "aws_paymentcryptography_key_alias",
        "aws_pinpoint_email_template",
        "aws_pinpointsmsvoicev2_configuration_set",
        "aws_pinpointsmsvoicev2_opt_out_list",
        "aws_pinpointsmsvoicev2_phone_number",
        "aws_quicksight_account_subscription",
        "aws_quicksight_analysis",
        "aws_quicksight_dashboard",
        "aws_quicksight_data_set",
        "aws_quicksight_iam_policy_assignment",
        "aws_quicksight_ingestion",
        "aws_quicksight_namespace",
        "aws_quicksight_refresh_schedule",
        "aws_quicksight_template",
        "aws_quicksight_template_alias",
        "aws_quicksight_theme",
        "aws_rds_certificate",
        "aws_rds_cluster_snapshot_copy",
        "aws_rds_instance_state",
        "aws_rds_integration",
        "aws_redshift_data_share_authorization",
        "aws_redshift_data_share_consumer_association",
        "aws_redshift_logging",
        "aws_redshift_snapshot_copy",
        "aws_redshiftserverless_custom_domain_association",
        "aws_rekognition_collection",
        "aws_rekognition_project",
        "aws_rekognition_stream_processor",
        "aws_resiliencehub_resiliency_policy",
        "aws_route53domains_delegation_signer_record",
        "aws_route53domains_domain",
        "aws_route53profiles_association",
        "aws_route53profiles_profile",
        "aws_route53profiles_resource_association",
        "aws_s3tables_namespace",
        "aws_s3tables_table",
        "aws_s3tables_table_bucket",
        "aws_s3tables_table_bucket_policy",
        "aws_s3tables_table_policy",
        "aws_sagemaker_hub",
        "aws_sagemaker_mlflow_tracking_server",
        "aws_securityhub_automation_rule",
        "aws_securityhub_configuration_policy",
        "aws_securityhub_configuration_policy_association",
        "aws_securityhub_standards_control_association",
        "aws_securitylake_custom_log_source",
        "aws_securitylake_subscriber",
        "aws_securitylake_subscriber_notification",
        "aws_servicecatalogappregistry_application",
        "aws_servicecatalogappregistry_attribute_group",
        "aws_servicecatalogappregistry_attribute_group_association",
        "aws_sesv2_account_suppression_attributes",
        "aws_sesv2_email_identity_policy",
        "aws_shield_proactive_engagement",
        "aws_shield_subscription",
        "aws_ssmcontacts_rotation",
        "aws_ssmquicksetup_configuration_manager",
        "aws_timestreaminfluxdb_db_instance",
        "aws_timestreamquery_scheduled_query",
        "aws_verifiedpermissions_identity_source",
        "aws_verifiedpermissions_policy",
        "aws_vpc_block_public_access_exclusion",
        "aws_vpc_block_public_access_options",
        "aws_vpc_endpoint_private_dns",
        "aws_vpc_endpoint_service_private_dns_verification",
        "aws_vpc_security_group_vpc_association",
        "aws_vpclattice_resource_configuration",
        "aws_vpclattice_resource_gateway",
        "aws_vpclattice_service_network_resource_association"
    ],
    "gcp": [
        "google_access_context_manager_access_level",
        "google_project_services",
        "google_access_context_manager_access_policy",
        "google_access_context_manager_service_perimeter",
        "google_access_context_manager_service_perimeter_resource",
        "google_app_engine_application",
        "google_app_engine_application_url_dispatch_rules",
        "google_app_engine_domain_mapping",
        "google_app_engine_firewall_rule",
        "google_app_engine_flexible_app_version",
        "google_app_engine_service_split_traffic",
        "google_app_engine_standard_app_version",
        "google_bigquery_dataset",
        "google_bigquery_dataset_access",
        "google_bigquery_dataset_iam",
        "google_bigquery_job",
        "google_bigquery_table",
        "google_bigquery_data_transfer_config",
        "google_binary_authorization_attestor",
        "google_binary_authorization_attestor_iam",
        "google_binary_authorization_policy",
        "google_logging_billing_account_bucket_config",
        "google_logging_billing_account_exclusion",
        "google_logging_billing_account_sink",
        "google_logging_folder_bucket_config",
        "google_logging_folder_exclusion",
        "google_logging_folder_sink",
        "google_logging_metric",
        "google_logging_organization_bucket_config",
        "google_logging_organization_exclusion",
        "google_logging_organization_sink",
        "google_logging_project_bucket_config",
        "google_logging_project_exclusion",
        "google_logging_project_sink",
        "google_monitoring_alert_policy",
        "google_monitoring_dashboard",
        "google_monitoring_group",
        "google_monitoring_metric_descriptor",
        "google_monitoring_notification_channel",
        "google_monitoring_service",
        "google_monitoring_slo",
        "google_monitoring_uptime_check_config",
        "google_cloud_asset_folder_feed",
        "google_cloud_asset_organization_feed",
        "google_cloud_asset_project_feed",
        "google_bigtable_app_profile",
        "google_bigtable_gc_policy",
        "google_bigtable_instance",
        "google_bigtable_instance_iam",
        "google_bigtable_table",
        "google_cloudbuild_trigger",
        "google_composer_environment",
        "google_dns_managed_zone",
        "google_dns_policy",
        "google_dns_record_set",
        "google_deployment_manager_deployment",
        "google_endpoints_service",
        "google_endpoints_service_iam",
        "google_cloudfunctions_cloud_function_iam",
        "google_cloudfunctions_function",
        "google_healthcare_dataset",
        "google_healthcare_dataset_iam",
        "google_healthcare_dicom_store",
        "google_healthcare_dicom_store_iam",
        "google_healthcare_fhir_store",
        "google_healthcare_fhir_store_iam",
        "google_healthcare_hl7_v2_store",
        "google_healthcare_hl7_v2_store_iam",
        "google_cloudiot_device",
        "google_cloudiot_device_registry",
        "google_kms_crypto_key_iam",
        "google_kms_key_ring_iam",
        "google_kms_crypto_key",
        "google_kms_key_ring",
        "google_kms_key_ring_import_job",
        "google_kms_secret_ciphertext",
        "google_billing_account_iam_binding",
        "google_billing_account_iam_member",
        "google_billing_account_iam_policy",
        "google_folder",
        "google_folder_iam_audit_config",
        "google_folder_iam_binding",
        "google_folder_iam_member",
        "google_folder_iam_policy",
        "google_folder_organization_policy",
        "google_organization_iam_audit_config",
        "google_organization_iam_binding",
        "google_organization_iam_custom_role",
        "google_organization_iam_member",
        "google_organization_iam_policy",
        "google_organization_policy",
        "google_project",
        "google_project_iam_binding",
        "google_project_iam_member",
        "google_project_iam_custom_role",
        "google_project_organization_policy",
        "google_project_service",
        "google_service_account",
        "google_service_account_iam",
        "google_service_account_key",
        "google_usage_export_bucket",
        "google_pubsub_subscription",
        "google_pubsub_subscription_iam",
        "google_pubsub_topic",
        "google_pubsub_topic_iam",
        "google_cloud_run_domain_mapping",
        "google_cloud_run_service",
        "google_cloud_run_service_iam",
        "google_sql_database",
        "google_sql_database_instance",
        "google_sql_source_representation_instance",
        "google_sql_ssl_cert",
        "google_sql_user",
        "google_cloud_scheduler_job",
        "google_sourcerepo_repository",
        "google_sourcerepo_repository_iam",
        "google_spanner_database",
        "google_spanner_database_iam",
        "google_spanner_instance",
        "google_spanner_instance_iam",
        "google_storage_bucket",
        "google_storage_bucket_access_control",
        "google_storage_bucket_acl",
        "google_storage_bucket_iam_binding",
        "google_storage_bucket_iam_member",
        "google_storage_bucket_object",
        "google_storage_default_object_access_control",
        "google_storage_default_object_acl",
        "google_storage_hmac_key",
        "google_storage_notification",
        "google_storage_object_access_control",
        "google_storage_object_acl",
        "google_tpu_node",
        "google_cloud_tasks_queue",
        "google_compute_address",
        "google_compute_attached_disk",
        "google_compute_autoscaler",
        "google_compute_backend_bucket",
        "google_compute_backend_bucket_signed_url_key",
        "google_compute_backend_service",
        "google_compute_backend_service_signed_url_key",
        "google_compute_disk",
        "google_compute_disk_resource_policy_attachment",
        "google_compute_firewall",
        "google_compute_forwarding_rule",
        "google_compute_global_address",
        "google_compute_global_forwarding_rule",
        "google_compute_global_network_endpoint",
        "google_compute_global_network_endpoint_group",
        "google_compute_health_check",
        "google_compute_http_health_check",
        "google_compute_https_health_check",
        "google_compute_image",
        "google_compute_instance",
        "google_compute_instance_from_template",
        "google_compute_instance_group",
        "google_compute_instance_group_manager",
        "google_compute_instance_group_named_port",
        "google_compute_instance_iam",
        "google_compute_instance_template",
        "google_compute_interconnect_attachment",
        "google_compute_network",
        "google_compute_network_endpoint",
        "google_compute_network_endpoint_group",
        "google_compute_network_peering",
        "google_compute_network_peering_routes_config",
        "google_compute_node_group",
        "google_compute_node_template",
        "google_compute_project_default_network_tier",
        "google_compute_project_metadata",
        "google_compute_project_metadata_item",
        "google_compute_region_autoscaler",
        "google_compute_region_backend_service",
        "google_compute_region_disk",
        "google_compute_region_disk_resource_policy_attachment",
        "google_compute_region_health_check",
        "google_compute_region_instance_group_manager",
        "google_compute_region_ssl_certificate",
        "google_compute_region_target_http_proxy",
        "google_compute_region_target_https_proxy",
        "google_compute_region_url_map",
        "google_compute_reservation",
        "google_compute_resource_policy",
        "google_compute_route",
        "google_compute_router",
        "google_compute_router_bgp_peer",
        "google_compute_router_interface",
        "google_compute_router_nat",
        "google_compute_security_policy",
        "google_compute_shared_vpc_host_project",
        "google_compute_shared_vpc_service_project",
        "google_compute_snapshot",
        "google_compute_ssl_certificate",
        "google_compute_ssl_policy",
        "google_compute_subnetwork",
        "google_compute_subnetwork_iam",
        "google_compute_target_http_proxy",
        "google_compute_target_https_proxy",
        "google_compute_target_instance",
        "google_compute_target_pool",
        "google_compute_target_ssl_proxy",
        "google_compute_target_tcp_proxy",
        "google_compute_url_map",
        "google_compute_vpn_gateway",
        "google_compute_vpn_tunnel",
        "google_container_analysis_note",
        "google_container_analysis_occurrence",
        "google_container_registry",
        "google_data_catalog_entry",
        "google_data_catalog_entry_group",
        "google_data_catalog_entry_group_iam",
        "google_data_catalog_tag",
        "google_data_catalog_tag_template",
        "google_dataflow_job",
        "google_dataproc_autoscaling_policy",
        "google_dataproc_cluster",
        "google_dataproc_cluster_iam",
        "google_dataproc_job",
        "google_dataproc_job_iam",
        "google_datastore_index",
        "google_dialogflow_agent",
        "google_dialogflow_entity_type",
        "google_dialogflow_intent",
        "google_filestore_instance",
        "google_firestore_index",
        "google_identity_platform_default_supported_idp_config",
        "google_identity_platform_inbound_saml_config",
        "google_identity_platform_oauth_idp_config",
        "google_identity_platform_tenant",
        "google_identity_platform_tenant_default_supported_idp_config",
        "google_identity_platform_tenant_inbound_saml_config",
        "google_identity_platform_tenant_oauth_idp_config",
        "google_iap_app_engine_service_iam",
        "google_iap_app_engine_version_iam",
        "google_iap_brand",
        "google_iap_client",
        "google_iap_tunnel_instance_iam",
        "google_iap_web_backend_service_iam",
        "google_iap_web_iam",
        "google_iap_web_type_app_engine_iam",
        "google_iap_web_type_compute_iam",
        "google_container_cluster",
        "google_container_node_pool",
        "google_ml_engine_model",
        "google_redis_instance",
        "google_network_management_connectivity_test_resource",
        "google_os_config_patch_deployment",
        "google_os_login_ssh_public_key",
        "google_resource_manager_lien",
        "google_runtimeconfig_config",
        "google_runtimeconfig_config_iam",
        "google_runtimeconfig_variable",
        "google_secret_manager_secret",
        "google_secret_manager_secret_iam",
        "google_secret_manager_secret_version",
        "google_scc_source",
        "google_vpc_access_connector",
        "google_service_networking_connection",
        "google_storage_transfer_job",
        "google_project_iam",
        "google_storage_bucket_iam",
        "google_dataflow_flex_template_job",
        "google_active_directory_domain",
        "google_access_context_manager_access_level_condition",
        "google_access_context_manager_access_levels",
        "google_access_context_manager_gcp_user_access_binding",
        "google_access_context_manager_service_perimeters",
        "google_active_directory_domain_trust",
        "google_apigee_organization",
        "google_bigquery_dataset_iam_binding",
        "google_bigquery_dataset_iam_member",
        "google_bigquery_dataset_iam_policy",
        "google_bigquery_reservation",
        "google_bigquery_routine",
        "google_bigquery_table_iam_binding",
        "google_bigquery_table_iam_member",
        "google_bigquery_table_iam_policy",
        "google_bigtable_instance_iam_binding",
        "google_bigtable_instance_iam_member",
        "google_bigtable_instance_iam_policy",
        "google_bigtable_table_iam_binding",
        "google_bigtable_table_iam_member",
        "google_bigtable_table_iam_policy",
        "google_billing_budget",
        "google_billing_subaccount",
        "google_binary_authorization_attestor_iam_binding",
        "google_binary_authorization_attestor_iam_member",
        "google_binary_authorization_attestor_iam_policy",
        "google_cloud_identity_group",
        "google_cloud_identity_group_membership",
        "google_cloud_run_service_iam_binding",
        "google_cloud_run_service_iam_member",
        "google_cloud_run_service_iam_policy",
        "google_cloudfunctions_function_iam_binding",
        "google_cloudfunctions_function_iam_member",
        "google_cloudfunctions_function_iam_policy",
        "google_cloudiot_registry",
        "google_compute_disk_iam_binding",
        "google_compute_disk_iam_member",
        "google_compute_disk_iam_policy",
        "google_compute_external_vpn_gateway",
        "google_compute_ha_vpn_gateway",
        "google_compute_image_iam_binding",
        "google_compute_image_iam_member",
        "google_compute_image_iam_policy",
        "google_compute_instance_iam_binding",
        "google_compute_instance_iam_member",
        "google_compute_instance_iam_policy",
        "google_compute_managed_ssl_certificate",
        "google_compute_packet_mirroring",
        "google_compute_per_instance_config",
        "google_compute_region_disk_iam_binding",
        "google_compute_region_disk_iam_member",
        "google_compute_region_disk_iam_policy",
        "google_compute_region_network_endpoint_group",
        "google_compute_region_per_instance_config",
        "google_compute_router_peer",
        "google_compute_subnetwork_iam_binding",
        "google_compute_subnetwork_iam_member",
        "google_compute_subnetwork_iam_policy",
        "google_compute_target_grpc_proxy",
        "google_data_catalog_entry_group_iam_binding",
        "google_data_catalog_entry_group_iam_member",
        "google_data_catalog_entry_group_iam_policy",
        "google_data_loss_prevention_deidentify_template",
        "google_data_loss_prevention_inspect_template",
        "google_data_loss_prevention_job_trigger",
        "google_data_loss_prevention_stored_info_type",
        "google_dataproc_cluster_iam_binding",
        "google_dataproc_cluster_iam_member",
        "google_dataproc_cluster_iam_policy",
        "google_dataproc_job_iam_binding",
        "google_dataproc_job_iam_member",
        "google_dataproc_job_iam_policy",
        "google_endpoints_service_iam_binding",
        "google_endpoints_service_iam_member",
        "google_endpoints_service_iam_policy",
        "google_firestore_document",
        "google_folder_access_approval_settings",
        "google_game_services_game_server_cluster",
        "google_game_services_game_server_config",
        "google_game_services_game_server_deployment",
        "google_game_services_game_server_deployment_rollout",
        "google_game_services_realm",
        "google_healthcare_dataset_iam_binding",
        "google_healthcare_dataset_iam_member",
        "google_healthcare_dataset_iam_policy",
        "google_healthcare_dicom_store_iam_binding",
        "google_healthcare_dicom_store_iam_member",
        "google_healthcare_dicom_store_iam_policy",
        "google_healthcare_fhir_store_iam_binding",
        "google_healthcare_fhir_store_iam_member",
        "google_healthcare_fhir_store_iam_policy",
        "google_healthcare_hl7_v2_store_iam_binding",
        "google_healthcare_hl7_v2_store_iam_member",
        "google_healthcare_hl7_v2_store_iam_policy",
        "google_iap_app_engine_service_iam_binding",
        "google_iap_app_engine_service_iam_member",
        "google_iap_app_engine_service_iam_policy",
        "google_iap_app_engine_version_iam_binding",
        "google_iap_app_engine_version_iam_member",
        "google_iap_app_engine_version_iam_policy",
        "google_iap_tunnel_iam_binding",
        "google_iap_tunnel_iam_member",
        "google_iap_tunnel_iam_policy",
        "google_iap_tunnel_instance_iam_binding",
        "google_iap_tunnel_instance_iam_member",
        "google_iap_tunnel_instance_iam_policy",
        "google_iap_web_backend_service_iam_binding",
        "google_iap_web_backend_service_iam_member",
        "google_iap_web_backend_service_iam_policy",
        "google_iap_web_iam_binding",
        "google_iap_web_iam_member",
        "google_iap_web_iam_policy",
        "google_iap_web_type_app_engine_iam_binding",
        "google_iap_web_type_app_engine_iam_member",
        "google_iap_web_type_app_engine_iam_policy",
        "google_iap_web_type_compute_iam_binding",
        "google_iap_web_type_compute_iam_member",
        "google_iap_web_type_compute_iam_policy",
        "google_kms_crypto_key_iam_binding",
        "google_kms_crypto_key_iam_member",
        "google_kms_crypto_key_iam_policy",
        "google_kms_key_ring_iam_binding",
        "google_kms_key_ring_iam_member",
        "google_kms_key_ring_iam_policy",
        "google_monitoring_custom_service",
        "google_network_management_connectivity_test",
        "google_notebooks_environment",
        "google_notebooks_instance",
        "google_notebooks_instance_iam_binding",
        "google_notebooks_instance_iam_member",
        "google_notebooks_instance_iam_policy",
        "google_notebooks_location",
        "google_organization_access_approval_settings",
        "google_project_access_approval_settings",
        "google_project_default_service_accounts",
        "google_project_iam_audit_config",
        "google_project_iam_policy",
        "google_project_usage_export_bucket",
        "google_pubsub_lite_subscription",
        "google_pubsub_lite_topic",
        "google_pubsub_subscription_iam_binding",
        "google_pubsub_subscription_iam_member",
        "google_pubsub_subscription_iam_policy",
        "google_pubsub_topic_iam_binding",
        "google_pubsub_topic_iam_member",
        "google_pubsub_topic_iam_policy",
        "google_runtimeconfig_config_iam_binding",
        "google_runtimeconfig_config_iam_member",
        "google_runtimeconfig_config_iam_policy",
        "google_secret_manager_secret_iam_binding",
        "google_secret_manager_secret_iam_member",
        "google_secret_manager_secret_iam_policy",
        "google_service_account_iam_binding",
        "google_service_account_iam_member",
        "google_service_account_iam_policy",
        "google_sourcerepo_repository_iam_binding",
        "google_sourcerepo_repository_iam_member",
        "google_sourcerepo_repository_iam_policy",
        "google_spanner_database_iam_binding",
        "google_spanner_database_iam_member",
        "google_spanner_database_iam_policy",
        "google_spanner_instance_iam_binding",
        "google_spanner_instance_iam_member",
        "google_spanner_instance_iam_policy",
        "google_storage_bucket_iam_policy",
        "google_apigee_envgroup",
        "google_apigee_envgroup_attachment",
        "google_apigee_environment",
        "google_apigee_instance",
        "google_apigee_instance_attachment",
        "google_data_catalog_tag_template_iam_binding",
        "google_data_catalog_tag_template_iam_member",
        "google_data_catalog_tag_template_iam_policy",
        "google_eventarc_trigger",
        "google_healthcare_consent_store",
        "google_healthcare_consent_store_iam_binding",
        "google_healthcare_consent_store_iam_member",
        "google_healthcare_consent_store_iam_policy",
        "google_tags_tag_binding",
        "google_tags_tag_key",
        "google_tags_tag_key_iam_binding",
        "google_tags_tag_key_iam_member",
        "google_tags_tag_key_iam_policy",
        "google_tags_tag_value",
        "google_tags_tag_value_iam_binding",
        "google_tags_tag_value_iam_member",
        "google_tags_tag_value_iam_policy",
        "google_workflows_workflow",
        "google_apigee_environment_iam_binding",
        "google_apigee_environment_iam_member",
        "google_apigee_environment_iam_policy",
        "google_app_engine_service_network_settings",
        "google_assured_workloads_workload",
        "google_cloudbuild_worker_pool",
        "google_compute_firewall_policy",
        "google_compute_firewall_policy_association",
        "google_compute_firewall_policy_rule",
        "google_compute_service_attachment",
        "google_container_aws_cluster",
        "google_container_aws_node_pool",
        "google_container_azure_client",
        "google_container_azure_cluster",
        "google_container_azure_node_pool",
        "google_dataproc_workflow_template",
        "google_dialogflow_cx_agent",
        "google_dialogflow_cx_entity_type",
        "google_dialogflow_cx_environment",
        "google_dialogflow_cx_flow",
        "google_dialogflow_cx_intent",
        "google_dialogflow_cx_page",
        "google_dialogflow_cx_version",
        "google_dialogflow_fulfillment",
        "google_essential_contacts_contact",
        "google_gke_hub_membership",
        "google_memcache_instance",
        "google_network_services_edge_cache_keyset",
        "google_network_services_edge_cache_origin",
        "google_network_services_edge_cache_service",
        "google_notebooks_runtime",
        "google_notebooks_runtime_iam_binding",
        "google_notebooks_runtime_iam_member",
        "google_notebooks_runtime_iam_policy",
        "google_org_policy_policy",
        "google_os_config_os_policy_assignment",
        "google_privateca_ca_pool",
        "google_privateca_ca_pool_iam_binding",
        "google_privateca_ca_pool_iam_member",
        "google_privateca_ca_pool_iam_policy",
        "google_privateca_certificate",
        "google_privateca_certificate_authority",
        "google_privateca_certificate_template",
        "google_pubsub_lite_reservation",
        "google_pubsub_schema",
        "google_recaptcha_enterprise_key",
        "google_scc_notification_config",
        "google_service_networking_peered_dns_domain",
        "google_vertex_ai_dataset",
        "google_access_context_manager_access_policy_iam_binding",
        "google_access_context_manager_access_policy_iam_member",
        "google_access_context_manager_access_policy_iam_policy",
        "google_apigee_endpoint_attachment",
        "google_apikeys_key",
        "google_artifact_registry_repository",
        "google_artifact_registry_repository_iam_binding",
        "google_artifact_registry_repository_iam_member",
        "google_artifact_registry_repository_iam_policy",
        "google_bigquery_connection",
        "google_bigquery_connection_iam_binding",
        "google_bigquery_connection_iam_member",
        "google_bigquery_connection_iam_policy",
        "google_bigquery_reservation_assignment",
        "google_certificate_manager_certificate",
        "google_certificate_manager_certificate_map",
        "google_certificate_manager_certificate_map_entry",
        "google_certificate_manager_dns_authorization",
        "google_cloud_tasks_queue_iam_binding",
        "google_cloud_tasks_queue_iam_member",
        "google_cloud_tasks_queue_iam_policy",
        "google_clouddeploy_delivery_pipeline",
        "google_clouddeploy_target",
        "google_cloudiot_registry_iam_binding",
        "google_cloudiot_registry_iam_member",
        "google_cloudiot_registry_iam_policy",
        "google_compute_snapshot_iam_binding",
        "google_compute_snapshot_iam_member",
        "google_compute_snapshot_iam_policy",
        "google_data_fusion_instance",
        "google_dataplex_lake",
        "google_dataproc_autoscaling_policy_iam_binding",
        "google_dataproc_autoscaling_policy_iam_member",
        "google_dataproc_autoscaling_policy_iam_policy",
        "google_dataproc_metastore_service",
        "google_dataproc_metastore_service_iam_binding",
        "google_dataproc_metastore_service_iam_member",
        "google_dataproc_metastore_service_iam_policy",
        "google_document_ai_processor",
        "google_document_ai_processor_default_version",
        "google_endpoints_service_consumers_iam_binding",
        "google_endpoints_service_consumers_iam_member",
        "google_endpoints_service_consumers_iam_policy",
        "google_firebaserules_release",
        "google_firebaserules_ruleset",
        "google_iam_workload_identity_pool",
        "google_iam_workload_identity_pool_provider",
        "google_logging_log_view",
        "google_monitoring_monitored_project",
        "google_network_connectivity_hub",
        "google_network_connectivity_spoke",
        "google_privateca_certificate_template_iam_binding",
        "google_privateca_certificate_template_iam_member",
        "google_privateca_certificate_template_iam_policy",
        "google_vertex_ai_metadata_store",
        "google_apigee_nat_address",
        "google_beyondcorp_app_connector",
        "google_beyondcorp_app_gateway",
        "google_bigquery_analytics_hub_data_exchange",
        "google_bigquery_analytics_hub_data_exchange_iam_binding",
        "google_bigquery_analytics_hub_data_exchange_iam_member",
        "google_bigquery_analytics_hub_data_exchange_iam_policy",
        "google_bigquery_analytics_hub_listing",
        "google_bigquery_analytics_hub_listing_iam_binding",
        "google_bigquery_analytics_hub_listing_iam_member",
        "google_bigquery_analytics_hub_listing_iam_policy",
        "google_cloud_ids_endpoint",
        "google_cloud_run_v2_job",
        "google_cloud_run_v2_service",
        "google_cloudfunctions2_function",
        "google_cloudfunctions2_function_iam_binding",
        "google_cloudfunctions2_function_iam_member",
        "google_cloudfunctions2_function_iam_policy",
        "google_compute_network_firewall_policy",
        "google_compute_network_firewall_policy_association",
        "google_compute_network_firewall_policy_rule",
        "google_compute_region_network_firewall_policy",
        "google_compute_region_network_firewall_policy_association",
        "google_compute_region_network_firewall_policy_rule",
        "google_data_fusion_instance_iam_binding",
        "google_data_fusion_instance_iam_member",
        "google_data_fusion_instance_iam_policy",
        "google_dataplex_asset",
        "google_dataplex_zone",
        "google_datastream_connection_profile",
        "google_datastream_private_connection",
        "google_dialogflow_cx_webhook",
        "google_eventarc_channel",
        "google_eventarc_google_channel_config",
        "google_filestore_backup",
        "google_filestore_snapshot",
        "google_gke_hub_membership_iam_binding",
        "google_gke_hub_membership_iam_member",
        "google_gke_hub_membership_iam_policy",
        "google_identity_platform_config",
        "google_identity_platform_project_default_config",
        "google_kms_crypto_key_version",
        "google_scc_source_iam_binding",
        "google_scc_source_iam_member",
        "google_scc_source_iam_policy",
        "google_storage_transfer_agent_pool",
        "google_vertex_ai_endpoint",
        "google_vertex_ai_featurestore",
        "google_vertex_ai_featurestore_entitytype",
        "google_vertex_ai_featurestore_entitytype_feature",
        "google_vertex_ai_index",
        "google_vertex_ai_tensorboard",
        "google_access_context_manager_authorized_orgs_desc",
        "google_access_context_manager_egress_policy",
        "google_access_context_manager_ingress_policy",
        "google_access_context_manager_service_perimeter_egress_policy",
        "google_access_context_manager_service_perimeter_ingress_policy",
        "google_alloydb_backup",
        "google_alloydb_cluster",
        "google_alloydb_instance",
        "google_alloydb_user",
        "google_apigee_addons_config",
        "google_apigee_env_keystore",
        "google_apigee_env_references",
        "google_apigee_flowhook",
        "google_apigee_keystores_aliases_key_cert_file",
        "google_apigee_keystores_aliases_pkcs12",
        "google_apigee_keystores_aliases_self_signed_cert",
        "google_apigee_sharedflow",
        "google_apigee_sharedflow_deployment",
        "google_apigee_sync_authorization",
        "google_apigee_target_server",
        "google_beyondcorp_app_connection",
        "google_biglake_catalog",
        "google_biglake_database",
        "google_biglake_table",
        "google_bigquery_bi_reservation",
        "google_bigquery_capacity_commitment",
        "google_bigquery_datapolicy_data_policy",
        "google_bigquery_datapolicy_data_policy_iam_binding",
        "google_bigquery_datapolicy_data_policy_iam_member",
        "google_bigquery_datapolicy_data_policy_iam_policy",
        "google_billing_project_info",
        "google_certificate_manager_certificate_issuance_config",
        "google_certificate_manager_trust_config",
        "google_cloud_run_v2_job_iam_binding",
        "google_cloud_run_v2_job_iam_member",
        "google_cloud_run_v2_job_iam_policy",
        "google_cloud_run_v2_service_iam_binding",
        "google_cloud_run_v2_service_iam_member",
        "google_cloud_run_v2_service_iam_policy",
        "google_cloudbuild_bitbucket_server_config",
        "google_cloudbuildv2_connection",
        "google_cloudbuildv2_connection_iam_binding",
        "google_cloudbuildv2_connection_iam_member",
        "google_cloudbuildv2_connection_iam_policy",
        "google_cloudbuildv2_repository",
        "google_clouddomains_registration",
        "google_compute_disk_async_replication",
        "google_compute_network_endpoints",
        "google_compute_public_advertised_prefix",
        "google_compute_public_delegated_prefix",
        "google_compute_region_commitment",
        "google_compute_region_instance_template",
        "google_compute_region_ssl_policy",
        "google_compute_region_target_tcp_proxy",
        "google_container_analysis_note_iam_binding",
        "google_container_analysis_note_iam_member",
        "google_container_analysis_note_iam_policy",
        "google_container_attached_cluster",
        "google_data_catalog_policy_tag",
        "google_data_catalog_policy_tag_iam_binding",
        "google_data_catalog_policy_tag_iam_member",
        "google_data_catalog_policy_tag_iam_policy",
        "google_data_catalog_taxonomy",
        "google_data_catalog_taxonomy_iam_binding",
        "google_data_catalog_taxonomy_iam_member",
        "google_data_catalog_taxonomy_iam_policy",
        "google_data_pipeline_pipeline",
        "google_database_migration_service_connection_profile",
        "google_database_migration_service_private_connection",
        "google_dataplex_asset_iam_binding",
        "google_dataplex_asset_iam_member",
        "google_dataplex_asset_iam_policy",
        "google_dataplex_datascan",
        "google_dataplex_datascan_iam_binding",
        "google_dataplex_datascan_iam_member",
        "google_dataplex_datascan_iam_policy",
        "google_dataplex_lake_iam_binding",
        "google_dataplex_lake_iam_member",
        "google_dataplex_lake_iam_policy",
        "google_dataplex_task",
        "google_dataplex_task_iam_binding",
        "google_dataplex_task_iam_member",
        "google_dataplex_task_iam_policy",
        "google_dataplex_zone_iam_binding",
        "google_dataplex_zone_iam_member",
        "google_dataplex_zone_iam_policy",
        "google_datastream_stream",
        "google_dialogflow_cx_security_settings",
        "google_dialogflow_cx_test_case",
        "google_dns_managed_zone_iam_binding",
        "google_dns_managed_zone_iam_member",
        "google_dns_managed_zone_iam_policy",
        "google_dns_response_policy",
        "google_dns_response_policy_rule",
        "google_document_ai_warehouse_document_schema",
        "google_document_ai_warehouse_location",
        "google_edgecontainer_cluster",
        "google_edgecontainer_node_pool",
        "google_edgecontainer_vpn_connection",
        "google_edgenetwork_network",
        "google_edgenetwork_subnet",
        "google_firestore_backup_schedule",
        "google_firestore_database",
        "google_firestore_field",
        "google_gke_backup_backup_plan",
        "google_gke_backup_backup_plan_iam_binding",
        "google_gke_backup_backup_plan_iam_member",
        "google_gke_backup_backup_plan_iam_policy",
        "google_gke_backup_restore_plan",
        "google_gke_backup_restore_plan_iam_binding",
        "google_gke_backup_restore_plan_iam_member",
        "google_gke_backup_restore_plan_iam_policy",
        "google_gke_hub_feature",
        "google_gke_hub_feature_iam_binding",
        "google_gke_hub_feature_iam_member",
        "google_gke_hub_feature_iam_policy",
        "google_gke_hub_feature_membership",
        "google_gke_hub_fleet",
        "google_gke_hub_membership_binding",
        "google_gke_hub_namespace",
        "google_gke_hub_scope",
        "google_gke_hub_scope_iam_binding",
        "google_gke_hub_scope_iam_member",
        "google_gke_hub_scope_iam_policy",
        "google_gke_hub_scope_rbac_role_binding",
        "google_gkeonprem_bare_metal_admin_cluster",
        "google_gkeonprem_bare_metal_cluster",
        "google_gkeonprem_bare_metal_node_pool",
        "google_gkeonprem_vmware_cluster",
        "google_gkeonprem_vmware_node_pool",
        "google_iam_access_boundary_policy",
        "google_iam_deny_policy",
        "google_iam_workforce_pool",
        "google_iam_workforce_pool_provider",
        "google_iap_web_region_backend_service_iam_binding",
        "google_iap_web_region_backend_service_iam_member",
        "google_iap_web_region_backend_service_iam_policy",
        "google_integration_connectors_connection",
        "google_integration_connectors_endpoint_attachment",
        "google_logging_folder_settings",
        "google_logging_linked_dataset",
        "google_logging_organization_settings",
        "google_looker_instance",
        "google_migration_center_group",
        "google_netapp_active_directory",
        "google_netapp_backup_policy",
        "google_netapp_backup_vault",
        "google_netapp_kmsconfig",
        "google_netapp_storage_pool",
        "google_netapp_volume",
        "google_network_connectivity_policy_based_route",
        "google_network_connectivity_service_connection_policy",
        "google_network_security_address_group",
        "google_network_security_address_group_iam_binding",
        "google_network_security_address_group_iam_member",
        "google_network_security_address_group_iam_policy",
        "google_network_security_gateway_security_policy",
        "google_network_security_gateway_security_policy_rule",
        "google_network_security_url_lists",
        "google_network_services_gateway",
        "google_org_policy_custom_constraint",
        "google_public_ca_external_account_key",
        "google_pubsub_schema_iam_binding",
        "google_pubsub_schema_iam_member",
        "google_pubsub_schema_iam_policy",
        "google_redis_cluster",
        "google_scc_event_threat_detection_custom_module",
        "google_scc_folder_custom_module",
        "google_scc_mute_config",
        "google_scc_organization_custom_module",
        "google_scc_project_custom_module",
        "google_secure_source_manager_instance",
        "google_secure_source_manager_instance_iam_binding",
        "google_secure_source_manager_instance_iam_member",
        "google_secure_source_manager_instance_iam_policy",
        "google_storage_insights_report_config",
        "google_tags_location_tag_binding",
        "google_vertex_ai_feature_group",
        "google_vertex_ai_feature_group_feature",
        "google_vertex_ai_feature_online_store",
        "google_vertex_ai_feature_online_store_featureview",
        "google_vertex_ai_index_endpoint",
        "google_vmwareengine_cluster",
        "google_vmwareengine_external_access_rule",
        "google_vmwareengine_external_address",
        "google_vmwareengine_network",
        "google_vmwareengine_network_peering",
        "google_vmwareengine_network_policy",
        "google_vmwareengine_private_cloud",
        "google_vmwareengine_subnet",
        "google_workbench_instance",
        "google_workbench_instance_iam_binding",
        "google_workbench_instance_iam_member",
        "google_workbench_instance_iam_policy",
        "google_iam_policy",
        "google_tpu_v2_vm",
        "google_access_context_manager_service_perimeter_dry_run_egress_policy",
        "google_access_context_manager_service_perimeter_dry_run_ingress_policy",
        "google_access_context_manager_service_perimeter_dry_run_resource",
        "google_apigee_api",
        "google_apigee_app_group",
        "google_apigee_developer",
        "google_apigee_environment_addons_config",
        "google_apigee_environment_keyvaluemaps",
        "google_apigee_environment_keyvaluemaps_entries",
        "google_apihub_api_hub_instance",
        "google_apphub_application",
        "google_apphub_service",
        "google_apphub_service_project_attachment",
        "google_apphub_workload",
        "google_backup_dr_backup_vault",
        "google_beyondcorp_security_gateway",
        "google_beyondcorp_security_gateway_iam_binding",
        "google_beyondcorp_security_gateway_iam_member",
        "google_beyondcorp_security_gateway_iam_policy",
        "google_bigtable_authorized_view",
        "google_blockchain_node_engine_blockchain_nodes",
        "google_cloud_quotas_quota_preference",
        "google_clouddeploy_automation",
        "google_clouddeploy_custom_target_type",
        "google_clouddeploy_custom_target_type_iam_binding",
        "google_clouddeploy_custom_target_type_iam_member",
        "google_clouddeploy_custom_target_type_iam_policy",
        "google_clouddeploy_delivery_pipeline_iam_binding",
        "google_clouddeploy_delivery_pipeline_iam_member",
        "google_clouddeploy_delivery_pipeline_iam_policy",
        "google_clouddeploy_target_iam_binding",
        "google_clouddeploy_target_iam_member",
        "google_clouddeploy_target_iam_policy",
        "google_colab_runtime",
        "google_colab_runtime_template",
        "google_colab_runtime_template_iam_binding",
        "google_colab_runtime_template_iam_member",
        "google_colab_runtime_template_iam_policy",
        "google_composer_user_workloads_config_map",
        "google_composer_user_workloads_secret",
        "google_compute_instance_group_membership",
        "google_compute_instance_settings",
        "google_compute_instance_template_iam_binding",
        "google_compute_instance_template_iam_member",
        "google_compute_instance_template_iam_policy",
        "google_compute_interconnect",
        "google_compute_network_attachment",
        "google_compute_project_cloud_armor_tier",
        "google_compute_region_network_endpoint",
        "google_compute_resize_request",
        "google_compute_router_nat_address",
        "google_compute_security_policy_rule",
        "google_data_loss_prevention_discovery_config",
        "google_database_migration_service_migration_job",
        "google_dataplex_aspect_type",
        "google_dataplex_aspect_type_iam_binding",
        "google_dataplex_aspect_type_iam_member",
        "google_dataplex_aspect_type_iam_policy",
        "google_dataplex_entry_group",
        "google_dataplex_entry_group_iam_binding",
        "google_dataplex_entry_group_iam_member",
        "google_dataplex_entry_group_iam_policy",
        "google_dataplex_entry_type",
        "google_dataplex_entry_type_iam_binding",
        "google_dataplex_entry_type_iam_member",
        "google_dataplex_entry_type_iam_policy",
        "google_dataproc_batch",
        "google_dataproc_gdc_application_environment",
        "google_dataproc_gdc_service_instance",
        "google_dataproc_gdc_spark_application",
        "google_dataproc_metastore_federation",
        "google_dataproc_metastore_federation_iam_binding",
        "google_dataproc_metastore_federation_iam_member",
        "google_dataproc_metastore_federation_iam_policy",
        "google_developer_connect_connection",
        "google_developer_connect_git_repository_link",
        "google_discovery_engine_chat_engine",
        "google_discovery_engine_data_store",
        "google_discovery_engine_schema",
        "google_discovery_engine_search_engine",
        "google_discovery_engine_target_site",
        "google_edgenetwork_interconnect_attachment",
        "google_firebase_app_check_app_attest_config",
        "google_firebase_app_check_debug_token",
        "google_firebase_app_check_device_check_config",
        "google_firebase_app_check_play_integrity_config",
        "google_firebase_app_check_recaptcha_enterprise_config",
        "google_firebase_app_check_recaptcha_v3_config",
        "google_firebase_app_check_service_config",
        "google_gemini_code_repository_index",
        "google_gemini_repository_group",
        "google_gemini_repository_group_iam_binding",
        "google_gemini_repository_group_iam_member",
        "google_gemini_repository_group_iam_policy",
        "google_healthcare_pipeline_job",
        "google_healthcare_workspace",
        "google_iam_folders_policy_binding",
        "google_iam_organizations_policy_binding",
        "google_iam_principal_access_boundary_policy",
        "google_iam_projects_policy_binding",
        "google_iap_settings",
        "google_iap_tunnel_dest_group",
        "google_iap_tunnel_dest_group_iam_binding",
        "google_iap_tunnel_dest_group_iam_member",
        "google_iap_tunnel_dest_group_iam_policy",
        "google_integration_connectors_managed_zone",
        "google_integrations_auth_config",
        "google_integrations_client",
        "google_kms_ekm_connection",
        "google_kms_ekm_connection_iam_binding",
        "google_kms_ekm_connection_iam_member",
        "google_kms_ekm_connection_iam_policy",
        "google_logging_log_scope",
        "google_logging_log_view_iam_binding",
        "google_logging_log_view_iam_member",
        "google_logging_log_view_iam_policy",
        "google_managed_kafka_cluster",
        "google_managed_kafka_topic",
        "google_memorystore_instance",
        "google_migration_center_preference_set",
        "google_netapp_backup",
        "google_netapp_volume_replication",
        "google_netapp_volume_snapshot",
        "google_network_connectivity_group",
        "google_network_connectivity_internal_range",
        "google_network_connectivity_regional_endpoint",
        "google_network_management_vpc_flow_logs_config",
        "google_network_security_authz_policy",
        "google_network_security_client_tls_policy",
        "google_network_security_firewall_endpoint",
        "google_network_security_firewall_endpoint_association",
        "google_network_security_security_profile",
        "google_network_security_security_profile_group",
        "google_network_security_server_tls_policy",
        "google_network_security_tls_inspection_policy",
        "google_network_services_authz_extension",
        "google_network_services_lb_route_extension",
        "google_network_services_lb_traffic_extension",
        "google_oracle_database_autonomous_database",
        "google_oracle_database_cloud_exadata_infrastructure",
        "google_oracle_database_cloud_vm_cluster",
        "google_parallelstore_instance",
        "google_privileged_access_manager_entitlement",
        "google_project_iam_member_remove",
        "google_redis_cluster_user_created_connections",
        "google_scc_folder_notification_config",
        "google_scc_folder_scc_big_query_export",
        "google_scc_management_folder_security_health_analytics_custom_module",
        "google_scc_management_organization_event_threat_detection_custom_module",
        "google_scc_management_organization_security_health_analytics_custom_module",
        "google_scc_management_project_security_health_analytics_custom_module",
        "google_scc_organization_scc_big_query_export",
        "google_scc_project_notification_config",
        "google_scc_project_scc_big_query_export",
        "google_scc_v2_folder_mute_config",
        "google_scc_v2_folder_notification_config",
        "google_scc_v2_folder_scc_big_query_export",
        "google_scc_v2_organization_mute_config",
        "google_scc_v2_organization_notification_config",
        "google_scc_v2_organization_scc_big_query_export",
        "google_scc_v2_organization_scc_big_query_exports",
        "google_scc_v2_organization_source",
        "google_scc_v2_organization_source_iam_binding",
        "google_scc_v2_organization_source_iam_member",
        "google_scc_v2_organization_source_iam_policy",
        "google_scc_v2_project_mute_config",
        "google_scc_v2_project_notification_config",
        "google_scc_v2_project_scc_big_query_export",
        "google_secret_manager_regional_secret",
        "google_secret_manager_regional_secret_iam_binding",
        "google_secret_manager_regional_secret_iam_member",
        "google_secret_manager_regional_secret_iam_policy",
        "google_secret_manager_regional_secret_version",
        "google_secure_source_manager_branch_rule",
        "google_secure_source_manager_repository",
        "google_secure_source_manager_repository_iam_binding",
        "google_secure_source_manager_repository_iam_member",
        "google_secure_source_manager_repository_iam_policy",
        "google_securityposture_posture",
        "google_securityposture_posture_deployment",
        "google_service_networking_vpc_service_controls",
        "google_site_verification_owner",
        "google_site_verification_web_resource",
        "google_spanner_backup_schedule",
        "google_spanner_instance_config",
        "google_storage_folder",
        "google_storage_managed_folder",
        "google_storage_managed_folder_iam_binding",
        "google_storage_managed_folder_iam_member",
        "google_storage_managed_folder_iam_policy",
        "google_transcoder_job",
        "google_transcoder_job_template",
        "google_vertex_ai_deployment_resource_pool",
        "google_vertex_ai_index_endpoint_deployed_index"
    ],
    "azure": [
        "azurerm_api_management",
        "azurerm_api_management_api",
        "azurerm_api_management_api_operation",
        "azurerm_api_management_api_operation_policy",
        "azurerm_api_management_api_policy",
        "azurerm_api_management_api_schema",
        "azurerm_api_management_api_version_set",
        "azurerm_api_management_authorization_server",
        "azurerm_api_management_backend",
        "azurerm_api_management_certificate",
        "azurerm_api_management_diagnostic",
        "azurerm_api_management_group",
        "azurerm_api_management_group_user",
        "azurerm_api_management_identity_provider_aad",
        "azurerm_api_management_identity_provider_facebook",
        "azurerm_api_management_identity_provider_google",
        "azurerm_api_management_identity_provider_microsoft",
        "azurerm_api_management_identity_provider_twitter",
        "azurerm_api_management_logger",
        "azurerm_api_management_named_value",
        "azurerm_api_management_openid_connect_provider",
        "azurerm_api_management_product",
        "azurerm_api_management_product_api",
        "azurerm_api_management_product_group",
        "azurerm_api_management_product_policy",
        "azurerm_api_management_property",
        "azurerm_api_management_subscription",
        "azurerm_api_management_user",
        "azurerm_analysis_services_server",
        "azurerm_app_configuration",
        "azurerm_app_service",
        "azurerm_app_service_active_slot",
        "azurerm_app_service_certificate",
        "azurerm_app_service_certificate_order",
        "azurerm_app_service_custom_hostname_binding",
        "azurerm_app_service_environment",
        "azurerm_app_service_hybrid_connection",
        "azurerm_app_service_plan",
        "azurerm_app_service_slot",
        "azurerm_app_service_slot_virtual_network_swift_connection",
        "azurerm_app_service_source_control_token",
        "azurerm_app_service_virtual_network_swift_connection",
        "azurerm_function_app",
        "azurerm_function_app_slot",
        "azurerm_application_insights",
        "azurerm_application_insights_analytics_item",
        "azurerm_application_insights_api_key",
        "azurerm_application_insights_web_test",
        "azurerm_role_assignment",
        "azurerm_role_definition",
        "azurerm_user_assigned_identity",
        "azurerm_automation_account",
        "azurerm_automation_certificate",
        "azurerm_automation_connection",
        "azurerm_automation_connection_certificate",
        "azurerm_automation_connection_classic_certificate",
        "azurerm_automation_connection_service_principal",
        "azurerm_automation_credential",
        "azurerm_automation_dsc_configuration",
        "azurerm_automation_dsc_nodeconfiguration",
        "azurerm_automation_job_schedule",
        "azurerm_automation_module",
        "azurerm_automation_runbook",
        "azurerm_automation_schedule",
        "azurerm_automation_variable_bool",
        "azurerm_automation_variable_datetime",
        "azurerm_automation_variable_int",
        "azurerm_automation_variable_string",
        "azurerm_resource_group",
        "azurerm_batch_account",
        "azurerm_batch_application",
        "azurerm_batch_certificate",
        "azurerm_batch_pool",
        "azurerm_blueprint_assignment",
        "azurerm_bot_channel_directline",
        "azurerm_bot_channel_email",
        "azurerm_bot_channel_ms_teams",
        "azurerm_bot_channel_slack",
        "azurerm_bot_channels_registration",
        "azurerm_bot_connection",
        "azurerm_bot_web_app",
        "azurerm_cdn_endpoint",
        "azurerm_cdn_profile",
        "azurerm_cognitive_account",
        "azurerm_availability_set",
        "azurerm_dedicated_host",
        "azurerm_dedicated_host_group",
        "azurerm_disk_encryption_set",
        "azurerm_image",
        "azurerm_linux_virtual_machine",
        "azurerm_linux_virtual_machine_scale_set",
        "azurerm_managed_disk",
        "azurerm_marketplace_agreement",
        "azurerm_orchestrated_virtual_machine_scale_set",
        "azurerm_proximity_placement_group",
        "azurerm_shared_image",
        "azurerm_shared_image_gallery",
        "azurerm_shared_image_version",
        "azurerm_snapshot",
        "azurerm_virtual_machine",
        "azurerm_virtual_machine_data_disk_attachment",
        "azurerm_virtual_machine_extension",
        "azurerm_virtual_machine_scale_set",
        "azurerm_virtual_machine_scale_set_extension",
        "azurerm_windows_virtual_machine",
        "azurerm_windows_virtual_machine_scale_set",
        "azurerm_container_group",
        "azurerm_container_registry",
        "azurerm_container_registry_webhook",
        "azurerm_kubernetes_cluster",
        "azurerm_kubernetes_cluster_node_pool",
        "azurerm_cosmosdb_account",
        "azurerm_cosmosdb_cassandra_keyspace",
        "azurerm_cosmosdb_gremlin_database",
        "azurerm_cosmosdb_gremlin_graph",
        "azurerm_cosmosdb_mongo_collection",
        "azurerm_cosmosdb_mongo_database",
        "azurerm_cosmosdb_sql_container",
        "azurerm_cosmosdb_sql_database",
        "azurerm_cosmosdb_table",
        "azurerm_cost_management_export_resource_group",
        "azurerm_custom_provider",
        "azurerm_dns_a_record",
        "azurerm_dns_aaaa_record",
        "azurerm_dns_caa_record",
        "azurerm_dns_cname_record",
        "azurerm_dns_mx_record",
        "azurerm_dns_ns_record",
        "azurerm_dns_ptr_record",
        "azurerm_dns_srv_record",
        "azurerm_dns_txt_record",
        "azurerm_dns_zone",
        "azurerm_kusto_attached_database_configuration",
        "azurerm_kusto_cluster",
        "azurerm_kusto_cluster_customer_managed_key",
        "azurerm_kusto_cluster_principal_assignment",
        "azurerm_kusto_database",
        "azurerm_kusto_database_principal",
        "azurerm_kusto_database_principal_assignment",
        "azurerm_kusto_eventhub_data_connection",
        "azurerm_data_factory",
        "azurerm_data_factory_dataset_azure_blob",
        "azurerm_data_factory_dataset_cosmosdb_sqlapi",
        "azurerm_data_factory_dataset_delimited_text",
        "azurerm_data_factory_dataset_http",
        "azurerm_data_factory_dataset_json",
        "azurerm_data_factory_dataset_mysql",
        "azurerm_data_factory_dataset_postgresql",
        "azurerm_data_factory_dataset_sql_server_table",
        "azurerm_data_factory_integration_runtime_managed",
        "azurerm_data_factory_integration_runtime_self_hosted",
        "azurerm_data_factory_linked_service_azure_blob_storage",
        "azurerm_data_factory_linked_service_azure_file_storage",
        "azurerm_data_factory_linked_service_azure_function",
        "azurerm_data_factory_linked_service_cosmosdb",
        "azurerm_data_factory_linked_service_data_lake_storage_gen2",
        "azurerm_data_factory_linked_service_key_vault",
        "azurerm_data_factory_linked_service_mysql",
        "azurerm_data_factory_linked_service_postgresql",
        "azurerm_data_factory_linked_service_sftp",
        "azurerm_data_factory_linked_service_sql_server",
        "azurerm_data_factory_linked_service_web",
        "azurerm_data_factory_pipeline",
        "azurerm_data_factory_trigger_schedule",
        "azurerm_data_lake_analytics_account",
        "azurerm_data_lake_analytics_firewall_rule",
        "azurerm_data_lake_store",
        "azurerm_data_lake_store_file",
        "azurerm_data_lake_store_firewall_rule",
        "azurerm_data_share",
        "azurerm_data_share_account",
        "azurerm_data_share_dataset_blob_storage",
        "azurerm_data_share_dataset_data_lake_gen1",
        "azurerm_mariadb_configuration",
        "azurerm_mariadb_database",
        "azurerm_mariadb_firewall_rule",
        "azurerm_mariadb_server",
        "azurerm_mariadb_virtual_network_rule",
        "azurerm_mssql_database",
        "azurerm_mssql_database_vulnerability_assessment_rule_baseline",
        "azurerm_mssql_elasticpool",
        "azurerm_mssql_server",
        "azurerm_mssql_server_security_alert_policy",
        "azurerm_mssql_server_vulnerability_assessment",
        "azurerm_mssql_virtual_machine",
        "azurerm_mysql_active_directory_administrator",
        "azurerm_mysql_configuration",
        "azurerm_mysql_database",
        "azurerm_mysql_firewall_rule",
        "azurerm_mysql_server",
        "azurerm_mysql_virtual_network_rule",
        "azurerm_postgresql_active_directory_administrator",
        "azurerm_postgresql_configuration",
        "azurerm_postgresql_database",
        "azurerm_postgresql_firewall_rule",
        "azurerm_postgresql_server",
        "azurerm_postgresql_virtual_network_rule",
        "azurerm_sql_active_directory_administrator",
        "azurerm_sql_database",
        "azurerm_sql_elasticpool",
        "azurerm_sql_failover_group",
        "azurerm_sql_firewall_rule",
        "azurerm_sql_server",
        "azurerm_sql_virtual_network_rule",
        "azurerm_database_migration_project",
        "azurerm_database_migration_service",
        "azurerm_databricks_workspace",
        "azurerm_dev_test_global_vm_shutdown_schedule",
        "azurerm_dev_test_lab",
        "azurerm_dev_test_linux_virtual_machine",
        "azurerm_dev_test_policy",
        "azurerm_dev_test_schedule",
        "azurerm_dev_test_virtual_network",
        "azurerm_dev_test_windows_virtual_machine",
        "azurerm_devspace_controller",
        "azurerm_hdinsight_hadoop_cluster",
        "azurerm_hdinsight_hbase_cluster",
        "azurerm_hdinsight_interactive_query_cluster",
        "azurerm_hdinsight_kafka_cluster",
        "azurerm_hdinsight_ml_services_cluster",
        "azurerm_hdinsight_rserver_cluster",
        "azurerm_hdinsight_spark_cluster",
        "azurerm_hdinsight_storm_cluster",
        "azurerm_dedicated_hardware_security_module",
        "azurerm_healthcare_service",
        "azurerm_iotcentral_application",
        "azurerm_iothub",
        "azurerm_iothub_consumer_group",
        "azurerm_iothub_dps",
        "azurerm_iothub_dps_certificate",
        "azurerm_iothub_dps_shared_access_policy",
        "azurerm_iothub_shared_access_policy",
        "azurerm_key_vault",
        "azurerm_key_vault_access_policy",
        "azurerm_key_vault_certificate",
        "azurerm_key_vault_certificate_issuer",
        "azurerm_key_vault_key",
        "azurerm_key_vault_secret",
        "azurerm_lb",
        "azurerm_lb_backend_address_pool",
        "azurerm_lb_nat_pool",
        "azurerm_lb_nat_rule",
        "azurerm_lb_outbound_rule",
        "azurerm_lb_probe",
        "azurerm_lb_rule",
        "azurerm_log_analytics_datasource_windows_event",
        "azurerm_log_analytics_datasource_windows_performance_counter",
        "azurerm_log_analytics_linked_service",
        "azurerm_log_analytics_solution",
        "azurerm_log_analytics_workspace",
        "azurerm_logic_app_action_custom",
        "azurerm_logic_app_action_http",
        "azurerm_logic_app_integration_account",
        "azurerm_logic_app_trigger_custom",
        "azurerm_logic_app_trigger_http_request",
        "azurerm_logic_app_trigger_recurrence",
        "azurerm_logic_app_workflow",
        "azurerm_machine_learning_workspace",
        "azurerm_maintenance_assignment_dedicated_host",
        "azurerm_maintenance_assignment_virtual_machine",
        "azurerm_maintenance_configuration",
        "azurerm_managed_application",
        "azurerm_managed_application_definition",
        "azurerm_management_group",
        "azurerm_management_lock",
        "azurerm_maps_account",
        "azurerm_media_services_account",
        "azurerm_eventgrid_domain",
        "azurerm_eventgrid_domain_topic",
        "azurerm_eventgrid_event_subscription",
        "azurerm_eventgrid_topic",
        "azurerm_eventhub",
        "azurerm_eventhub_authorization_rule",
        "azurerm_eventhub_cluster",
        "azurerm_eventhub_consumer_group",
        "azurerm_eventhub_namespace",
        "azurerm_eventhub_namespace_authorization_rule",
        "azurerm_eventhub_namespace_disaster_recovery_config",
        "azurerm_iothub_endpoint_eventhub",
        "azurerm_iothub_endpoint_servicebus_queue",
        "azurerm_iothub_endpoint_servicebus_topic",
        "azurerm_iothub_endpoint_storage_container",
        "azurerm_iothub_fallback_route",
        "azurerm_iothub_route",
        "azurerm_notification_hub",
        "azurerm_notification_hub_authorization_rule",
        "azurerm_notification_hub_namespace",
        "azurerm_relay_hybrid_connection",
        "azurerm_relay_namespace",
        "azurerm_servicebus_namespace",
        "azurerm_servicebus_namespace_authorization_rule",
        "azurerm_servicebus_namespace_network_rule_set",
        "azurerm_servicebus_queue",
        "azurerm_servicebus_queue_authorization_rule",
        "azurerm_servicebus_subscription",
        "azurerm_servicebus_subscription_rule",
        "azurerm_servicebus_topic",
        "azurerm_servicebus_topic_authorization_rule",
        "azurerm_signalr_service",
        "azurerm_spatial_anchors_account",
        "azurerm_monitor_action_group",
        "azurerm_monitor_action_rule_action_group",
        "azurerm_monitor_action_rule_suppression",
        "azurerm_monitor_activity_log_alert",
        "azurerm_monitor_autoscale_setting",
        "azurerm_monitor_diagnostic_setting",
        "azurerm_monitor_log_profile",
        "azurerm_monitor_metric_alert",
        "azurerm_monitor_scheduled_query_rules_alert",
        "azurerm_monitor_scheduled_query_rules_log",
        "azurerm_netapp_account",
        "azurerm_netapp_pool",
        "azurerm_netapp_snapshot",
        "azurerm_netapp_volume",
        "azurerm_application_gateway",
        "azurerm_application_security_group",
        "azurerm_bastion_host",
        "azurerm_express_route_circuit",
        "azurerm_express_route_circuit_authorization",
        "azurerm_express_route_circuit_peering",
        "azurerm_express_route_gateway",
        "azurerm_firewall",
        "azurerm_firewall_application_rule_collection",
        "azurerm_firewall_nat_rule_collection",
        "azurerm_firewall_network_rule_collection",
        "azurerm_frontdoor",
        "azurerm_frontdoor_custom_https_configuration",
        "azurerm_frontdoor_firewall_policy",
        "azurerm_local_network_gateway",
        "azurerm_nat_gateway",
        "azurerm_nat_gateway_public_ip_association",
        "azurerm_network_ddos_protection_plan",
        "azurerm_network_interface",
        "azurerm_network_interface_application_gateway_backend_address_pool_association",
        "azurerm_network_interface_application_security_group_association",
        "azurerm_network_interface_backend_address_pool_association",
        "azurerm_network_interface_nat_rule_association",
        "azurerm_network_interface_security_group_association",
        "azurerm_network_packet_capture",
        "azurerm_network_profile",
        "azurerm_network_security_group",
        "azurerm_network_security_rule",
        "azurerm_network_watcher",
        "azurerm_network_watcher_flow_log",
        "azurerm_packet_capture",
        "azurerm_point_to_site_vpn_gateway",
        "azurerm_private_endpoint",
        "azurerm_private_link_service",
        "azurerm_public_ip",
        "azurerm_public_ip_prefix",
        "azurerm_route",
        "azurerm_route_filter",
        "azurerm_route_table",
        "azurerm_subnet",
        "azurerm_subnet_nat_gateway_association",
        "azurerm_subnet_network_security_group_association",
        "azurerm_subnet_route_table_association",
        "azurerm_traffic_manager_endpoint",
        "azurerm_traffic_manager_profile",
        "azurerm_virtual_hub",
        "azurerm_virtual_hub_connection",
        "azurerm_virtual_network",
        "azurerm_virtual_network_gateway",
        "azurerm_virtual_network_gateway_connection",
        "azurerm_virtual_network_peering",
        "azurerm_virtual_wan",
        "azurerm_vpn_gateway",
        "azurerm_vpn_server_configuration",
        "azurerm_web_application_firewall_policy",
        "azurerm_policy_assignment",
        "azurerm_policy_definition",
        "azurerm_policy_remediation",
        "azurerm_policy_set_definition",
        "azurerm_dashboard",
        "azurerm_powerbi_embedded",
        "azurerm_private_dns_a_record",
        "azurerm_private_dns_aaaa_record",
        "azurerm_private_dns_cname_record",
        "azurerm_private_dns_mx_record",
        "azurerm_private_dns_ptr_record",
        "azurerm_private_dns_srv_record",
        "azurerm_private_dns_txt_record",
        "azurerm_private_dns_zone",
        "azurerm_private_dns_zone_virtual_network_link",
        "azurerm_backup_container_storage_account",
        "azurerm_backup_policy_file_share",
        "azurerm_backup_policy_vm",
        "azurerm_backup_protected_file_share",
        "azurerm_backup_protected_vm",
        "azurerm_recovery_services_vault",
        "azurerm_site_recovery_fabric",
        "azurerm_site_recovery_network_mapping",
        "azurerm_site_recovery_protection_container",
        "azurerm_site_recovery_protection_container_mapping",
        "azurerm_site_recovery_replicated_vm",
        "azurerm_site_recovery_replication_policy",
        "azurerm_redis_cache",
        "azurerm_redis_firewall_rule",
        "azurerm_search_service",
        "azurerm_advanced_threat_protection",
        "azurerm_security_center_contact",
        "azurerm_security_center_subscription_pricing",
        "azurerm_security_center_workspace",
        "azurerm_sentinel_alert_rule_ms_security_incident",
        "azurerm_sentinel_alert_rule_scheduled",
        "azurerm_service_fabric_cluster",
        "azurerm_spring_cloud_app",
        "azurerm_spring_cloud_service",
        "azurerm_hpc_cache",
        "azurerm_hpc_cache_blob_target",
        "azurerm_hpc_cache_nfs_target",
        "azurerm_storage_account",
        "azurerm_storage_account_customer_managed_key",
        "azurerm_storage_account_network_rules",
        "azurerm_storage_blob",
        "azurerm_storage_container",
        "azurerm_storage_data_lake_gen2_filesystem",
        "azurerm_storage_management_policy",
        "azurerm_storage_queue",
        "azurerm_storage_share",
        "azurerm_storage_share_directory",
        "azurerm_storage_table",
        "azurerm_storage_table_entity",
        "azurerm_stream_analytics_function_javascript_udf",
        "azurerm_stream_analytics_job",
        "azurerm_stream_analytics_output_blob",
        "azurerm_stream_analytics_output_eventhub",
        "azurerm_stream_analytics_output_mssql",
        "azurerm_stream_analytics_output_servicebus_queue",
        "azurerm_stream_analytics_output_servicebus_topic",
        "azurerm_stream_analytics_reference_input_blob",
        "azurerm_stream_analytics_stream_input_blob",
        "azurerm_stream_analytics_stream_input_eventhub",
        "azurerm_stream_analytics_stream_input_iothub",
        "azurerm_synapse_workspace",
        "azurerm_template_deployment",
        "azurerm_iot_time_series_insights_access_policy",
        "azurerm_iot_time_series_insights_reference_data_set",
        "azurerm_iot_time_series_insights_standard_environment",
        "azurerm_api_management_api_diagnostic",
        "azurerm_api_management_custom_domain",
        "azurerm_api_management_identity_provider_aadb2c",
        "azurerm_api_management_policy",
        "azurerm_app_service_certificate_binding",
        "azurerm_app_service_managed_certificate",
        "azurerm_application_insights_smart_detection_rule",
        "azurerm_attestation_provider",
        "azurerm_cosmosdb_cassandra_table",
        "azurerm_cosmosdb_sql_stored_procedure",
        "azurerm_data_factory_integration_runtime_azure",
        "azurerm_data_factory_integration_runtime_azure_ssis",
        "azurerm_data_factory_linked_service_azure_sql_database",
        "azurerm_data_factory_linked_service_azure_table_storage",
        "azurerm_data_factory_linked_service_snowflake",
        "azurerm_data_factory_linked_service_synapse",
        "azurerm_data_share_dataset_data_lake_gen2",
        "azurerm_data_share_dataset_kusto_cluster",
        "azurerm_data_share_dataset_kusto_database",
        "azurerm_digital_twins_endpoint_eventgrid",
        "azurerm_digital_twins_endpoint_eventhub",
        "azurerm_digital_twins_endpoint_servicebus",
        "azurerm_digital_twins_instance",
        "azurerm_disk_access",
        "azurerm_eventgrid_system_topic",
        "azurerm_eventgrid_system_topic_event_subscription",
        "azurerm_firewall_policy",
        "azurerm_firewall_policy_rule_collection_group",
        "azurerm_integration_service_environment",
        "azurerm_iot_security_device_group",
        "azurerm_iot_security_solution",
        "azurerm_iot_time_series_insights_gen2_environment",
        "azurerm_iothub_enrichment",
        "azurerm_ip_group",
        "azurerm_lb_backend_address_pool_address",
        "azurerm_lighthouse_assignment",
        "azurerm_lighthouse_definition",
        "azurerm_log_analytics_cluster",
        "azurerm_log_analytics_cluster_customer_managed_key",
        "azurerm_log_analytics_data_export_rule",
        "azurerm_log_analytics_linked_storage_account",
        "azurerm_log_analytics_saved_search",
        "azurerm_log_analytics_storage_insights",
        "azurerm_media_asset",
        "azurerm_media_content_key_policy",
        "azurerm_media_job",
        "azurerm_media_streaming_endpoint",
        "azurerm_media_streaming_locator",
        "azurerm_media_streaming_policy",
        "azurerm_media_transform",
        "azurerm_monitor_smart_detector_alert_rule",
        "azurerm_mssql_database_extended_auditing_policy",
        "azurerm_mssql_server_extended_auditing_policy",
        "azurerm_mysql_server_key",
        "azurerm_network_connection_monitor",
        "azurerm_postgresql_server_key",
        "azurerm_redis_linked_server",
        "azurerm_resource_group_template_deployment",
        "azurerm_resource_provider_registration",
        "azurerm_security_center_auto_provisioning",
        "azurerm_security_center_automation",
        "azurerm_security_center_setting",
        "azurerm_sentinel_alert_rule_fusion",
        "azurerm_service_fabric_mesh_application",
        "azurerm_service_fabric_mesh_local_network",
        "azurerm_service_fabric_mesh_secret",
        "azurerm_service_fabric_mesh_secret_value",
        "azurerm_spring_cloud_active_deployment",
        "azurerm_spring_cloud_certificate",
        "azurerm_spring_cloud_java_deployment",
        "azurerm_ssh_public_key",
        "azurerm_stack_hci_cluster",
        "azurerm_storage_data_lake_gen2_path",
        "azurerm_storage_encryption_scope",
        "azurerm_storage_share_file",
        "azurerm_storage_sync",
        "azurerm_storage_sync_cloud_endpoint",
        "azurerm_storage_sync_group",
        "azurerm_subnet_service_endpoint_storage_policy",
        "azurerm_subscription_template_deployment",
        "azurerm_synapse_firewall_rule",
        "azurerm_synapse_managed_private_endpoint",
        "azurerm_synapse_role_assignment",
        "azurerm_synapse_spark_pool",
        "azurerm_synapse_sql_pool",
        "azurerm_virtual_desktop_application_group",
        "azurerm_virtual_desktop_host_pool",
        "azurerm_virtual_desktop_workspace",
        "azurerm_virtual_desktop_workspace_application_group_association",
        "azurerm_virtual_hub_bgp_connection",
        "azurerm_virtual_hub_ip",
        "azurerm_virtual_hub_route_table",
        "azurerm_virtual_hub_security_partner_provider",
        "azurerm_vpn_gateway_connection",
        "azurerm_vpn_site",
        "azurerm_api_management_email_template",
        "azurerm_communication_service",
        "azurerm_data_factory_dataset_parquet",
        "azurerm_data_factory_linked_service_azure_databricks",
        "azurerm_data_lake_store_virtual_network_rule",
        "azurerm_databox_edge_device",
        "azurerm_databox_edge_order",
        "azurerm_express_route_port",
        "azurerm_hpc_cache_access_policy",
        "azurerm_kusto_eventgrid_data_connection",
        "azurerm_kusto_iothub_data_connection",
        "azurerm_management_group_subscription_association",
        "azurerm_management_group_template_deployment",
        "azurerm_media_live_event",
        "azurerm_media_live_event_output",
        "azurerm_mssql_firewall_rule",
        "azurerm_mssql_virtual_network_rule",
        "azurerm_purview_account",
        "azurerm_redis_enterprise_cluster",
        "azurerm_redis_enterprise_database",
        "azurerm_security_center_assessment",
        "azurerm_security_center_assessment_metadata",
        "azurerm_security_center_assessment_policy",
        "azurerm_security_center_server_vulnerability_assessment",
        "azurerm_sentinel_data_connector_aws_cloud_trail",
        "azurerm_sentinel_data_connector_azure_active_directory",
        "azurerm_sentinel_data_connector_azure_advanced_threat_protection",
        "azurerm_sentinel_data_connector_azure_security_center",
        "azurerm_sentinel_data_connector_microsoft_cloud_app_security",
        "azurerm_sentinel_data_connector_office_365",
        "azurerm_sentinel_data_connector_threat_intelligence",
        "azurerm_spring_cloud_app_mysql_association",
        "azurerm_spring_cloud_app_redis_association",
        "azurerm_spring_cloud_custom_domain",
        "azurerm_subscription",
        "azurerm_tenant_template_deployment",
        "azurerm_vmware_private_cloud",
        "azurerm_aadb2c_directory",
        "azurerm_active_directory_domain_service",
        "azurerm_active_directory_domain_service_replica_set",
        "azurerm_api_management_api_operation_tag",
        "azurerm_api_management_api_release",
        "azurerm_api_management_gateway",
        "azurerm_api_management_gateway_api",
        "azurerm_api_management_notification_recipient_email",
        "azurerm_api_management_notification_recipient_user",
        "azurerm_api_management_redis_cache",
        "azurerm_api_management_tag",
        "azurerm_app_configuration_feature",
        "azurerm_app_configuration_key",
        "azurerm_app_service_environment_v3",
        "azurerm_app_service_public_certificate",
        "azurerm_app_service_slot_custom_hostname_binding",
        "azurerm_automation_webhook",
        "azurerm_batch_job",
        "azurerm_bot_channel_alexa",
        "azurerm_bot_channel_direct_line_speech",
        "azurerm_bot_channel_facebook",
        "azurerm_bot_channel_line",
        "azurerm_bot_channel_sms",
        "azurerm_bot_channel_web_chat",
        "azurerm_bot_service_azure_bot",
        "azurerm_cdn_endpoint_custom_domain",
        "azurerm_cognitive_account_customer_managed_key",
        "azurerm_consumption_budget_management_group",
        "azurerm_consumption_budget_resource_group",
        "azurerm_consumption_budget_subscription",
        "azurerm_container_registry_scope_map",
        "azurerm_container_registry_task",
        "azurerm_container_registry_token",
        "azurerm_cosmosdb_cassandra_cluster",
        "azurerm_cosmosdb_cassandra_datacenter",
        "azurerm_cosmosdb_notebook_workspace",
        "azurerm_cosmosdb_sql_function",
        "azurerm_cosmosdb_sql_trigger",
        "azurerm_data_factory_custom_dataset",
        "azurerm_data_factory_data_flow",
        "azurerm_data_factory_dataset_binary",
        "azurerm_data_factory_dataset_snowflake",
        "azurerm_data_factory_linked_custom_service",
        "azurerm_data_factory_linked_service_azure_search",
        "azurerm_data_factory_linked_service_cosmosdb_mongoapi",
        "azurerm_data_factory_linked_service_kusto",
        "azurerm_data_factory_linked_service_odata",
        "azurerm_data_factory_linked_service_odbc",
        "azurerm_data_factory_managed_private_endpoint",
        "azurerm_data_factory_trigger_blob_event",
        "azurerm_data_factory_trigger_custom_event",
        "azurerm_data_factory_trigger_tumbling_window",
        "azurerm_data_protection_backup_instance_blob_storage",
        "azurerm_data_protection_backup_instance_disk",
        "azurerm_data_protection_backup_instance_postgresql",
        "azurerm_data_protection_backup_policy_blob_storage",
        "azurerm_data_protection_backup_policy_disk",
        "azurerm_data_protection_backup_policy_postgresql",
        "azurerm_data_protection_backup_vault",
        "azurerm_databricks_workspace_customer_managed_key",
        "azurerm_disk_pool",
        "azurerm_eventhub_namespace_customer_managed_key",
        "azurerm_express_route_circuit_connection",
        "azurerm_express_route_connection",
        "azurerm_frontdoor_rules_engine",
        "azurerm_healthbot",
        "azurerm_hpc_cache_blob_nfs_target",
        "azurerm_iot_time_series_insights_event_source_eventhub",
        "azurerm_iot_time_series_insights_event_source_iothub",
        "azurerm_key_vault_managed_hardware_security_module",
        "azurerm_key_vault_managed_storage_account",
        "azurerm_key_vault_managed_storage_account_sas_token_definition",
        "azurerm_kusto_script",
        "azurerm_load_test",
        "azurerm_logic_app_integration_account_agreement",
        "azurerm_logic_app_integration_account_assembly",
        "azurerm_logic_app_integration_account_batch_configuration",
        "azurerm_logic_app_integration_account_certificate",
        "azurerm_logic_app_integration_account_map",
        "azurerm_logic_app_integration_account_partner",
        "azurerm_logic_app_integration_account_schema",
        "azurerm_logic_app_integration_account_session",
        "azurerm_logic_app_standard",
        "azurerm_logz_monitor",
        "azurerm_logz_tag_rule",
        "azurerm_machine_learning_compute_cluster",
        "azurerm_machine_learning_compute_instance",
        "azurerm_machine_learning_inference_cluster",
        "azurerm_machine_learning_synapse_spark",
        "azurerm_maintenance_assignment_virtual_machine_scale_set",
        "azurerm_management_group_policy_assignment",
        "azurerm_maps_creator",
        "azurerm_media_asset_filter",
        "azurerm_monitor_aad_diagnostic_setting",
        "azurerm_monitor_private_link_scope",
        "azurerm_monitor_private_link_scoped_service",
        "azurerm_mssql_failover_group",
        "azurerm_mssql_job_agent",
        "azurerm_mssql_job_credential",
        "azurerm_mssql_server_transparent_data_encryption",
        "azurerm_mysql_flexible_database",
        "azurerm_mysql_flexible_server",
        "azurerm_mysql_flexible_server_configuration",
        "azurerm_mysql_flexible_server_firewall_rule",
        "azurerm_nat_gateway_public_ip_prefix_association",
        "azurerm_netapp_snapshot_policy",
        "azurerm_policy_virtual_machine_configuration_assignment",
        "azurerm_portal_tenant_configuration",
        "azurerm_postgresql_flexible_server",
        "azurerm_postgresql_flexible_server_configuration",
        "azurerm_postgresql_flexible_server_database",
        "azurerm_postgresql_flexible_server_firewall_rule",
        "azurerm_relay_hybrid_connection_authorization_rule",
        "azurerm_relay_namespace_authorization_rule",
        "azurerm_resource_group_cost_management_export",
        "azurerm_resource_group_policy_assignment",
        "azurerm_resource_policy_assignment",
        "azurerm_sentinel_alert_rule_machine_learning_behavior_analytics",
        "azurerm_sentinel_automation_rule",
        "azurerm_sentinel_data_connector_microsoft_defender_advanced_threat_protection",
        "azurerm_sentinel_watchlist",
        "azurerm_service_fabric_managed_cluster",
        "azurerm_servicebus_namespace_disaster_recovery_config",
        "azurerm_signalr_service_network_acl",
        "azurerm_spring_cloud_app_cosmosdb_association",
        "azurerm_sql_managed_database",
        "azurerm_sql_managed_instance",
        "azurerm_sql_managed_instance_active_directory_administrator",
        "azurerm_sql_managed_instance_failover_group",
        "azurerm_static_site",
        "azurerm_static_site_custom_domain",
        "azurerm_storage_blob_inventory_policy",
        "azurerm_storage_disks_pool",
        "azurerm_storage_object_replication",
        "azurerm_stream_analytics_cluster",
        "azurerm_stream_analytics_managed_private_endpoint",
        "azurerm_stream_analytics_output_synapse",
        "azurerm_stream_analytics_output_table",
        "azurerm_stream_analytics_reference_input_mssql",
        "azurerm_subscription_cost_management_export",
        "azurerm_subscription_policy_assignment",
        "azurerm_synapse_integration_runtime_azure",
        "azurerm_synapse_integration_runtime_self_hosted",
        "azurerm_synapse_linked_service",
        "azurerm_synapse_private_link_hub",
        "azurerm_synapse_sql_pool_extended_auditing_policy",
        "azurerm_synapse_sql_pool_security_alert_policy",
        "azurerm_synapse_sql_pool_vulnerability_assessment",
        "azurerm_synapse_sql_pool_vulnerability_assessment_baseline",
        "azurerm_synapse_sql_pool_workload_classifier",
        "azurerm_synapse_sql_pool_workload_group",
        "azurerm_synapse_workspace_aad_admin",
        "azurerm_synapse_workspace_extended_auditing_policy",
        "azurerm_synapse_workspace_key",
        "azurerm_synapse_workspace_security_alert_policy",
        "azurerm_synapse_workspace_sql_aad_admin",
        "azurerm_synapse_workspace_vulnerability_assessment",
        "azurerm_video_analyzer",
        "azurerm_video_analyzer_edge_module",
        "azurerm_virtual_desktop_application",
        "azurerm_virtual_desktop_scaling_plan",
        "azurerm_virtual_hub_route_table_route",
        "azurerm_virtual_machine_configuration_policy_assignment",
        "azurerm_virtual_network_dns_servers",
        "azurerm_vmware_cluster",
        "azurerm_vmware_express_route_authorization",
        "azurerm_vpn_gateway_nat_rule",
        "azurerm_active_directory_domain_service_trust",
        "azurerm_api_connection",
        "azurerm_api_management_api_tag",
        "azurerm_app_service_source_control",
        "azurerm_app_service_source_control_slot",
        "azurerm_application_insights_workbook",
        "azurerm_application_insights_workbook_template",
        "azurerm_capacity_reservation",
        "azurerm_capacity_reservation_group",
        "azurerm_cdn_frontdoor_endpoint",
        "azurerm_cdn_frontdoor_origin",
        "azurerm_cdn_frontdoor_origin_group",
        "azurerm_cdn_frontdoor_profile",
        "azurerm_cdn_frontdoor_rule_set",
        "azurerm_confidential_ledger",
        "azurerm_container_connected_registry",
        "azurerm_container_registry_agent_pool",
        "azurerm_cosmosdb_sql_role_assignment",
        "azurerm_cosmosdb_sql_role_definition",
        "azurerm_data_protection_resource_guard",
        "azurerm_disk_pool_iscsi_target",
        "azurerm_disk_pool_iscsi_target_lun",
        "azurerm_disk_pool_managed_disk_attachment",
        "azurerm_elastic_cloud_elasticsearch",
        "azurerm_fluid_relay_server",
        "azurerm_function_app_active_slot",
        "azurerm_function_app_function",
        "azurerm_function_app_hybrid_connection",
        "azurerm_gallery_application",
        "azurerm_gallery_application_version",
        "azurerm_healthcare_dicom_service",
        "azurerm_healthcare_fhir_service",
        "azurerm_healthcare_workspace",
        "azurerm_iothub_certificate",
        "azurerm_linux_function_app",
        "azurerm_linux_function_app_slot",
        "azurerm_linux_web_app",
        "azurerm_linux_web_app_slot",
        "azurerm_logz_sub_account",
        "azurerm_managed_disk_sas_token",
        "azurerm_management_group_policy_exemption",
        "azurerm_management_group_policy_remediation",
        "azurerm_monitor_data_collection_rule",
        "azurerm_mssql_managed_database",
        "azurerm_mssql_managed_instance",
        "azurerm_mssql_managed_instance_active_directory_administrator",
        "azurerm_mssql_managed_instance_failover_group",
        "azurerm_mssql_managed_instance_vulnerability_assessment",
        "azurerm_mssql_outbound_firewall_rule",
        "azurerm_mssql_server_dns_alias",
        "azurerm_portal_dashboard",
        "azurerm_resource_group_policy_exemption",
        "azurerm_resource_group_policy_remediation",
        "azurerm_resource_policy_exemption",
        "azurerm_resource_policy_remediation",
        "azurerm_route_server",
        "azurerm_route_server_bgp_connection",
        "azurerm_security_center_server_vulnerability_assessment_virtual_machine",
        "azurerm_sentinel_data_connector_aws_s3",
        "azurerm_sentinel_watchlist_item",
        "azurerm_service_plan",
        "azurerm_source_control_token",
        "azurerm_spring_cloud_api_portal",
        "azurerm_spring_cloud_api_portal_custom_domain",
        "azurerm_spring_cloud_build_deployment",
        "azurerm_spring_cloud_build_pack_binding",
        "azurerm_spring_cloud_builder",
        "azurerm_spring_cloud_configuration_service",
        "azurerm_spring_cloud_container_deployment",
        "azurerm_spring_cloud_gateway",
        "azurerm_spring_cloud_gateway_custom_domain",
        "azurerm_spring_cloud_gateway_route_config",
        "azurerm_spring_cloud_storage",
        "azurerm_stream_analytics_function_javascript_uda",
        "azurerm_stream_analytics_job_schedule",
        "azurerm_stream_analytics_output_cosmosdb",
        "azurerm_stream_analytics_output_function",
        "azurerm_stream_analytics_output_powerbi",
        "azurerm_subscription_policy_exemption",
        "azurerm_subscription_policy_remediation",
        "azurerm_traffic_manager_azure_endpoint",
        "azurerm_traffic_manager_external_endpoint",
        "azurerm_traffic_manager_nested_endpoint",
        "azurerm_virtual_desktop_host_pool_registration_info",
        "azurerm_virtual_network_gateway_nat_rule",
        "azurerm_vpn_server_configuration_policy_group",
        "azurerm_web_app_active_slot",
        "azurerm_web_app_hybrid_connection",
        "azurerm_web_pubsub",
        "azurerm_web_pubsub_hub",
        "azurerm_web_pubsub_network_acl",
        "azurerm_web_pubsub_shared_private_link_resource",
        "azurerm_windows_function_app",
        "azurerm_windows_function_app_slot",
        "azurerm_windows_web_app",
        "azurerm_windows_web_app_slot",
        "azurerm_api_management_api_tag_description",
        "azurerm_api_management_gateway_certificate_authority",
        "azurerm_api_management_gateway_host_name_configuration",
        "azurerm_api_management_global_schema",
        "azurerm_api_management_product_tag",
        "azurerm_app_service_connection",
        "azurerm_automation_connection_type",
        "azurerm_automation_hybrid_runbook_worker",
        "azurerm_automation_hybrid_runbook_worker_group",
        "azurerm_automation_software_update_configuration",
        "azurerm_automation_source_control",
        "azurerm_automation_watcher",
        "azurerm_backup_policy_vm_workload",
        "azurerm_billing_account_cost_management_export",
        "azurerm_cdn_frontdoor_custom_domain",
        "azurerm_cdn_frontdoor_custom_domain_association",
        "azurerm_cdn_frontdoor_firewall_policy",
        "azurerm_cdn_frontdoor_route",
        "azurerm_cdn_frontdoor_route_disable_link_to_default_domain",
        "azurerm_cdn_frontdoor_rule",
        "azurerm_cdn_frontdoor_secret",
        "azurerm_cdn_frontdoor_security_policy",
        "azurerm_cognitive_deployment",
        "azurerm_container_registry_task_schedule_run_now",
        "azurerm_container_registry_token_password",
        "azurerm_cosmosdb_sql_dedicated_gateway",
        "azurerm_dashboard_grafana",
        "azurerm_data_factory_flowlet_data_flow",
        "azurerm_databricks_access_connector",
        "azurerm_datadog_monitor",
        "azurerm_datadog_monitor_sso_configuration",
        "azurerm_datadog_monitor_tag_rule",
        "azurerm_digital_twins_time_series_database_connection",
        "azurerm_eventhub_namespace_schema_group",
        "azurerm_federated_identity_credential",
        "azurerm_healthcare_medtech_service",
        "azurerm_healthcare_medtech_service_fhir_destination",
        "azurerm_iotcentral_application_network_rule_set",
        "azurerm_iothub_device_update_account",
        "azurerm_iothub_device_update_instance",
        "azurerm_key_vault_certificate_contacts",
        "azurerm_kubernetes_fleet_manager",
        "azurerm_kusto_cluster_managed_private_endpoint",
        "azurerm_lab_service_plan",
        "azurerm_log_analytics_query_pack",
        "azurerm_log_analytics_query_pack_query",
        "azurerm_logz_sub_account_tag_rule",
        "azurerm_monitor_alert_processing_rule_action_group",
        "azurerm_monitor_alert_processing_rule_suppression",
        "azurerm_monitor_data_collection_endpoint",
        "azurerm_monitor_data_collection_rule_association",
        "azurerm_monitor_scheduled_query_rules_alert_v2",
        "azurerm_mssql_managed_instance_security_alert_policy",
        "azurerm_mssql_managed_instance_transparent_data_encryption",
        "azurerm_mssql_server_microsoft_support_auditing_policy",
        "azurerm_network_manager",
        "azurerm_nginx_certificate",
        "azurerm_nginx_configuration",
        "azurerm_nginx_deployment",
        "azurerm_orbital_contact_profile",
        "azurerm_orbital_spacecraft",
        "azurerm_postgresql_flexible_server_active_directory_administrator",
        "azurerm_private_dns_resolver",
        "azurerm_private_dns_resolver_dns_forwarding_ruleset",
        "azurerm_private_dns_resolver_forwarding_rule",
        "azurerm_private_dns_resolver_inbound_endpoint",
        "azurerm_private_dns_resolver_outbound_endpoint",
        "azurerm_private_dns_resolver_virtual_network_link",
        "azurerm_resource_deployment_script_azure_cli",
        "azurerm_resource_deployment_script_azure_power_shell",
        "azurerm_route_map",
        "azurerm_search_shared_private_link_service",
        "azurerm_sentinel_alert_rule_nrt",
        "azurerm_sentinel_data_connector_dynamics_365",
        "azurerm_sentinel_data_connector_iot",
        "azurerm_sentinel_data_connector_microsoft_threat_protection",
        "azurerm_sentinel_data_connector_office_365_project",
        "azurerm_sentinel_data_connector_office_atp",
        "azurerm_sentinel_data_connector_office_irm",
        "azurerm_sentinel_data_connector_office_power_bi",
        "azurerm_signalr_shared_private_link_resource",
        "azurerm_spring_cloud_accelerator",
        "azurerm_spring_cloud_application_live_view",
        "azurerm_spring_cloud_connection",
        "azurerm_spring_cloud_customized_accelerator",
        "azurerm_spring_cloud_dev_tool_portal",
        "azurerm_stream_analytics_stream_input_eventhub_v2",
        "azurerm_virtual_machine_packet_capture",
        "azurerm_virtual_machine_scale_set_packet_capture",
        "azurerm_vmware_netapp_volume_attachment",
        "azurerm_application_insights_standard_web_test",
        "azurerm_application_load_balancer",
        "azurerm_application_load_balancer_frontend",
        "azurerm_application_load_balancer_subnet_association",
        "azurerm_arc_kubernetes_cluster",
        "azurerm_arc_kubernetes_cluster_extension",
        "azurerm_arc_kubernetes_flux_configuration",
        "azurerm_arc_machine_extension",
        "azurerm_arc_private_link_scope",
        "azurerm_arc_resource_bridge_appliance",
        "azurerm_automanage_configuration",
        "azurerm_automation_powershell72_module",
        "azurerm_automation_python3_package",
        "azurerm_automation_variable_object",
        "azurerm_container_app",
        "azurerm_container_app_environment",
        "azurerm_container_app_environment_certificate",
        "azurerm_container_app_environment_dapr_component",
        "azurerm_container_app_environment_storage",
        "azurerm_cosmosdb_mongo_role_definition",
        "azurerm_cosmosdb_mongo_user_definition",
        "azurerm_cosmosdb_postgresql_cluster",
        "azurerm_cosmosdb_postgresql_coordinator_configuration",
        "azurerm_cosmosdb_postgresql_firewall_rule",
        "azurerm_cosmosdb_postgresql_node_configuration",
        "azurerm_cosmosdb_postgresql_role",
        "azurerm_cost_anomaly_alert",
        "azurerm_cost_management_scheduled_action",
        "azurerm_custom_ip_prefix",
        "azurerm_data_factory_credential_user_managed_identity",
        "azurerm_data_factory_dataset_azure_sql_table",
        "azurerm_databricks_virtual_network_peering",
        "azurerm_databricks_workspace_root_dbfs_customer_managed_key",
        "azurerm_dev_center",
        "azurerm_dev_center_project",
        "azurerm_elastic_san",
        "azurerm_email_communication_service",
        "azurerm_express_route_port_authorization",
        "azurerm_function_app_connection",
        "azurerm_graph_account",
        "azurerm_graph_services_account",
        "azurerm_iothub_endpoint_cosmosdb_account",
        "azurerm_iothub_file_upload",
        "azurerm_ip_group_cidr",
        "azurerm_key_vault_managed_hardware_security_module_role_assignment",
        "azurerm_key_vault_managed_hardware_security_module_role_definition",
        "azurerm_kubernetes_cluster_extension",
        "azurerm_kubernetes_cluster_trusted_access_role_binding",
        "azurerm_kubernetes_flux_configuration",
        "azurerm_kusto_cosmosdb_data_connection",
        "azurerm_lab_service_lab",
        "azurerm_lab_service_schedule",
        "azurerm_lab_service_user",
        "azurerm_log_analytics_workspace_table",
        "azurerm_machine_learning_datastore_blobstorage",
        "azurerm_machine_learning_datastore_datalake_gen2",
        "azurerm_machine_learning_datastore_fileshare",
        "azurerm_managed_lustre_file_system",
        "azurerm_marketplace_role_assignment",
        "azurerm_media_services_account_filter",
        "azurerm_mobile_network",
        "azurerm_mobile_network_attached_data_network",
        "azurerm_mobile_network_data_network",
        "azurerm_mobile_network_packet_core_control_plane",
        "azurerm_mobile_network_packet_core_data_plane",
        "azurerm_mobile_network_service",
        "azurerm_mobile_network_sim",
        "azurerm_mobile_network_sim_group",
        "azurerm_mobile_network_sim_policy",
        "azurerm_mobile_network_site",
        "azurerm_mobile_network_slice",
        "azurerm_monitor_alert_prometheus_rule_group",
        "azurerm_monitor_workspace",
        "azurerm_mssql_virtual_machine_availability_group_listener",
        "azurerm_mssql_virtual_machine_group",
        "azurerm_mysql_flexible_server_active_directory_administrator",
        "azurerm_netapp_volume_group_sap_hana",
        "azurerm_netapp_volume_quota_rule",
        "azurerm_network_function_azure_traffic_collector",
        "azurerm_network_function_collector_policy",
        "azurerm_network_manager_admin_rule",
        "azurerm_network_manager_admin_rule_collection",
        "azurerm_network_manager_connectivity_configuration",
        "azurerm_network_manager_deployment",
        "azurerm_network_manager_management_group_connection",
        "azurerm_network_manager_network_group",
        "azurerm_network_manager_scope_connection",
        "azurerm_network_manager_security_admin_configuration",
        "azurerm_network_manager_static_member",
        "azurerm_network_manager_subscription_connection",
        "azurerm_new_relic_monitor",
        "azurerm_new_relic_tag_rule",
        "azurerm_orbital_contact",
        "azurerm_palo_alto_local_rulestack",
        "azurerm_palo_alto_local_rulestack_certificate",
        "azurerm_palo_alto_local_rulestack_fqdn_list",
        "azurerm_palo_alto_local_rulestack_outbound_trust_certificate_association",
        "azurerm_palo_alto_local_rulestack_outbound_untrust_certificate_association",
        "azurerm_palo_alto_local_rulestack_prefix_list",
        "azurerm_palo_alto_local_rulestack_rule",
        "azurerm_palo_alto_next_generation_firewall_virtual_hub_local_rulestack",
        "azurerm_palo_alto_next_generation_firewall_virtual_hub_panorama",
        "azurerm_palo_alto_next_generation_firewall_virtual_network_local_rulestack",
        "azurerm_palo_alto_next_generation_firewall_virtual_network_panorama",
        "azurerm_palo_alto_virtual_network_appliance",
        "azurerm_pim_active_role_assignment",
        "azurerm_pim_eligible_role_assignment",
        "azurerm_private_endpoint_application_security_group_association",
        "azurerm_recovery_services_vault_resource_guard_association",
        "azurerm_resource_group_cost_management_view",
        "azurerm_resource_management_private_link",
        "azurerm_resource_management_private_link_association",
        "azurerm_security_center_server_vulnerability_assessments_setting",
        "azurerm_security_center_storage_defender",
        "azurerm_sentinel_alert_rule_anomaly_built_in",
        "azurerm_sentinel_alert_rule_anomaly_duplicate",
        "azurerm_sentinel_alert_rule_threat_intelligence",
        "azurerm_sentinel_data_connector_microsoft_threat_intelligence",
        "azurerm_sentinel_data_connector_threat_intelligence_taxii",
        "azurerm_sentinel_log_analytics_workspace_onboarding",
        "azurerm_sentinel_metadata",
        "azurerm_sentinel_threat_intelligence_indicator",
        "azurerm_signalr_service_custom_certificate",
        "azurerm_signalr_service_custom_domain",
        "azurerm_site_recovery_hyperv_network_mapping",
        "azurerm_site_recovery_hyperv_replication_policy",
        "azurerm_site_recovery_hyperv_replication_policy_association",
        "azurerm_site_recovery_replication_recovery_plan",
        "azurerm_site_recovery_services_vault_hyperv_site",
        "azurerm_site_recovery_vmware_replication_policy",
        "azurerm_site_recovery_vmware_replication_policy_association",
        "azurerm_spring_cloud_application_insights_application_performance_monitoring",
        "azurerm_spring_cloud_dynatrace_application_performance_monitoring",
        "azurerm_storage_account_local_user",
        "azurerm_storage_mover",
        "azurerm_storage_mover_agent",
        "azurerm_storage_mover_job_definition",
        "azurerm_storage_mover_project",
        "azurerm_storage_mover_source_endpoint",
        "azurerm_storage_mover_target_endpoint",
        "azurerm_subscription_cost_management_view",
        "azurerm_virtual_hub_routing_intent",
        "azurerm_virtual_machine_run_command",
        "azurerm_voice_services_communications_gateway",
        "azurerm_voice_services_communications_gateway_test_line",
        "azurerm_web_pubsub_custom_certificate",
        "azurerm_web_pubsub_custom_domain",
        "azurerm_advisor_suppression",
        "azurerm_ai_services",
        "azurerm_api_management_policy_fragment",
        "azurerm_arc_kubernetes_provisioned_cluster",
        "azurerm_arc_machine",
        "azurerm_arc_machine_automanage_configuration_assignment",
        "azurerm_chaos_studio_capability",
        "azurerm_chaos_studio_experiment",
        "azurerm_chaos_studio_target",
        "azurerm_cognitive_account_rai_blocklist",
        "azurerm_cognitive_account_rai_policy",
        "azurerm_communication_service_email_domain_association",
        "azurerm_container_app_custom_domain",
        "azurerm_container_app_environment_custom_domain",
        "azurerm_container_app_job",
        "azurerm_container_registry_cache_rule",
        "azurerm_container_registry_credential_set",
        "azurerm_dashboard_grafana_managed_private_endpoint",
        "azurerm_data_factory_credential_service_principal",
        "azurerm_data_protection_backup_instance_kubernetes_cluster",
        "azurerm_data_protection_backup_instance_mysql_flexible_server",
        "azurerm_data_protection_backup_instance_postgresql_flexible_server",
        "azurerm_data_protection_backup_policy_kubernetes_cluster",
        "azurerm_data_protection_backup_policy_mysql_flexible_server",
        "azurerm_data_protection_backup_policy_postgresql_flexible_server",
        "azurerm_dev_center_attached_network",
        "azurerm_dev_center_catalog",
        "azurerm_dev_center_dev_box_definition",
        "azurerm_dev_center_environment_type",
        "azurerm_dev_center_gallery",
        "azurerm_dev_center_network_connection",
        "azurerm_dev_center_project_environment_type",
        "azurerm_dev_center_project_pool",
        "azurerm_dynatrace_monitor",
        "azurerm_dynatrace_tag_rules",
        "azurerm_elastic_san_volume",
        "azurerm_elastic_san_volume_group",
        "azurerm_email_communication_service_domain",
        "azurerm_eventgrid_namespace",
        "azurerm_extended_custom_location",
        "azurerm_fabric_capacity",
        "azurerm_iotcentral_organization",
        "azurerm_key_vault_managed_hardware_security_module_key",
        "azurerm_key_vault_managed_hardware_security_module_key_rotation_policy",
        "azurerm_kubernetes_fleet_member",
        "azurerm_kubernetes_fleet_update_run",
        "azurerm_kubernetes_fleet_update_strategy",
        "azurerm_machine_learning_workspace_network_outbound_rule_fqdn",
        "azurerm_machine_learning_workspace_network_outbound_rule_private_endpoint",
        "azurerm_machine_learning_workspace_network_outbound_rule_service_tag",
        "azurerm_maintenance_assignment_dynamic_scope",
        "azurerm_mongo_cluster",
        "azurerm_mssql_job",
        "azurerm_mssql_job_schedule",
        "azurerm_mssql_job_target_group",
        "azurerm_netapp_account_encryption",
        "azurerm_netapp_backup_policy",
        "azurerm_netapp_backup_vault",
        "azurerm_oracle_autonomous_database",
        "azurerm_oracle_cloud_vm_cluster",
        "azurerm_oracle_exadata_infrastructure",
        "azurerm_postgresql_flexible_server_virtual_endpoint",
        "azurerm_redhat_openshift_cluster",
        "azurerm_redis_cache_access_policy",
        "azurerm_redis_cache_access_policy_assignment",
        "azurerm_restore_point_collection",
        "azurerm_role_management_policy",
        "azurerm_site_recovery_vmware_replicated_vm",
        "azurerm_spring_cloud_app_dynamics_application_performance_monitoring",
        "azurerm_spring_cloud_elastic_application_performance_monitoring",
        "azurerm_spring_cloud_new_relic_application_performance_monitoring",
        "azurerm_stack_hci_deployment_setting",
        "azurerm_stack_hci_extension",
        "azurerm_stack_hci_logical_network",
        "azurerm_stack_hci_marketplace_gallery_image",
        "azurerm_stack_hci_network_interface",
        "azurerm_stack_hci_storage_path",
        "azurerm_stack_hci_virtual_hard_disk",
        "azurerm_static_web_app",
        "azurerm_static_web_app_custom_domain",
        "azurerm_static_web_app_function_app_registration",
        "azurerm_storage_account_queue_properties",
        "azurerm_storage_account_static_website",
        "azurerm_storage_container_immutability_policy",
        "azurerm_storage_sync_server_endpoint",
        "azurerm_system_center_virtual_machine_manager_availability_set",
        "azurerm_system_center_virtual_machine_manager_cloud",
        "azurerm_system_center_virtual_machine_manager_server",
        "azurerm_system_center_virtual_machine_manager_virtual_machine_template",
        "azurerm_system_center_virtual_machine_manager_virtual_network",
        "azurerm_trusted_signing_account",
        "azurerm_video_indexer_account",
        "azurerm_virtual_desktop_scaling_plan_host_pool_association",
        "azurerm_virtual_machine_automanage_configuration_assignment",
        "azurerm_virtual_machine_gallery_application_assignment",
        "azurerm_virtual_machine_implicit_data_disk_from_source",
        "azurerm_virtual_machine_restore_point",
        "azurerm_virtual_machine_restore_point_collection",
        "azurerm_workloads_sap_discovery_virtual_instance",
        "azurerm_workloads_sap_single_node_virtual_instance",
        "azurerm_workloads_sap_three_tier_virtual_instance"
    ],
    "aws_taggable": [
        "aws_acm_certificate",
        "aws_acmpca_certificate_authority",
        "aws_api_gateway_api_key",
        "aws_api_gateway_client_certificate",
        "aws_api_gateway_domain_name",
        "aws_api_gateway_rest_api",
        "aws_api_gateway_stage",
        "aws_api_gateway_usage_plan",
        "aws_api_gateway_vpc_link",
        "aws_apigatewayv2_api",
        "aws_apigatewayv2_domain_name",
        "aws_apigatewayv2_stage",
        "aws_apigatewayv2_vpc_link",
        "aws_accessanalyzer_analyzer",
        "aws_appmesh_mesh",
        "aws_appmesh_route",
        "aws_appmesh_virtual_node",
        "aws_appmesh_virtual_router",
        "aws_appmesh_virtual_service",
        "aws_appsync_graphql_api",
        "aws_appautoscaling_target",
        "aws_athena_workgroup",
        "aws_backup_plan",
        "aws_backup_vault",
        "aws_batch_compute_environment",
        "aws_batch_job_definition",
        "aws_batch_job_queue",
        "aws_budgets_budget",
        "aws_cloud9_environment_ec2",
        "aws_cloudformation_stack",
        "aws_cloudformation_stack_set",
        "aws_cloudfront_distribution",
        "aws_cloudhsm_v2_cluster",
        "aws_cloudtrail",
        "aws_cloudwatch_event_rule",
        "aws_cloudwatch_log_destination",
        "aws_cloudwatch_log_group",
        "aws_cloudwatch_metric_alarm",
        "aws_codebuild_project",
        "aws_codecommit_repository",
        "aws_codedeploy_app",
        "aws_codedeploy_deployment_group",
        "aws_codepipeline",
        "aws_codepipeline_webhook",
        "aws_codestarnotifications_notification_rule",
        "aws_cognito_identity_pool",
        "aws_cognito_user_pool",
        "aws_config_aggregate_authorization",
        "aws_config_config_rule",
        "aws_config_configuration_aggregator",
        "aws_cur_report_definition",
        "aws_dlm_lifecycle_policy",
        "aws_datapipeline_pipeline",
        "aws_datasync_agent",
        "aws_datasync_location_efs",
        "aws_datasync_location_nfs",
        "aws_datasync_location_s3",
        "aws_datasync_location_smb",
        "aws_datasync_task",
        "aws_dms_certificate",
        "aws_dms_endpoint",
        "aws_dms_event_subscription",
        "aws_dms_replication_instance",
        "aws_dms_replication_subnet_group",
        "aws_dms_replication_task",
        "aws_devicefarm_project",
        "aws_dx_connection",
        "aws_dx_hosted_private_virtual_interface_accepter",
        "aws_dx_hosted_public_virtual_interface_accepter",
        "aws_dx_hosted_transit_virtual_interface_accepter",
        "aws_dx_lag",
        "aws_dx_private_virtual_interface",
        "aws_dx_public_virtual_interface",
        "aws_dx_transit_virtual_interface",
        "aws_directory_service_directory",
        "aws_docdb_cluster",
        "aws_docdb_cluster_instance",
        "aws_docdb_cluster_parameter_group",
        "aws_docdb_subnet_group",
        "aws_dynamodb_table",
        "aws_dax_cluster",
        "aws_ami",
        "aws_ami_copy",
        "aws_ami_from_instance",
        "aws_ebs_snapshot",
        "aws_ebs_snapshot_copy",
        "aws_ebs_volume",
        "aws_ec2_capacity_reservation",
        "aws_ec2_client_vpn_endpoint",
        "aws_ec2_fleet",
        "aws_ec2_local_gateway_route_table_vpc_association",
        "aws_ec2_traffic_mirror_filter",
        "aws_ec2_traffic_mirror_session",
        "aws_ec2_traffic_mirror_target",
        "aws_ec2_transit_gateway",
        "aws_ec2_transit_gateway_peering_attachment",
        "aws_ec2_transit_gateway_peering_attachment_accepter",
        "aws_ec2_transit_gateway_route_table",
        "aws_ec2_transit_gateway_vpc_attachment",
        "aws_ec2_transit_gateway_vpc_attachment_accepter",
        "aws_eip",
        "aws_instance",
        "aws_key_pair",
        "aws_launch_template",
        "aws_placement_group",
        "aws_spot_fleet_request",
        "aws_spot_instance_request",
        "aws_ecr_repository",
        "aws_ecs_capacity_provider",
        "aws_ecs_cluster",
        "aws_ecs_service",
        "aws_ecs_task_definition",
        "aws_efs_access_point",
        "aws_efs_file_system",
        "aws_eks_cluster",
        "aws_eks_fargate_profile",
        "aws_eks_node_group",
        "aws_elasticache_cluster",
        "aws_elasticache_parameter_group",
        "aws_elasticache_replication_group",
        "aws_elasticache_subnet_group",
        "aws_elastic_beanstalk_application",
        "aws_elastic_beanstalk_application_version",
        "aws_elastic_beanstalk_environment",
        "aws_elb",
        "aws_lb",
        "aws_lb_listener",
        "aws_lb_listener_rule",
        "aws_lb_target_group",
        "aws_emr_cluster",
        "aws_elasticsearch_domain",
        "aws_fsx_lustre_file_system",
        "aws_fsx_windows_file_system",
        "aws_gamelift_alias",
        "aws_gamelift_build",
        "aws_gamelift_fleet",
        "aws_gamelift_game_session_queue",
        "aws_glacier_vault",
        "aws_globalaccelerator_accelerator",
        "aws_glue_catalog_database",
        "aws_glue_connection",
        "aws_glue_crawler",
        "aws_glue_job",
        "aws_glue_trigger",
        "aws_glue_workflow",
        "aws_guardduty_detector",
        "aws_guardduty_ipset",
        "aws_guardduty_threatintelset",
        "aws_iam_instance_profile",
        "aws_iam_openid_connect_provider",
        "aws_iam_policy",
        "aws_iam_role",
        "aws_iam_saml_provider",
        "aws_iam_server_certificate",
        "aws_iam_service_linked_role",
        "aws_iam_user",
        "aws_inspector_assessment_template",
        "aws_inspector_resource_group",
        "aws_iot_policy",
        "aws_iot_role_alias",
        "aws_iot_thing_type",
        "aws_iot_topic_rule",
        "aws_kms_external_key",
        "aws_kms_key",
        "aws_kinesis_analytics_application",
        "aws_kinesis_stream",
        "aws_kinesis_firehose_delivery_stream",
        "aws_kinesis_video_stream",
        "aws_lambda_event_source_mapping",
        "aws_lambda_function",
        "aws_licensemanager_license_configuration",
        "aws_lightsail_instance",
        "aws_lightsail_key_pair",
        "aws_mq_broker",
        "aws_mq_configuration",
        "aws_msk_cluster",
        "aws_media_convert_queue",
        "aws_media_package_channel",
        "aws_media_store_container",
        "aws_neptune_cluster",
        "aws_neptune_cluster_instance",
        "aws_neptune_cluster_parameter_group",
        "aws_neptune_event_subscription",
        "aws_neptune_parameter_group",
        "aws_neptune_subnet_group",
        "aws_opsworks_custom_layer",
        "aws_opsworks_ganglia_layer",
        "aws_opsworks_haproxy_layer",
        "aws_opsworks_java_app_layer",
        "aws_opsworks_memcached_layer",
        "aws_opsworks_mysql_layer",
        "aws_opsworks_nodejs_app_layer",
        "aws_opsworks_php_app_layer",
        "aws_opsworks_rails_app_layer",
        "aws_opsworks_stack",
        "aws_opsworks_static_web_layer",
        "aws_organizations_account",
        "aws_organizations_organizational_unit",
        "aws_organizations_policy",
        "aws_pinpoint_app",
        "aws_qldb_ledger",
        "aws_ram_resource_share",
        "aws_db_cluster_snapshot",
        "aws_db_event_subscription",
        "aws_db_instance",
        "aws_db_option_group",
        "aws_db_parameter_group",
        "aws_db_security_group",
        "aws_db_snapshot",
        "aws_db_subnet_group",
        "aws_rds_cluster",
        "aws_rds_cluster_endpoint",
        "aws_rds_cluster_instance",
        "aws_rds_cluster_parameter_group",
        "aws_rds_global_cluster",
        "aws_redshift_cluster",
        "aws_redshift_event_subscription",
        "aws_redshift_parameter_group",
        "aws_redshift_snapshot_copy_grant",
        "aws_redshift_snapshot_schedule",
        "aws_redshift_subnet_group",
        "aws_resourcegroups_group",
        "aws_route53_health_check",
        "aws_route53_zone",
        "aws_route53_resolver_endpoint",
        "aws_route53_resolver_rule",
        "aws_s3_bucket",
        "aws_s3_bucket_object",
        "aws_sns_topic",
        "aws_sqs_queue",
        "aws_ssm_activation",
        "aws_ssm_association",
        "aws_ssm_document",
        "aws_ssm_maintenance_window",
        "aws_ssm_parameter",
        "aws_ssm_patch_baseline",
        "aws_swf_domain",
        "aws_sagemaker_endpoint",
        "aws_sagemaker_endpoint_configuration",
        "aws_sagemaker_model",
        "aws_sagemaker_notebook_instance",
        "aws_secretsmanager_secret",
        "aws_servicecatalog_portfolio",
        "aws_service_discovery_http_namespace",
        "aws_service_discovery_private_dns_namespace",
        "aws_service_discovery_public_dns_namespace",
        "aws_service_discovery_service",
        "aws_shield_protection",
        "aws_sfn_activity",
        "aws_sfn_state_machine",
        "aws_storagegateway_cached_iscsi_volume",
        "aws_storagegateway_gateway",
        "aws_storagegateway_nfs_file_share",
        "aws_storagegateway_smb_file_share",
        "aws_transfer_server",
        "aws_transfer_user",
        "aws_customer_gateway",
        "aws_default_network_acl",
        "aws_default_route_table",
        "aws_default_security_group",
        "aws_default_subnet",
        "aws_default_vpc",
        "aws_default_vpc_dhcp_options",
        "aws_egress_only_internet_gateway",
        "aws_flow_log",
        "aws_internet_gateway",
        "aws_nat_gateway",
        "aws_network_acl",
        "aws_network_interface",
        "aws_route_table",
        "aws_security_group",
        "aws_subnet",
        "aws_vpc",
        "aws_vpc_dhcp_options",
        "aws_vpc_endpoint",
        "aws_vpc_endpoint_service",
        "aws_vpc_peering_connection",
        "aws_vpc_peering_connection_accepter",
        "aws_vpn_connection",
        "aws_vpn_gateway",
        "aws_waf_rate_based_rule",
        "aws_waf_rule",
        "aws_waf_rule_group",
        "aws_waf_web_acl",
        "aws_wafregional_rate_based_rule",
        "aws_wafregional_rule",
        "aws_wafregional_rule_group",
        "aws_wafregional_web_acl",
        "aws_wafv2_ip_set",
        "aws_wafv2_regex_pattern_set",
        "aws_wafv2_rule_group",
        "aws_wafv2_web_acl",
        "aws_workspaces_directory",
        "aws_workspaces_ip_group",
        "aws_workspaces_workspace",
        "aws_xray_sampling_rule",
        "aws_alb",
        "aws_alb_listener",
        "aws_alb_listener_rule",
        "aws_alb_target_group",
        "aws_appmesh_gateway_route",
        "aws_appmesh_virtual_gateway",
        "aws_cloudwatch_composite_alarm",
        "aws_cloudwatch_event_bus",
        "aws_codeartifact_domain",
        "aws_codeartifact_repository",
        "aws_codebuild_report_group",
        "aws_codestarconnections_connection",
        "aws_datasync_location_fsx_windows_file_system",
        "aws_db_proxy",
        "aws_ec2_carrier_gateway",
        "aws_ec2_managed_prefix_list",
        "aws_fms_policy",
        "aws_glue_dev_endpoint",
        "aws_glue_ml_transform",
        "aws_glue_registry",
        "aws_glue_schema",
        "aws_guardduty_filter",
        "aws_imagebuilder_component",
        "aws_imagebuilder_distribution_configuration",
        "aws_imagebuilder_image",
        "aws_imagebuilder_image_pipeline",
        "aws_imagebuilder_image_recipe",
        "aws_imagebuilder_infrastructure_configuration",
        "aws_kinesisanalyticsv2_application",
        "aws_lambda_code_signing_config",
        "aws_networkfirewall_firewall",
        "aws_networkfirewall_firewall_policy",
        "aws_networkfirewall_rule_group",
        "aws_prometheus_workspace",
        "aws_route53_resolver_query_log_config",
        "aws_s3_object_copy",
        "aws_s3control_bucket",
        "aws_sagemaker_app_image_config",
        "aws_sagemaker_code_repository",
        "aws_sagemaker_domain",
        "aws_sagemaker_feature_group",
        "aws_sagemaker_image",
        "aws_sagemaker_model_package_group",
        "aws_sagemaker_user_profile",
        "aws_serverlessapplicationrepository_cloudformation_stack",
        "aws_signer_signing_profile",
        "aws_ssoadmin_permission_set",
        "aws_storagegateway_stored_iscsi_volume",
        "aws_storagegateway_tape_pool",
        "aws_synthetics_canary",
        "aws_xray_group",
        "aws_ecrpublic_repository",
        "aws_eks_addon",
        "aws_mwaa_environment",
        "aws_route53_resolver_firewall_domain_list",
        "aws_route53_resolver_firewall_rule_group",
        "aws_sagemaker_app",
        "aws_timestreamwrite_database",
        "aws_amplify_app",
        "aws_amplify_branch",
        "aws_appconfig_application",
        "aws_appconfig_configuration_profile",
        "aws_appconfig_deployment",
        "aws_appconfig_deployment_strategy",
        "aws_appconfig_environment",
        "aws_apprunner_auto_scaling_configuration_version",
        "aws_apprunner_connection",
        "aws_apprunner_service",
        "aws_appstream_fleet",
        "aws_appstream_image_builder",
        "aws_appstream_stack",
        "aws_batch_scheduling_policy",
        "aws_budgets_budget_action",
        "aws_chime_voice_connector",
        "aws_cloudwatch_metric_stream",
        "aws_connect_contact_flow",
        "aws_connect_hours_of_operation",
        "aws_connect_instance",
        "aws_datasync_location_fsx_lustre_file_system",
        "aws_datasync_location_hdfs",
        "aws_db_proxy_endpoint",
        "aws_detective_graph",
        "aws_devicefarm_device_pool",
        "aws_devicefarm_network_profile",
        "aws_ebs_snapshot_import",
        "aws_ec2_host",
        "aws_ecs_task_set",
        "aws_eks_identity_provider_config",
        "aws_elasticache_user",
        "aws_elasticache_user_group",
        "aws_emr_studio",
        "aws_fsx_backup",
        "aws_fsx_ontap_file_system",
        "aws_fsx_ontap_storage_virtual_machine",
        "aws_fsx_ontap_volume",
        "aws_fsx_openzfs_file_system",
        "aws_fsx_openzfs_snapshot",
        "aws_fsx_openzfs_volume",
        "aws_iot_authorizer",
        "aws_iot_thing_group",
        "aws_kms_replica_external_key",
        "aws_kms_replica_key",
        "aws_macie2_classification_job",
        "aws_macie2_custom_data_identifier",
        "aws_macie2_findings_filter",
        "aws_macie2_member",
        "aws_memorydb_acl",
        "aws_memorydb_cluster",
        "aws_memorydb_parameter_group",
        "aws_memorydb_subnet_group",
        "aws_memorydb_user",
        "aws_mskconnect_custom_plugin",
        "aws_mskconnect_worker_configuration",
        "aws_neptune_cluster_endpoint",
        "aws_quicksight_data_source",
        "aws_route53_resolver_firewall_rule_group_association",
        "aws_route53recoveryreadiness_cell",
        "aws_route53recoveryreadiness_readiness_check",
        "aws_route53recoveryreadiness_recovery_group",
        "aws_route53recoveryreadiness_resource_set",
        "aws_sagemaker_device_fleet",
        "aws_sagemaker_flow_definition",
        "aws_sagemaker_human_task_ui",
        "aws_sagemaker_studio_lifecycle_config",
        "aws_sagemaker_workteam",
        "aws_schemas_discoverer",
        "aws_schemas_registry",
        "aws_schemas_schema",
        "aws_servicecatalog_product",
        "aws_servicecatalog_provisioned_product",
        "aws_shield_protection_group",
        "aws_storagegateway_file_system_association",
        "aws_timestreamwrite_table",
        "aws_vpc_ipam",
        "aws_vpc_ipam_pool",
        "aws_vpc_ipam_scope",
        "aws_appflow_flow",
        "aws_appintegrations_event_integration",
        "aws_applicationinsights_application",
        "aws_apprunner_observability_configuration",
        "aws_apprunner_vpc_connector",
        "aws_athena_data_catalog",
        "aws_backup_framework",
        "aws_backup_report_plan",
        "aws_ce_anomaly_monitor",
        "aws_ce_anomaly_subscription",
        "aws_ce_cost_category",
        "aws_cloudtrail_event_data_store",
        "aws_connect_contact_flow_module",
        "aws_connect_queue",
        "aws_connect_quick_connect",
        "aws_connect_routing_profile",
        "aws_connect_security_profile",
        "aws_connect_user",
        "aws_connect_user_hierarchy_group",
        "aws_connect_vocabulary",
        "aws_dataexchange_data_set",
        "aws_dataexchange_revision",
        "aws_datasync_location_fsx_openzfs_file_system",
        "aws_db_snapshot_copy",
        "aws_devicefarm_instance_profile",
        "aws_devicefarm_test_grid_project",
        "aws_docdb_event_subscription",
        "aws_ec2_network_insights_path",
        "aws_ec2_transit_gateway_connect",
        "aws_ec2_transit_gateway_connect_peer",
        "aws_ec2_transit_gateway_multicast_domain",
        "aws_emrcontainers_virtual_cluster",
        "aws_emrserverless_application",
        "aws_fis_experiment_template",
        "aws_fsx_data_repository_association",
        "aws_gamelift_game_server_group",
        "aws_gamelift_script",
        "aws_grafana_workspace",
        "aws_iam_virtual_mfa_device",
        "aws_imagebuilder_container_recipe",
        "aws_iot_provisioning_template",
        "aws_kendra_faq",
        "aws_kendra_index",
        "aws_kendra_query_suggestions_block_list",
        "aws_kendra_thesaurus",
        "aws_keyspaces_keyspace",
        "aws_keyspaces_table",
        "aws_lightsail_container_service",
        "aws_lightsail_database",
        "aws_location_geofence_collection",
        "aws_location_map",
        "aws_location_place_index",
        "aws_location_route_calculator",
        "aws_location_tracker",
        "aws_memorydb_snapshot",
        "aws_mskconnect_connector",
        "aws_networkmanager_connection",
        "aws_networkmanager_device",
        "aws_networkmanager_global_network",
        "aws_networkmanager_link",
        "aws_networkmanager_site",
        "aws_opensearch_domain",
        "aws_opsworks_ecs_cluster_layer",
        "aws_qldb_stream",
        "aws_redshift_hsm_client_certificate",
        "aws_redshift_hsm_configuration",
        "aws_redshift_usage_limit",
        "aws_redshiftserverless_namespace",
        "aws_rolesanywhere_profile",
        "aws_rolesanywhere_trust_anchor",
        "aws_route53domains_registered_domain",
        "aws_rum_app_monitor",
        "aws_s3_object",
        "aws_sagemaker_project",
        "aws_transcribe_medical_vocabulary",
        "aws_transcribe_vocabulary",
        "aws_transcribe_vocabulary_filter",
        "aws_transfer_workflow",
        "aws_appconfig_extension",
        "aws_apprunner_vpc_ingress_connection",
        "aws_auditmanager_control",
        "aws_auditmanager_framework",
        "aws_codepipeline_custom_action_type",
        "aws_comprehend_document_classifier",
        "aws_comprehend_entity_recognizer",
        "aws_connect_phone_number",
        "aws_directory_service_region",
        "aws_dms_s3_endpoint",
        "aws_dynamodb_table_replica",
        "aws_ec2_network_insights_analysis",
        "aws_ec2_transit_gateway_policy_table",
        "aws_evidently_feature",
        "aws_evidently_project",
        "aws_evidently_segment",
        "aws_fsx_file_cache",
        "aws_ivs_channel",
        "aws_ivs_playback_key_pair",
        "aws_ivs_recording_configuration",
        "aws_ivschat_logging_configuration",
        "aws_ivschat_room",
        "aws_kendra_data_source",
        "aws_lightsail_certificate",
        "aws_lightsail_disk",
        "aws_lightsail_lb",
        "aws_medialive_channel",
        "aws_medialive_input",
        "aws_medialive_input_security_group",
        "aws_medialive_multiplex",
        "aws_msk_serverless_cluster",
        "aws_networkmanager_connect_attachment",
        "aws_networkmanager_core_network",
        "aws_networkmanager_site_to_site_vpn_attachment",
        "aws_networkmanager_transit_gateway_peering",
        "aws_networkmanager_transit_gateway_route_table_attachment",
        "aws_networkmanager_vpc_attachment",
        "aws_rds_reserved_instance",
        "aws_redshiftserverless_workgroup",
        "aws_resourceexplorer2_index",
        "aws_s3control_storage_lens_configuration",
        "aws_sagemaker_space",
        "aws_scheduler_schedule_group",
        "aws_sesv2_configuration_set",
        "aws_sesv2_dedicated_ip_pool",
        "aws_sesv2_email_identity",
        "aws_transcribe_language_model",
        "aws_auditmanager_assessment",
        "aws_chimesdkmediapipelines_media_insights_pipeline_configuration",
        "aws_chimesdkvoice_sip_media_application",
        "aws_chimesdkvoice_voice_profile_domain",
        "aws_cleanrooms_collaboration",
        "aws_cleanrooms_configured_table",
        "aws_codeguruprofiler_profiling_group",
        "aws_codegurureviewer_repository_association",
        "aws_customerprofiles_domain",
        "aws_datasync_location_azure_blob",
        "aws_datasync_location_fsx_ontap_file_system",
        "aws_datasync_location_object_storage",
        "aws_dms_replication_config",
        "aws_docdbelastic_cluster",
        "aws_ec2_instance_connect_endpoint",
        "aws_eks_access_entry",
        "aws_eks_pod_identity_association",
        "aws_elasticache_serverless_cache",
        "aws_emrcontainers_job_template",
        "aws_evidently_launch",
        "aws_finspace_kx_cluster",
        "aws_finspace_kx_database",
        "aws_finspace_kx_dataview",
        "aws_finspace_kx_environment",
        "aws_finspace_kx_scaling_group",
        "aws_finspace_kx_user",
        "aws_finspace_kx_volume",
        "aws_globalaccelerator_custom_routing_accelerator",
        "aws_glue_data_quality_ruleset",
        "aws_imagebuilder_workflow",
        "aws_internetmonitor_monitor",
        "aws_iot_billing_group",
        "aws_iot_ca_certificate",
        "aws_iot_domain_configuration",
        "aws_lb_trust_store",
        "aws_lexv2models_bot",
        "aws_lightsail_bucket",
        "aws_lightsail_distribution",
        "aws_msk_replicator",
        "aws_msk_vpc_connection",
        "aws_networkmanager_connect_peer",
        "aws_oam_link",
        "aws_oam_sink",
        "aws_opensearchserverless_collection",
        "aws_organizations_resource_policy",
        "aws_pipes_pipe",
        "aws_prometheus_scraper",
        "aws_quicksight_folder",
        "aws_quicksight_vpc_connection",
        "aws_rbin_rule",
        "aws_rds_custom_db_engine_version",
        "aws_redshift_cluster_snapshot",
        "aws_resourceexplorer2_view",
        "aws_s3control_access_grant",
        "aws_s3control_access_grants_instance",
        "aws_s3control_access_grants_location",
        "aws_sagemaker_data_quality_job_definition",
        "aws_sagemaker_monitoring_schedule",
        "aws_sagemaker_pipeline",
        "aws_securitylake_data_lake",
        "aws_sesv2_contact_list",
        "aws_ssmcontacts_contact",
        "aws_ssmincidents_replication_set",
        "aws_ssmincidents_response_plan",
        "aws_ssoadmin_application",
        "aws_ssoadmin_trusted_token_issuer",
        "aws_synthetics_group",
        "aws_transfer_agreement",
        "aws_transfer_certificate",
        "aws_transfer_connector",
        "aws_transfer_profile",
        "aws_verifiedaccess_endpoint",
        "aws_verifiedaccess_group",
        "aws_verifiedaccess_instance",
        "aws_verifiedaccess_trust_provider",
        "aws_vpc_ipam_resource_discovery",
        "aws_vpc_ipam_resource_discovery_association",
        "aws_vpc_security_group_egress_rule",
        "aws_vpc_security_group_ingress_rule",
        "aws_vpclattice_access_log_subscription",
        "aws_vpclattice_listener",
        "aws_vpclattice_listener_rule",
        "aws_vpclattice_service",
        "aws_vpclattice_service_network",
        "aws_vpclattice_service_network_service_association",
        "aws_vpclattice_service_network_vpc_association",
        "aws_vpclattice_target_group",
        "aws_workspaces_connection_alias",
        "aws_bedrockagent_agent",
        "aws_api_gateway_domain_name_access_association",
        "aws_appfabric_app_authorization",
        "aws_appfabric_app_bundle",
        "aws_appfabric_ingestion",
        "aws_appfabric_ingestion_destination",
        "aws_appintegrations_data_integration",
        "aws_backup_logically_air_gapped_vault",
        "aws_backup_restore_testing_plan",
        "aws_bcmdataexports_export",
        "aws_bedrock_custom_model",
        "aws_bedrock_guardrail",
        "aws_bedrock_inference_profile",
        "aws_bedrock_provisioned_model_throughput",
        "aws_bedrockagent_agent_alias",
        "aws_bedrockagent_knowledge_base",
        "aws_chatbot_slack_channel_configuration",
        "aws_chatbot_teams_channel_configuration",
        "aws_cleanrooms_membership",
        "aws_cloudfront_vpc_origin",
        "aws_cloudwatch_log_anomaly_detector",
        "aws_cloudwatch_log_delivery",
        "aws_cloudwatch_log_delivery_destination",
        "aws_cloudwatch_log_delivery_source",
        "aws_codebuild_fleet",
        "aws_codeconnections_connection",
        "aws_codeconnections_host",
        "aws_controltower_landing_zone",
        "aws_datazone_domain",
        "aws_drs_replication_configuration_template",
        "aws_ec2_capacity_block_reservation",
        "aws_elasticache_reserved_cache_node",
        "aws_fms_resource_set",
        "aws_globalaccelerator_cross_account_attachment",
        "aws_guardduty_malware_protection_plan",
        "aws_imagebuilder_lifecycle_policy",
        "aws_m2_application",
        "aws_m2_environment",
        "aws_media_packagev2_channel_group",
        "aws_memorydb_multi_region_cluster",
        "aws_networkfirewall_tls_inspection_configuration",
        "aws_networkmanager_dx_gateway_attachment",
        "aws_networkmonitor_monitor",
        "aws_networkmonitor_probe",
        "aws_osis_pipeline",
        "aws_paymentcryptography_key",
        "aws_pinpoint_email_template",
        "aws_pinpointsmsvoicev2_configuration_set",
        "aws_pinpointsmsvoicev2_opt_out_list",
        "aws_pinpointsmsvoicev2_phone_number",
        "aws_quicksight_analysis",
        "aws_quicksight_dashboard",
        "aws_quicksight_data_set",
        "aws_quicksight_namespace",
        "aws_quicksight_template",
        "aws_quicksight_theme",
        "aws_rds_cluster_snapshot_copy",
        "aws_rds_integration",
        "aws_rekognition_collection",
        "aws_rekognition_project",
        "aws_rekognition_stream_processor",
        "aws_resiliencehub_resiliency_policy",
        "aws_route53domains_domain",
        "aws_route53profiles_association",
        "aws_route53profiles_profile",
        "aws_sagemaker_hub",
        "aws_sagemaker_mlflow_tracking_server",
        "aws_securityhub_automation_rule",
        "aws_securitylake_subscriber",
        "aws_servicecatalogappregistry_application",
        "aws_servicecatalogappregistry_attribute_group",
        "aws_ssmcontacts_rotation",
        "aws_ssmquicksetup_configuration_manager",
        "aws_timestreaminfluxdb_db_instance",
        "aws_timestreamquery_scheduled_query",
        "aws_vpc_block_public_access_exclusion",
        "aws_vpclattice_resource_configuration",
        "aws_vpclattice_resource_gateway",
        "aws_vpclattice_service_network_resource_association"
    ],
    "gcp_taggable": [
        "google_bigquery_dataset",
        "google_bigquery_job",
        "google_bigquery_table",
        "google_monitoring_notification_channel",
        "google_bigtable_instance",
        "google_composer_environment",
        "google_dns_managed_zone",
        "google_cloudfunctions_function",
        "google_healthcare_dicom_store",
        "google_healthcare_fhir_store",
        "google_healthcare_hl7_v2_store",
        "google_kms_crypto_key",
        "google_project",
        "google_pubsub_subscription",
        "google_pubsub_topic",
        "google_spanner_instance",
        "google_storage_bucket",
        "google_tpu_node",
        "google_compute_address",
        "google_compute_disk",
        "google_compute_forwarding_rule",
        "google_compute_global_address",
        "google_compute_global_forwarding_rule",
        "google_compute_image",
        "google_compute_instance",
        "google_compute_instance_from_template",
        "google_compute_instance_template",
        "google_compute_interconnect_attachment",
        "google_compute_region_disk",
        "google_compute_snapshot",
        "google_compute_vpn_tunnel",
        "google_dataflow_job",
        "google_dataproc_cluster",
        "google_dataproc_job",
        "google_filestore_instance",
        "google_ml_engine_model",
        "google_redis_instance",
        "google_secret_manager_secret",
        "google_dataflow_flex_template_job",
        "google_active_directory_domain",
        "google_cloud_identity_group",
        "google_compute_external_vpn_gateway",
        "google_game_services_game_server_cluster",
        "google_game_services_game_server_config",
        "google_game_services_game_server_deployment",
        "google_game_services_realm",
        "google_network_management_connectivity_test",
        "google_notebooks_instance",
        "google_eventarc_trigger",
        "google_healthcare_consent_store",
        "google_workflows_workflow",
        "google_assured_workloads_workload",
        "google_dataproc_workflow_template",
        "google_dialogflow_cx_intent",
        "google_gke_hub_membership",
        "google_memcache_instance",
        "google_network_services_edge_cache_keyset",
        "google_network_services_edge_cache_origin",
        "google_network_services_edge_cache_service",
        "google_notebooks_runtime",
        "google_privateca_ca_pool",
        "google_privateca_certificate",
        "google_privateca_certificate_authority",
        "google_privateca_certificate_template",
        "google_recaptcha_enterprise_key",
        "google_vertex_ai_dataset",
        "google_artifact_registry_repository",
        "google_certificate_manager_certificate",
        "google_certificate_manager_certificate_map",
        "google_certificate_manager_certificate_map_entry",
        "google_certificate_manager_dns_authorization",
        "google_clouddeploy_delivery_pipeline",
        "google_clouddeploy_target",
        "google_data_fusion_instance",
        "google_dataplex_lake",
        "google_dataproc_metastore_service",
        "google_network_connectivity_hub",
        "google_network_connectivity_spoke",
        "google_beyondcorp_app_connector",
        "google_beyondcorp_app_gateway",
        "google_cloud_run_v2_job",
        "google_cloud_run_v2_service",
        "google_cloudfunctions2_function",
        "google_dataplex_asset",
        "google_dataplex_zone",
        "google_datastream_connection_profile",
        "google_datastream_private_connection",
        "google_filestore_backup",
        "google_filestore_snapshot",
        "google_vertex_ai_endpoint",
        "google_vertex_ai_featurestore",
        "google_vertex_ai_featurestore_entitytype",
        "google_vertex_ai_featurestore_entitytype_feature",
        "google_vertex_ai_index",
        "google_vertex_ai_tensorboard",
        "google_alloydb_backup",
        "google_alloydb_cluster",
        "google_alloydb_instance",
        "google_beyondcorp_app_connection",
        "google_certificate_manager_certificate_issuance_config",
        "google_certificate_manager_trust_config",
        "google_clouddomains_registration",
        "google_compute_region_instance_template",
        "google_database_migration_service_connection_profile",
        "google_database_migration_service_private_connection",
        "google_dataplex_datascan",
        "google_dataplex_task",
        "google_datastream_stream",
        "google_edgecontainer_cluster",
        "google_edgecontainer_node_pool",
        "google_edgecontainer_vpn_connection",
        "google_edgenetwork_network",
        "google_edgenetwork_subnet",
        "google_gke_backup_backup_plan",
        "google_gke_backup_restore_plan",
        "google_gke_hub_feature",
        "google_gke_hub_membership_binding",
        "google_gke_hub_namespace",
        "google_gke_hub_scope",
        "google_gke_hub_scope_rbac_role_binding",
        "google_integration_connectors_connection",
        "google_integration_connectors_endpoint_attachment",
        "google_migration_center_group",
        "google_netapp_active_directory",
        "google_netapp_backup_policy",
        "google_netapp_backup_vault",
        "google_netapp_kmsconfig",
        "google_netapp_storage_pool",
        "google_netapp_volume",
        "google_network_connectivity_policy_based_route",
        "google_network_connectivity_service_connection_policy",
        "google_network_security_address_group",
        "google_network_services_gateway",
        "google_secure_source_manager_instance",
        "google_vertex_ai_feature_group",
        "google_vertex_ai_feature_group_feature",
        "google_vertex_ai_feature_online_store",
        "google_vertex_ai_feature_online_store_featureview",
        "google_vertex_ai_index_endpoint",
        "google_workbench_instance",
        "google_tpu_v2_vm",
        "google_apihub_api_hub_instance",
        "google_backup_dr_backup_vault",
        "google_blockchain_node_engine_blockchain_nodes",
        "google_clouddeploy_automation",
        "google_clouddeploy_custom_target_type",
        "google_colab_runtime_template",
        "google_compute_interconnect",
        "google_database_migration_service_migration_job",
        "google_dataplex_aspect_type",
        "google_dataplex_entry_group",
        "google_dataplex_entry_type",
        "google_dataproc_batch",
        "google_dataproc_gdc_application_environment",
        "google_dataproc_gdc_service_instance",
        "google_dataproc_gdc_spark_application",
        "google_dataproc_metastore_federation",
        "google_developer_connect_connection",
        "google_developer_connect_git_repository_link",
        "google_edgenetwork_interconnect_attachment",
        "google_gemini_code_repository_index",
        "google_gemini_repository_group",
        "google_healthcare_pipeline_job",
        "google_healthcare_workspace",
        "google_integration_connectors_managed_zone",
        "google_managed_kafka_cluster",
        "google_memorystore_instance",
        "google_netapp_backup",
        "google_netapp_volume_replication",
        "google_netapp_volume_snapshot",
        "google_network_connectivity_group",
        "google_network_connectivity_internal_range",
        "google_network_connectivity_regional_endpoint",
        "google_network_management_vpc_flow_logs_config",
        "google_network_security_authz_policy",
        "google_network_security_client_tls_policy",
        "google_network_security_firewall_endpoint",
        "google_network_security_firewall_endpoint_association",
        "google_network_security_security_profile",
        "google_network_security_security_profile_group",
        "google_network_security_server_tls_policy",
        "google_network_services_authz_extension",
        "google_network_services_lb_route_extension",
        "google_network_services_lb_traffic_extension",
        "google_oracle_database_autonomous_database",
        "google_oracle_database_cloud_exadata_infrastructure",
        "google_oracle_database_cloud_vm_cluster",
        "google_parallelstore_instance",
        "google_secret_manager_regional_secret",
        "google_spanner_instance_config",
        "google_transcoder_job",
        "google_transcoder_job_template"
    ],
    "azure_taggable": [
        "azurerm_api_management",
        "azurerm_api_management_named_value",
        "azurerm_api_management_property",
        "azurerm_analysis_services_server",
        "azurerm_app_configuration",
        "azurerm_app_service",
        "azurerm_app_service_certificate",
        "azurerm_app_service_certificate_order",
        "azurerm_app_service_environment",
        "azurerm_app_service_plan",
        "azurerm_app_service_slot",
        "azurerm_function_app",
        "azurerm_function_app_slot",
        "azurerm_application_insights",
        "azurerm_application_insights_web_test",
        "azurerm_user_assigned_identity",
        "azurerm_automation_account",
        "azurerm_automation_dsc_configuration",
        "azurerm_automation_runbook",
        "azurerm_resource_group",
        "azurerm_batch_account",
        "azurerm_bot_channels_registration",
        "azurerm_bot_web_app",
        "azurerm_cdn_endpoint",
        "azurerm_cdn_profile",
        "azurerm_cognitive_account",
        "azurerm_availability_set",
        "azurerm_dedicated_host",
        "azurerm_dedicated_host_group",
        "azurerm_disk_encryption_set",
        "azurerm_image",
        "azurerm_linux_virtual_machine",
        "azurerm_linux_virtual_machine_scale_set",
        "azurerm_managed_disk",
        "azurerm_orchestrated_virtual_machine_scale_set",
        "azurerm_proximity_placement_group",
        "azurerm_shared_image",
        "azurerm_shared_image_gallery",
        "azurerm_shared_image_version",
        "azurerm_snapshot",
        "azurerm_virtual_machine",
        "azurerm_virtual_machine_extension",
        "azurerm_virtual_machine_scale_set",
        "azurerm_windows_virtual_machine",
        "azurerm_windows_virtual_machine_scale_set",
        "azurerm_container_group",
        "azurerm_container_registry",
        "azurerm_container_registry_webhook",
        "azurerm_kubernetes_cluster",
        "azurerm_kubernetes_cluster_node_pool",
        "azurerm_cosmosdb_account",
        "azurerm_custom_provider",
        "azurerm_dns_a_record",
        "azurerm_dns_aaaa_record",
        "azurerm_dns_caa_record",
        "azurerm_dns_cname_record",
        "azurerm_dns_mx_record",
        "azurerm_dns_ns_record",
        "azurerm_dns_ptr_record",
        "azurerm_dns_srv_record",
        "azurerm_dns_txt_record",
        "azurerm_dns_zone",
        "azurerm_kusto_cluster",
        "azurerm_data_factory",
        "azurerm_data_lake_analytics_account",
        "azurerm_data_lake_store",
        "azurerm_data_share_account",
        "azurerm_mariadb_server",
        "azurerm_mssql_database",
        "azurerm_mssql_elasticpool",
        "azurerm_mssql_server",
        "azurerm_mssql_virtual_machine",
        "azurerm_mysql_server",
        "azurerm_postgresql_server",
        "azurerm_sql_database",
        "azurerm_sql_elasticpool",
        "azurerm_sql_failover_group",
        "azurerm_sql_server",
        "azurerm_database_migration_project",
        "azurerm_database_migration_service",
        "azurerm_databricks_workspace",
        "azurerm_dev_test_global_vm_shutdown_schedule",
        "azurerm_dev_test_lab",
        "azurerm_dev_test_linux_virtual_machine",
        "azurerm_dev_test_policy",
        "azurerm_dev_test_schedule",
        "azurerm_dev_test_virtual_network",
        "azurerm_dev_test_windows_virtual_machine",
        "azurerm_devspace_controller",
        "azurerm_hdinsight_hadoop_cluster",
        "azurerm_hdinsight_hbase_cluster",
        "azurerm_hdinsight_interactive_query_cluster",
        "azurerm_hdinsight_kafka_cluster",
        "azurerm_hdinsight_ml_services_cluster",
        "azurerm_hdinsight_rserver_cluster",
        "azurerm_hdinsight_spark_cluster",
        "azurerm_hdinsight_storm_cluster",
        "azurerm_dedicated_hardware_security_module",
        "azurerm_healthcare_service",
        "azurerm_iotcentral_application",
        "azurerm_iothub",
        "azurerm_iothub_dps",
        "azurerm_key_vault",
        "azurerm_key_vault_certificate",
        "azurerm_key_vault_key",
        "azurerm_key_vault_secret",
        "azurerm_lb",
        "azurerm_log_analytics_solution",
        "azurerm_log_analytics_workspace",
        "azurerm_logic_app_integration_account",
        "azurerm_logic_app_workflow",
        "azurerm_machine_learning_workspace",
        "azurerm_maintenance_configuration",
        "azurerm_managed_application",
        "azurerm_managed_application_definition",
        "azurerm_maps_account",
        "azurerm_media_services_account",
        "azurerm_eventgrid_domain",
        "azurerm_eventgrid_topic",
        "azurerm_eventhub_cluster",
        "azurerm_eventhub_namespace",
        "azurerm_notification_hub",
        "azurerm_notification_hub_namespace",
        "azurerm_relay_namespace",
        "azurerm_servicebus_namespace",
        "azurerm_signalr_service",
        "azurerm_spatial_anchors_account",
        "azurerm_monitor_action_group",
        "azurerm_monitor_action_rule_action_group",
        "azurerm_monitor_action_rule_suppression",
        "azurerm_monitor_activity_log_alert",
        "azurerm_monitor_autoscale_setting",
        "azurerm_monitor_metric_alert",
        "azurerm_monitor_scheduled_query_rules_alert",
        "azurerm_monitor_scheduled_query_rules_log",
        "azurerm_netapp_account",
        "azurerm_netapp_pool",
        "azurerm_netapp_volume",
        "azurerm_application_gateway",
        "azurerm_application_security_group",
        "azurerm_bastion_host",
        "azurerm_express_route_circuit",
        "azurerm_express_route_gateway",
        "azurerm_firewall",
        "azurerm_frontdoor",
        "azurerm_frontdoor_firewall_policy",
        "azurerm_local_network_gateway",
        "azurerm_nat_gateway",
        "azurerm_network_ddos_protection_plan",
        "azurerm_network_interface",
        "azurerm_network_profile",
        "azurerm_network_security_group",
        "azurerm_network_watcher",
        "azurerm_network_watcher_flow_log",
        "azurerm_point_to_site_vpn_gateway",
        "azurerm_private_endpoint",
        "azurerm_private_link_service",
        "azurerm_public_ip",
        "azurerm_public_ip_prefix",
        "azurerm_route_filter",
        "azurerm_route_table",
        "azurerm_traffic_manager_profile",
        "azurerm_virtual_hub",
        "azurerm_virtual_network",
        "azurerm_virtual_network_gateway",
        "azurerm_virtual_network_gateway_connection",
        "azurerm_virtual_wan",
        "azurerm_vpn_gateway",
        "azurerm_vpn_server_configuration",
        "azurerm_web_application_firewall_policy",
        "azurerm_dashboard",
        "azurerm_powerbi_embedded",
        "azurerm_private_dns_a_record",
        "azurerm_private_dns_aaaa_record",
        "azurerm_private_dns_cname_record",
        "azurerm_private_dns_mx_record",
        "azurerm_private_dns_ptr_record",
        "azurerm_private_dns_srv_record",
        "azurerm_private_dns_txt_record",
        "azurerm_private_dns_zone",
        "azurerm_private_dns_zone_virtual_network_link",
        "azurerm_recovery_services_vault",
        "azurerm_redis_cache",
        "azurerm_search_service",
        "azurerm_service_fabric_cluster",
        "azurerm_spring_cloud_service",
        "azurerm_hpc_cache",
        "azurerm_storage_account",
        "azurerm_stream_analytics_job",
        "azurerm_synapse_workspace",
        "azurerm_iot_time_series_insights_reference_data_set",
        "azurerm_iot_time_series_insights_standard_environment",
        "azurerm_app_service_managed_certificate",
        "azurerm_attestation_provider",
        "azurerm_digital_twins_instance",
        "azurerm_disk_access",
        "azurerm_eventgrid_system_topic",
        "azurerm_firewall_policy",
        "azurerm_integration_service_environment",
        "azurerm_iot_security_solution",
        "azurerm_iot_time_series_insights_gen2_environment",
        "azurerm_ip_group",
        "azurerm_log_analytics_cluster",
        "azurerm_log_analytics_saved_search",
        "azurerm_media_streaming_endpoint",
        "azurerm_monitor_smart_detector_alert_rule",
        "azurerm_network_connection_monitor",
        "azurerm_resource_group_template_deployment",
        "azurerm_security_center_automation",
        "azurerm_service_fabric_mesh_application",
        "azurerm_service_fabric_mesh_local_network",
        "azurerm_service_fabric_mesh_secret",
        "azurerm_service_fabric_mesh_secret_value",
        "azurerm_ssh_public_key",
        "azurerm_stack_hci_cluster",
        "azurerm_storage_sync",
        "azurerm_subnet_service_endpoint_storage_policy",
        "azurerm_subscription_template_deployment",
        "azurerm_synapse_spark_pool",
        "azurerm_synapse_sql_pool",
        "azurerm_virtual_desktop_application_group",
        "azurerm_virtual_desktop_host_pool",
        "azurerm_virtual_desktop_workspace",
        "azurerm_virtual_hub_security_partner_provider",
        "azurerm_vpn_site",
        "azurerm_communication_service",
        "azurerm_databox_edge_device",
        "azurerm_express_route_port",
        "azurerm_management_group_template_deployment",
        "azurerm_media_live_event",
        "azurerm_purview_account",
        "azurerm_redis_enterprise_cluster",
        "azurerm_subscription",
        "azurerm_tenant_template_deployment",
        "azurerm_vmware_private_cloud",
        "azurerm_aadb2c_directory",
        "azurerm_active_directory_domain_service",
        "azurerm_app_configuration_feature",
        "azurerm_app_configuration_key",
        "azurerm_app_service_environment_v3",
        "azurerm_bot_service_azure_bot",
        "azurerm_container_registry_task",
        "azurerm_cosmosdb_cassandra_cluster",
        "azurerm_data_protection_backup_vault",
        "azurerm_disk_pool",
        "azurerm_healthbot",
        "azurerm_iot_time_series_insights_event_source_eventhub",
        "azurerm_iot_time_series_insights_event_source_iothub",
        "azurerm_key_vault_managed_hardware_security_module",
        "azurerm_key_vault_managed_storage_account",
        "azurerm_key_vault_managed_storage_account_sas_token_definition",
        "azurerm_load_test",
        "azurerm_logic_app_standard",
        "azurerm_logz_monitor",
        "azurerm_machine_learning_compute_cluster",
        "azurerm_machine_learning_compute_instance",
        "azurerm_machine_learning_inference_cluster",
        "azurerm_machine_learning_synapse_spark",
        "azurerm_maps_creator",
        "azurerm_monitor_private_link_scope",
        "azurerm_mssql_failover_group",
        "azurerm_mssql_job_agent",
        "azurerm_mysql_flexible_server",
        "azurerm_netapp_snapshot_policy",
        "azurerm_postgresql_flexible_server",
        "azurerm_service_fabric_managed_cluster",
        "azurerm_sql_managed_instance",
        "azurerm_static_site",
        "azurerm_storage_disks_pool",
        "azurerm_stream_analytics_cluster",
        "azurerm_synapse_private_link_hub",
        "azurerm_video_analyzer",
        "azurerm_virtual_desktop_scaling_plan",
        "azurerm_api_connection",
        "azurerm_application_insights_workbook",
        "azurerm_application_insights_workbook_template",
        "azurerm_capacity_reservation",
        "azurerm_capacity_reservation_group",
        "azurerm_cdn_frontdoor_endpoint",
        "azurerm_cdn_frontdoor_profile",
        "azurerm_confidential_ledger",
        "azurerm_container_registry_agent_pool",
        "azurerm_data_protection_resource_guard",
        "azurerm_elastic_cloud_elasticsearch",
        "azurerm_fluid_relay_server",
        "azurerm_gallery_application",
        "azurerm_gallery_application_version",
        "azurerm_healthcare_dicom_service",
        "azurerm_healthcare_fhir_service",
        "azurerm_healthcare_workspace",
        "azurerm_linux_function_app",
        "azurerm_linux_function_app_slot",
        "azurerm_linux_web_app",
        "azurerm_linux_web_app_slot",
        "azurerm_logz_sub_account",
        "azurerm_monitor_data_collection_rule",
        "azurerm_mssql_managed_database",
        "azurerm_mssql_managed_instance",
        "azurerm_portal_dashboard",
        "azurerm_route_server",
        "azurerm_service_plan",
        "azurerm_web_pubsub",
        "azurerm_windows_function_app",
        "azurerm_windows_function_app_slot",
        "azurerm_windows_web_app",
        "azurerm_windows_web_app_slot",
        "azurerm_automation_watcher",
        "azurerm_cdn_frontdoor_firewall_policy",
        "azurerm_dashboard_grafana",
        "azurerm_databricks_access_connector",
        "azurerm_datadog_monitor",
        "azurerm_healthcare_medtech_service",
        "azurerm_iothub_device_update_account",
        "azurerm_iothub_device_update_instance",
        "azurerm_kubernetes_fleet_manager",
        "azurerm_lab_service_plan",
        "azurerm_log_analytics_query_pack",
        "azurerm_log_analytics_query_pack_query",
        "azurerm_monitor_alert_processing_rule_action_group",
        "azurerm_monitor_alert_processing_rule_suppression",
        "azurerm_monitor_data_collection_endpoint",
        "azurerm_monitor_scheduled_query_rules_alert_v2",
        "azurerm_network_manager",
        "azurerm_nginx_deployment",
        "azurerm_orbital_contact_profile",
        "azurerm_orbital_spacecraft",
        "azurerm_private_dns_resolver",
        "azurerm_private_dns_resolver_dns_forwarding_ruleset",
        "azurerm_private_dns_resolver_inbound_endpoint",
        "azurerm_private_dns_resolver_outbound_endpoint",
        "azurerm_resource_deployment_script_azure_cli",
        "azurerm_resource_deployment_script_azure_power_shell",
        "azurerm_application_insights_standard_web_test",
        "azurerm_application_load_balancer",
        "azurerm_application_load_balancer_frontend",
        "azurerm_application_load_balancer_subnet_association",
        "azurerm_arc_kubernetes_cluster",
        "azurerm_arc_machine_extension",
        "azurerm_arc_private_link_scope",
        "azurerm_arc_resource_bridge_appliance",
        "azurerm_automanage_configuration",
        "azurerm_automation_powershell72_module",
        "azurerm_automation_python3_package",
        "azurerm_container_app",
        "azurerm_container_app_environment",
        "azurerm_container_app_environment_certificate",
        "azurerm_cosmosdb_postgresql_cluster",
        "azurerm_custom_ip_prefix",
        "azurerm_dev_center",
        "azurerm_dev_center_project",
        "azurerm_elastic_san",
        "azurerm_email_communication_service",
        "azurerm_graph_account",
        "azurerm_graph_services_account",
        "azurerm_lab_service_lab",
        "azurerm_machine_learning_datastore_blobstorage",
        "azurerm_machine_learning_datastore_datalake_gen2",
        "azurerm_machine_learning_datastore_fileshare",
        "azurerm_managed_lustre_file_system",
        "azurerm_mobile_network",
        "azurerm_mobile_network_attached_data_network",
        "azurerm_mobile_network_data_network",
        "azurerm_mobile_network_packet_core_control_plane",
        "azurerm_mobile_network_packet_core_data_plane",
        "azurerm_mobile_network_service",
        "azurerm_mobile_network_sim_group",
        "azurerm_mobile_network_sim_policy",
        "azurerm_mobile_network_site",
        "azurerm_mobile_network_slice",
        "azurerm_monitor_alert_prometheus_rule_group",
        "azurerm_monitor_workspace",
        "azurerm_mssql_virtual_machine_group",
        "azurerm_network_function_azure_traffic_collector",
        "azurerm_network_function_collector_policy",
        "azurerm_palo_alto_local_rulestack_rule",
        "azurerm_palo_alto_next_generation_firewall_virtual_hub_local_rulestack",
        "azurerm_palo_alto_next_generation_firewall_virtual_hub_panorama",
        "azurerm_palo_alto_next_generation_firewall_virtual_network_local_rulestack",
        "azurerm_palo_alto_next_generation_firewall_virtual_network_panorama",
        "azurerm_sentinel_threat_intelligence_indicator",
        "azurerm_storage_mover",
        "azurerm_virtual_machine_run_command",
        "azurerm_voice_services_communications_gateway",
        "azurerm_voice_services_communications_gateway_test_line",
        "azurerm_ai_services",
        "azurerm_arc_kubernetes_provisioned_cluster",
        "azurerm_arc_machine",
        "azurerm_cognitive_account_rai_policy",
        "azurerm_container_app_job",
        "azurerm_dashboard_grafana_managed_private_endpoint",
        "azurerm_dev_center_dev_box_definition",
        "azurerm_dev_center_environment_type",
        "azurerm_dev_center_network_connection",
        "azurerm_dev_center_project_environment_type",
        "azurerm_dev_center_project_pool",
        "azurerm_dynatrace_monitor",
        "azurerm_email_communication_service_domain",
        "azurerm_eventgrid_namespace",
        "azurerm_fabric_capacity",
        "azurerm_key_vault_managed_hardware_security_module_key",
        "azurerm_mongo_cluster",
        "azurerm_netapp_backup_policy",
        "azurerm_netapp_backup_vault",
        "azurerm_oracle_autonomous_database",
        "azurerm_oracle_cloud_vm_cluster",
        "azurerm_oracle_exadata_infrastructure",
        "azurerm_redhat_openshift_cluster",
        "azurerm_restore_point_collection",
        "azurerm_stack_hci_logical_network",
        "azurerm_stack_hci_marketplace_gallery_image",
        "azurerm_stack_hci_network_interface",
        "azurerm_stack_hci_storage_path",
        "azurerm_stack_hci_virtual_hard_disk",
        "azurerm_static_web_app",
        "azurerm_system_center_virtual_machine_manager_availability_set",
        "azurerm_system_center_virtual_machine_manager_cloud",
        "azurerm_system_center_virtual_machine_manager_server",
        "azurerm_system_center_virtual_machine_manager_virtual_machine_template",
        "azurerm_system_center_virtual_machine_manager_virtual_network",
        "azurerm_trusted_signing_account",
        "azurerm_video_indexer_account",
        "azurerm_virtual_machine_restore_point_collection",
        "azurerm_workloads_sap_discovery_virtual_instance",
        "azurerm_workloads_sap_single_node_virtual_instance",
        "azurerm_workloads_sap_three_tier_virtual_instance"
    ]
}
